/*
 * Automatically generated file; DO NOT EDIT.
 * Linux/arm64 6.6.33-2 Kernel Configuration
 */
#define CONFIG_IP6_NF_MATCH_AH_MODULE 1
#define CONFIG_NLS_CODEPAGE_861_MODULE 1
#define CONFIG_MTD_SPI_NAND_MODULE 1
#define CONFIG_RING_BUFFER 1
#define CONFIG_SND_SOC_WM8804_MODULE 1
#define CONFIG_NF_CONNTRACK_H323_MODULE 1
#define CONFIG_HAVE_ARCH_SECCOMP_FILTER 1
#define CONFIG_IP6_NF_SECURITY_MODULE 1
#define CONFIG_SND_PROC_FS 1
#define CONFIG_SCSI_DMA 1
#define CONFIG_NETFILTER_FAMILY_BRIDGE 1
#define CONFIG_TOUCHSCREEN_IQS5XX_MODULE 1
#define CONFIG_CC_HAS_SANCOV_TRACE_PC 1
#define CONFIG_DEFAULT_INIT ""
#define CONFIG_ARM64_PAGE_SHIFT 12
#define CONFIG_VIDEO_EM28XX_V4L2_MODULE 1
#define CONFIG_ARCH_HAS_DEBUG_VM_PGTABLE 1
#define CONFIG_NFT_NAT_MODULE 1
#define CONFIG_INPUT_KEYBOARD 1
#define CONFIG_INET_TABLE_PERTURB_ORDER 16
#define CONFIG_ARCH_SUPPORTS_INT128 1
#define CONFIG_IP_NF_TARGET_SYNPROXY_MODULE 1
#define CONFIG_MEMORY_ISOLATION 1
#define CONFIG_SLUB_CPU_PARTIAL 1
#define CONFIG_RFS_ACCEL 1
#define CONFIG_IP_NF_TARGET_REDIRECT_MODULE 1
#define CONFIG_ARCH_WANTS_THP_SWAP 1
#define CONFIG_CRC32 1
#define CONFIG_SND_BCM2708_SOC_FE_PI_AUDIO_MODULE 1
#define CONFIG_I2C_BOARDINFO 1
#define CONFIG_USB_ALI_M5632 1
#define CONFIG_NFT_FIB_INET_MODULE 1
#define CONFIG_DM_SNAPSHOT_MODULE 1
#define CONFIG_TOUCHSCREEN_RASPBERRYPI_FW_MODULE 1
#define CONFIG_PNFS_FLEXFILE_LAYOUT 1
#define CONFIG_IR_JVC_DECODER_MODULE 1
#define CONFIG_USB_CONFIGFS_NCM 1
#define CONFIG_FSCACHE 1
#define CONFIG_NETFILTER_XT_MATCH_CPU_MODULE 1
#define CONFIG_DVB_ISL6405_MODULE 1
#define CONFIG_B43_BCMA_PIO 1
#define CONFIG_RTC_DRV_PCF85363_MODULE 1
#define CONFIG_BLK_SED_OPAL 1
#define CONFIG_SUNRPC_SWAP 1
#define CONFIG_KEY_DH_OPERATIONS 1
#define CONFIG_IR_MCE_KBD_DECODER_MODULE 1
#define CONFIG_SECCOMP 1
#define CONFIG_CPU_FREQ_GOV_CONSERVATIVE 1
#define CONFIG_HIGH_RES_TIMERS 1
#define CONFIG_KGDB_HONOUR_BLOCKLIST 1
#define CONFIG_ARCH_HAS_SET_MEMORY 1
#define CONFIG_BLK_DEV_DM_MODULE 1
#define CONFIG_RT2800USB_RT3573 1
#define CONFIG_VLAN_8021Q_MODULE 1
#define CONFIG_IP_MULTIPLE_TABLES 1
#define CONFIG_UEVENT_HELPER 1
#define CONFIG_BT_RFCOMM_MODULE 1
#define CONFIG_FIX_EARLYCON_MEM 1
#define CONFIG_LEDS_TRIGGER_HEARTBEAT 1
#define CONFIG_FB_TFT_HX8353D_MODULE 1
#define CONFIG_DVB_TDA1004X_MODULE 1
#define CONFIG_XZ_DEC_IA64 1
#define CONFIG_JOYSTICK_ADI_MODULE 1
#define CONFIG_CLK_BCM2835 1
#define CONFIG_DVB_BCM3510_MODULE 1
#define CONFIG_INOTIFY_USER 1
#define CONFIG_NF_CONNTRACK_NETBIOS_NS_MODULE 1
#define CONFIG_HDMI 1
#define CONFIG_MULTIPLEXER_MODULE 1
#define CONFIG_BRIDGE_EBT_T_FILTER_MODULE 1
#define CONFIG_NETWORK_FILESYSTEMS 1
#define CONFIG_NF_FLOW_TABLE_MODULE 1
#define CONFIG_CRYPTO_MD4_MODULE 1
#define CONFIG_BCMA_HOST_PCI 1
#define CONFIG_USB_SI470X_MODULE 1
#define CONFIG_RPI_AXIPERF_MODULE 1
#define CONFIG_CPU_FREQ_GOV_ONDEMAND 1
#define CONFIG_KDB_DEFAULT_ENABLE 0x1
#define CONFIG_USB_GSPCA_JL2005BCD_MODULE 1
#define CONFIG_ARM64_VA_BITS 48
#define CONFIG_BT_HCIBFUSB_MODULE 1
#define CONFIG_FB_CORE 1
#define CONFIG_GLOB 1
#define CONFIG_ARCH_WANT_LD_ORPHAN_WARN 1
#define CONFIG_CGROUP_DEVICE 1
#define CONFIG_ARM64_CNP 1
#define CONFIG_PPP_SYNC_TTY_MODULE 1
#define CONFIG_ARCH_SUSPEND_POSSIBLE 1
#define CONFIG_MMU_LAZY_TLB_REFCOUNT 1
#define CONFIG_COMPAT_NETLINK_MESSAGES 1
#define CONFIG_RC_CORE 1
#define CONFIG_USB_G_SERIAL_MODULE 1
#define CONFIG_CGROUP_WRITEBACK 1
#define CONFIG_PSTORE_DEFAULT_KMSG_BYTES 10240
#define CONFIG_SND_SOC_TPA6130A2_MODULE 1
#define CONFIG_MAC80211_STA_HASH_MAX_SIZE 0
#define CONFIG_LEDS_PCA955X_MODULE 1
#define CONFIG_IXGBE_IPSEC 1
#define CONFIG_IP_VS_NQ_MODULE 1
#define CONFIG_DVB_DRXD_MODULE 1
#define CONFIG_IR_IMON_DECODER_MODULE 1
#define CONFIG_HAVE_ARCH_MMAP_RND_BITS 1
#define CONFIG_TCG_TIS_CORE_MODULE 1
#define CONFIG_HID_SPEEDLINK_MODULE 1
#define CONFIG_BLK_DEV_NBD_MODULE 1
#define CONFIG_USB_SERIAL_NAVMAN_MODULE 1
#define CONFIG_CPU_FREQ_GOV_ATTR_SET 1
#define CONFIG_ARM64_ERRATUM_1024718 1
#define CONFIG_TCP_CONG_HTCP_MODULE 1
#define CONFIG_EXT4_FS_POSIX_ACL 1
#define CONFIG_PHYLINK 1
#define CONFIG_ZSTD_COMPRESS 1
#define CONFIG_BINFMT_MISC_MODULE 1
#define CONFIG_DRM_PANEL_ILITEK_ILI9881C_MODULE 1
#define CONFIG_SND_SOC_PCM179X_I2C_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_HELPER_MODULE 1
#define CONFIG_SSB_POSSIBLE 1
#define CONFIG_NFS_V4_2 1
#define CONFIG_USBIP_VUDC_MODULE 1
#define CONFIG_BRIDGE_EBT_T_NAT_MODULE 1
#define CONFIG_NF_NAT_SIP_MODULE 1
#define CONFIG_USB_F_EEM_MODULE 1
#define CONFIG_MMU_NOTIFIER 1
#define CONFIG_RADIO_SHARK_MODULE 1
#define CONFIG_ASYMMETRIC_KEY_TYPE 1
#define CONFIG_VHOST_VSOCK_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_STATISTIC_MODULE 1
#define CONFIG_I2C_MUX_PINCTRL_MODULE 1
#define CONFIG_NLS_CODEPAGE_855_MODULE 1
#define CONFIG_FB_TFT_ILI9486_MODULE 1
#define CONFIG_SPI_DYNAMIC 1
#define CONFIG_ARCH_CORRECT_STACKTRACE_ON_KRETPROBE 1
#define CONFIG_BCM_VC_SM_CMA_MODULE 1
#define CONFIG_UHID_MODULE 1
#define CONFIG_DVB_EC100_MODULE 1
#define CONFIG_IP_NF_NAT_MODULE 1
#define CONFIG_USB_SERIAL_EDGEPORT_TI_MODULE 1
#define CONFIG_B43LEGACY_LEDS 1
#define CONFIG_BME680_SPI_MODULE 1
#define CONFIG_USB_SERIAL_SAFE_MODULE 1
#define CONFIG_DVB_LGS8GL5_MODULE 1
#define CONFIG_BRIDGE_NF_EBTABLES_MODULE 1
#define CONFIG_CRYPTO_SHA1_ARM64_CE_MODULE 1
#define CONFIG_DVB_LG2160_MODULE 1
#define CONFIG_FW_LOADER_COMPRESS 1
#define CONFIG_USB_OHCI_LITTLE_ENDIAN 1
#define CONFIG_NET_SCH_FIFO 1
#define CONFIG_REISERFS_FS_MODULE 1
#define CONFIG_SWPHY 1
#define CONFIG_FSNOTIFY 1
#define CONFIG_BLK_DEV_LOOP_MIN_COUNT 8
#define CONFIG_STP_MODULE 1
#define CONFIG_USB_GSPCA_SQ905_MODULE 1
#define CONFIG_DVB_AU8522_MODULE 1
#define CONFIG_INET6_TUNNEL_MODULE 1
#define CONFIG_VIDEO_I2C_MODULE 1
#define CONFIG_DVB_M88RS2000_MODULE 1
#define CONFIG_NF_CONNTRACK_SIP_MODULE 1
#define CONFIG_STACK_TRACER 1
#define CONFIG_MEDIA_ATTACH 1
#define CONFIG_CRYPTO_MANAGER_DISABLE_TESTS 1
#define CONFIG_HIDRAW 1
#define CONFIG_NET_SCH_FQ_CODEL_MODULE 1
#define CONFIG_CEC_GPIO_MODULE 1
#define CONFIG_RT2X00_LIB_LEDS 1
#define CONFIG_NET_PTP_CLASSIFY 1
#define CONFIG_SND_BCM2708_SOC_ALLO_KATANA_DAC_MODULE 1
#define CONFIG_UNIX_DIAG_MODULE 1
#define CONFIG_IP_VS_SED_MODULE 1
#define CONFIG_GENERIC_SMP_IDLE_THREAD 1
#define CONFIG_NET_VENDOR_QUALCOMM 1
#define CONFIG_DVB_DS3000_MODULE 1
#define CONFIG_SQUASHFS_FILE_CACHE 1
#define CONFIG_ARCH_SUPPORTS_NUMA_BALANCING 1
#define CONFIG_CIFS_STATS2 1
#define CONFIG_MACVTAP_MODULE 1
#define CONFIG_ARCH_SUPPORTS_CRASH_DUMP 1
#define CONFIG_USB_SERIAL_FTDI_SIO_MODULE 1
#define CONFIG_NET_VENDOR_EZCHIP 1
#define CONFIG_BRIDGE_EBT_REDIRECT_MODULE 1
#define CONFIG_MEDIA_DIGITAL_TV_SUPPORT 1
#define CONFIG_LDISC_AUTOLOAD 1
#define CONFIG_MEDIA_TUNER_QM1D1B0004_MODULE 1
#define CONFIG_FIB_RULES 1
#define CONFIG_CRYPTO_CRCT10DIF 1
#define CONFIG_CRYPTO_GHASH_ARM64_CE_MODULE 1
#define CONFIG_W1_SLAVE_DS2408_MODULE 1
#define CONFIG_USB_CONFIGFS_OBEX 1
#define CONFIG_IP_VS_NFCT 1
#define CONFIG_HID_EMS_FF_MODULE 1
#define CONFIG_USB_AUTOSUSPEND_DELAY 2
#define CONFIG_VLAN_8021Q_GVRP 1
#define CONFIG_IP_SET_HASH_NETIFACE_MODULE 1
#define CONFIG_IP6_NF_MANGLE_MODULE 1
#define CONFIG_MEDIA_TUNER_SI2157_MODULE 1
#define CONFIG_HAVE_KVM_DIRTY_RING_ACQ_REL 1
#define CONFIG_HAVE_IRQ_TIME_ACCOUNTING 1
#define CONFIG_BT_MRVL_SDIO_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_REALM_MODULE 1
#define CONFIG_BT_HCIBPA10X_MODULE 1
#define CONFIG_SQUASHFS_XATTR 1
#define CONFIG_IP_VS_RR_MODULE 1
#define CONFIG_IPV6_MODULE 1
#define CONFIG_USB_SERIAL_QUALCOMM_MODULE 1
#define CONFIG_HAVE_STACKPROTECTOR 1
#define CONFIG_MT76x02_LIB_MODULE 1
#define CONFIG_NET_9P_MODULE 1
#define CONFIG_NET_HANDSHAKE 1
#define CONFIG_CRYPTO_AEAD_MODULE 1
#define CONFIG_COMPAT 1
#define CONFIG_MAGIC_SYSRQ_SERIAL 1
#define CONFIG_BQL 1
#define CONFIG_PHY_BRCM_USB 1
#define CONFIG_GPIO_PCA953X_IRQ 1
#define CONFIG_DEFAULT_TCP_CONG "cubic"
#define CONFIG_UEVENT_HELPER_PATH ""
#define CONFIG_USB_UAS 1
#define CONFIG_DEVTMPFS 1
#define CONFIG_NET_CLS_FLOW_MODULE 1
#define CONFIG_OF_IOMMU 1
#define CONFIG_VIDEO_BCM2835_MODULE 1
#define CONFIG_PNFS_FILE_LAYOUT 1
#define CONFIG_NET_IPVTI_MODULE 1
#define CONFIG_PCIEASPM_POWERSAVE 1
#define CONFIG_DVB_ISL6423_MODULE 1
#define CONFIG_USB_STORAGE_USBAT_MODULE 1
#define CONFIG_REISERFS_FS_POSIX_ACL 1
#define CONFIG_REGULATOR_ARIZONA_LDO1_MODULE 1
#define CONFIG_GPIO_MAX7301_MODULE 1
#define CONFIG_SUNRPC_BACKCHANNEL 1
#define CONFIG_NLS_ISO8859_7_MODULE 1
#define CONFIG_ANDROID_BINDER_IPC 1
#define CONFIG_NVMEM_RASPBERRYPI_OTP 1
#define CONFIG_IP6_NF_TARGET_REJECT_MODULE 1
#define CONFIG_CPUFREQ_DT 1
#define CONFIG_ARCH_MMAP_RND_COMPAT_BITS_MAX 16
#define CONFIG_PWM_PCA9685_MODULE 1
#define CONFIG_IR_SHARP_DECODER_MODULE 1
#define CONFIG_ASYNC_MEMCPY_MODULE 1
#define CONFIG_ARCH_SPARSEMEM_ENABLE 1
#define CONFIG_V4L_TEST_DRIVERS 1
#define CONFIG_NFT_OSF_MODULE 1
#define CONFIG_NF_NAT_REDIRECT 1
#define CONFIG_RTC_DRV_DS1305_MODULE 1
#define CONFIG_SND_BCM2708_SOC_CHIPDIP_DAC_MODULE 1
#define CONFIG_IR_NEC_DECODER_MODULE 1
#define CONFIG_USB_SERIAL_MOS7840_MODULE 1
#define CONFIG_SND_SOC_GENERIC_DMAENGINE_PCM 1
#define CONFIG_MEDIA_PCI_SUPPORT 1
#define CONFIG_WLAN 1
#define CONFIG_NAMESPACES 1
#define CONFIG_USB_U_AUDIO_MODULE 1
#define CONFIG_W1_SLAVE_DS2423_MODULE 1
#define CONFIG_HAVE_CMPXCHG_DOUBLE 1
#define CONFIG_RTC_DRV_ABX80X_MODULE 1
#define CONFIG_USB_NET_INT51X1_MODULE 1
#define CONFIG_KGDB_SERIAL_CONSOLE 1
#define CONFIG_ARCH_USE_MEMREMAP_PROT 1
#define CONFIG_NFS_V4_2_READ_PLUS 1
#define CONFIG_HAVE_ARCH_HUGE_VMAP 1
#define CONFIG_SND_SOC_SIGMADSP_MODULE 1
#define CONFIG_FRAMEBUFFER_CONSOLE_DETECT_PRIMARY 1
#define CONFIG_BCM_VIDEOCORE 1
#define CONFIG_DRM_GEM_DMA_HELPER_MODULE 1
#define CONFIG_USB_CONFIGFS_MODULE 1
#define CONFIG_SND_AUDIOSENSE_PI_MODULE 1
#define CONFIG_BLK_DEV_BSG 1
#define CONFIG_CRYPTO_ADIANTUM_MODULE 1
#define CONFIG_CONNECTOR_MODULE 1
#define CONFIG_MEDIA_USB_SUPPORT 1
#define CONFIG_NETFILTER_XT_TARGET_RATEEST_MODULE 1
#define CONFIG_PCIEAER 1
#define CONFIG_CRYPTO_ARCH_HAVE_LIB_CHACHA_MODULE 1
#define CONFIG_SCTP_COOKIE_HMAC_SHA1 1
#define CONFIG_BRIDGE_EBT_ARPREPLY_MODULE 1
#define CONFIG_B43LEGACY_DMA_AND_PIO_MODE 1
#define CONFIG_RTC_DRV_SD3078_MODULE 1
#define CONFIG_FB_RPISENSE_MODULE 1
#define CONFIG_INTEGRITY 1
#define CONFIG_ZONEFS_FS_MODULE 1
#define CONFIG_BCM2835_VCHIQ 1
#define CONFIG_DVB_MAX_ADAPTERS 16
#define CONFIG_LIBERTAS_USB_MODULE 1
#define CONFIG_JFS_FS_MODULE 1
#define CONFIG_CAN_EMS_USB_MODULE 1
#define CONFIG_XFRM_IPCOMP_MODULE 1
#define CONFIG_CRYPTO_DRBG_MENU 1
#define CONFIG_CRYPTO_RNG2 1
#define CONFIG_USB_PWC_INPUT_EVDEV 1
#define CONFIG_NETFILTER_NETLINK_QUEUE_MODULE 1
#define CONFIG_NET_ACT_CSUM_MODULE 1
#define CONFIG_SND_SOC_AD193X_MODULE 1
#define CONFIG_DVB_CXD2880_MODULE 1
#define CONFIG_NETWORK_PHY_TIMESTAMPING 1
#define CONFIG_MSDOS_FS 1
#define CONFIG_USB_U_SERIAL_MODULE 1
#define CONFIG_NET_CLS_CGROUP_MODULE 1
#define CONFIG_TUN_MODULE 1
#define CONFIG_SND_RPI_WM8804_SOUNDCARD_MODULE 1
#define CONFIG_WLAN_VENDOR_MICROCHIP 1
#define CONFIG_VIDEO_BU64754_MODULE 1
#define CONFIG_NET_VENDOR_DAVICOM 1
#define CONFIG_SOFTIRQ_ON_OWN_STACK 1
#define CONFIG_USB_GSPCA_SUNPLUS_MODULE 1
#define CONFIG_DVB_AU8522_V4L_MODULE 1
#define CONFIG_IIO_KFIFO_BUF_MODULE 1
#define CONFIG_IPV6_PIMSM_V2 1
#define CONFIG_DVB_USB_DVBSKY_MODULE 1
#define CONFIG_WIZNET_BUS_ANY 1
#define CONFIG_ZRAM_DEF_COMP_LZORLE 1
#define CONFIG_CAN_MODULE 1
#define CONFIG_GPIO_BCM_VIRT 1
#define CONFIG_CFG80211_MODULE 1
#define CONFIG_PAGE_SIZE_LESS_THAN_256KB 1
#define CONFIG_CRYPTO_CHACHA20POLY1305_MODULE 1
#define CONFIG_SSB_BLOCKIO 1
#define CONFIG_FB_TFT_HX8347D_MODULE 1
#define CONFIG_NLS_CODEPAGE_1250_MODULE 1
#define CONFIG_OF_RESERVED_MEM 1
#define CONFIG_DM_CRYPT_MODULE 1
#define CONFIG_REED_SOLOMON_ENC8 1
#define CONFIG_SERIAL_8250 1
#define CONFIG_RTC_DRV_ISL12022_MODULE 1
#define CONFIG_CRYPTO_AES_ARM64_MODULE 1
#define CONFIG_CAVIUM_ERRATUM_30115 1
#define CONFIG_B43LEGACY_PIO 1
#define CONFIG_LZO_DECOMPRESS 1
#define CONFIG_LIBERTAS_THINFIRM_MODULE 1
#define CONFIG_IP_VS_PROTO_AH 1
#define CONFIG_IOMMU_SUPPORT 1
#define CONFIG_HID_BELKIN_MODULE 1
#define CONFIG_VIDEO_IR_I2C_MODULE 1
#define CONFIG_DVB_STV0367_MODULE 1
#define CONFIG_LEDS_TRIGGER_CAMERA_MODULE 1
#define CONFIG_ARM64_ERRATUM_2077057 1
#define CONFIG_NLS_CODEPAGE_862_MODULE 1
#define CONFIG_WLAN_VENDOR_CISCO 1
#define CONFIG_ARM64_USE_LSE_ATOMICS 1
#define CONFIG_SND_AUDIOINJECTOR_OCTO_SOUNDCARD_MODULE 1
#define CONFIG_NFSD_MODULE 1
#define CONFIG_COMPAT_BINFMT_ELF 1
#define CONFIG_GCC_SUPPORTS_DYNAMIC_FTRACE_WITH_ARGS 1
#define CONFIG_USB_SERIAL_OPTION_MODULE 1
#define CONFIG_HID_ACRUX_MODULE 1
#define CONFIG_RD_LZMA 1
#define CONFIG_USB_GSPCA_SE401_MODULE 1
#define CONFIG_USB 1
#define CONFIG_GENERIC_IRQ_DEBUGFS 1
#define CONFIG_BCM2712_IOMMU 1
#define CONFIG_USB_SPEEDTOUCH_MODULE 1
#define CONFIG_MODULES_USE_ELF_RELA 1
#define CONFIG_BTREE 1
#define CONFIG_CRYPTO_HMAC 1
#define CONFIG_WLAN_VENDOR_REALTEK 1
#define CONFIG_BLK_WBT 1
#define CONFIG_INPUT_ADXL34X_SPI_MODULE 1
#define CONFIG_ETHERNET 1
#define CONFIG_NET_SCH_CODEL_MODULE 1
#define CONFIG_FRAMEBUFFER_CONSOLE_ROTATION 1
#define CONFIG_USBIP_VHCI_HC_PORTS 8
#define CONFIG_USB_GSPCA_JEILINJ_MODULE 1
#define CONFIG_HID_LOGITECH_HIDPP_MODULE 1
#define CONFIG_CRYPTO_SHA3 1
#define CONFIG_UBIFS_FS_ZSTD 1
#define CONFIG_BRANCH_PROFILE_NONE 1
#define CONFIG_SPI_DW_MMIO_MODULE 1
#define CONFIG_CRC_ITU_T 1
#define CONFIG_SND_HRTIMER_MODULE 1
#define CONFIG_HAVE_DMA_CONTIGUOUS 1
#define CONFIG_DQL 1
#define CONFIG_VXLAN_MODULE 1
#define CONFIG_FRAMEBUFFER_CONSOLE 1
#define CONFIG_SND_SOC_PCM512x_I2C_MODULE 1
#define CONFIG_DM_ZERO_MODULE 1
#define CONFIG_DVB_DIB8000_MODULE 1
#define CONFIG_SND_SEQUENCER_MODULE 1
#define CONFIG_SONY_FF 1
#define CONFIG_RASPBERRYPI_FIRMWARE 1
#define CONFIG_SOCK_CGROUP_DATA 1
#define CONFIG_COREDUMP 1
#define CONFIG_NET_FOU_IP_TUNNELS 1
#define CONFIG_USB_NET_GL620A_MODULE 1
#define CONFIG_DVB_LGDT3306A_MODULE 1
#define CONFIG_IP_NF_ARPTABLES_MODULE 1
#define CONFIG_DVB_ASCOT2E_MODULE 1
#define CONFIG_DVB_USB_GP8PSK_MODULE 1
#define CONFIG_USB_SERIAL_GENERIC 1
#define CONFIG_HID_CHERRY_MODULE 1
#define CONFIG_CAN_J1939_MODULE 1
#define CONFIG_FB_TFT_SH1106_MODULE 1
#define CONFIG_BATTERY_MAX17040_MODULE 1
#define CONFIG_ACCESSIBILITY 1
#define CONFIG_MKISS_MODULE 1
#define CONFIG_NFT_FIB_MODULE 1
#define CONFIG_HID_SUNPLUS_MODULE 1
#define CONFIG_INPUT_ADXL34X_MODULE 1
#define CONFIG_HID_PICOLCD_MODULE 1
#define CONFIG_BCMA_POSSIBLE 1
#define CONFIG_USB_CONFIGFS_RNDIS 1
#define CONFIG_NF_LOG_IPV4_MODULE 1
#define CONFIG_NET_SCH_SFB_MODULE 1
#define CONFIG_CC_HAS_AUTO_VAR_INIT_ZERO 1
#define CONFIG_ZRAM_MODULE 1
#define CONFIG_RASPBERRYPI_GPIOMEM_MODULE 1
#define CONFIG_CRYPTO_CAST5_MODULE 1
#define CONFIG_VGA_ARB 1
#define CONFIG_SATA_HOST 1
#define CONFIG_NF_TABLES_ARP 1
#define CONFIG_SND_SOC_MODULE 1
#define CONFIG_MAXIM_THERMOCOUPLE_MODULE 1
#define CONFIG_SND_BCM2708_SOC_JUSTBOOM_DIGI_MODULE 1
#define CONFIG_SCSI_COMMON 1
#define CONFIG_SURFACE_PLATFORMS 1
#define CONFIG_NET_IPGRE_DEMUX_MODULE 1
#define CONFIG_MEDIA_TUNER_XC5000_MODULE 1
#define CONFIG_NET_POLL_CONTROLLER 1
#define CONFIG_PRINTK 1
#define CONFIG_6LOWPAN_NHC_ROUTING_MODULE 1
#define CONFIG_FB_SYS_FILLRECT 1
#define CONFIG_TIMERFD 1
#define CONFIG_CRYPTO_LIB_CHACHA_GENERIC_MODULE 1
#define CONFIG_HID_THRUSTMASTER_MODULE 1
#define CONFIG_SND_BCM2708_SOC_RPI_PROTO_MODULE 1
#define CONFIG_HD44780_COMMON_MODULE 1
#define CONFIG_DNS_RESOLVER 1
#define CONFIG_GPIO_RASPBERRYPI_EXP 1
#define CONFIG_TRACEPOINTS 1
#define CONFIG_B43_PHY_LP 1
#define CONFIG_MTD_CFI_I2 1
#define CONFIG_CRYPTO_AUTHENC_MODULE 1
#define CONFIG_W1_MASTER_DS2482_MODULE 1
#define CONFIG_NET_EMATCH_STACK 32
#define CONFIG_CARL9170_LEDS 1
#define CONFIG_VIDEO_V4L2_SUBDEV_API 1
#define CONFIG_USB_STORAGE_ENE_UB6250_MODULE 1
#define CONFIG_BRCMFMAC_SDIO 1
#define CONFIG_ARCH_HAS_SYSCALL_WRAPPER 1
#define CONFIG_P54_COMMON_MODULE 1
#define CONFIG_COMPAT_32BIT_TIME 1
#define CONFIG_SECURITY_APPARMOR_HASH 1
#define CONFIG_RTW88_8822BU_MODULE 1
#define CONFIG_SHMEM 1
#define CONFIG_MTD_MODULE 1
#define CONFIG_MIGRATION 1
#define CONFIG_HAVE_ARCH_JUMP_LABEL 1
#define CONFIG_BUILD_SALT ""
#define CONFIG_MMC_BLOCK_MINORS 32
#define CONFIG_F2FS_FS_LZ4 1
#define CONFIG_USB_HSO_MODULE 1
#define CONFIG_HAVE_ARCH_PREL32_RELOCATIONS 1
#define CONFIG_DECOMPRESS_LZMA 1
#define CONFIG_SENSORS_IIO_HWMON_MODULE 1
#define CONFIG_HAVE_KVM_EVENTFD 1
#define CONFIG_DEVTMPFS_MOUNT 1
#define CONFIG_USB_IPHETH_MODULE 1
#define CONFIG_NLS_CODEPAGE_850_MODULE 1
#define CONFIG_DVB_CX22700_MODULE 1
#define CONFIG_HAVE_PREEMPT_DYNAMIC 1
#define CONFIG_DNOTIFY 1
#define CONFIG_CRYPTO_CTS 1
#define CONFIG_AS_HAS_ARMV8_3 1
#define CONFIG_SND_SOC_WM5102_MODULE 1
#define CONFIG_DVB_USB_UMT_010_MODULE 1
#define CONFIG_RTW88_8822C_MODULE 1
#define CONFIG_RTC_DRV_R9701_MODULE 1
#define CONFIG_INPUT_MOUSEDEV 1
#define CONFIG_GENERIC_NET_UTILS 1
#define CONFIG_IPV6_ILA_MODULE 1
#define CONFIG_ATA_MODULE 1
#define CONFIG_SND_SOC_CS42XX8_MODULE 1
#define CONFIG_GPIO_MAX730X_MODULE 1
#define CONFIG_CRYPTO_DES 1
#define CONFIG_USB_ROLE_SWITCH 1
#define CONFIG_GPIOLIB_FASTPATH_LIMIT 512
#define CONFIG_CEPH_LIB_MODULE 1
#define CONFIG_SND_SOC_COMPRESS 1
#define CONFIG_NLS_CODEPAGE_437 1
#define CONFIG_DRM_DISPLAY_CONNECTOR_MODULE 1
#define CONFIG_ARCH_PROC_KCORE_TEXT 1
#define CONFIG_NET_CLS_U32_MODULE 1
#define CONFIG_EXPORTFS 1
#define CONFIG_MTD_UBI_WL_THRESHOLD 4096
#define CONFIG_SND_DACBERRY400_MODULE 1
#define CONFIG_VIDEO_OV64A40_MODULE 1
#define CONFIG_IP6_NF_MATCH_MH_MODULE 1
#define CONFIG_IP_MROUTE_COMMON 1
#define CONFIG_NET_INGRESS 1
#define CONFIG_FB_TFT_ST7789V_MODULE 1
#define CONFIG_DVB_S921_MODULE 1
#define CONFIG_LRU_CACHE_MODULE 1
#define CONFIG_BLK_DEV_INTEGRITY_T10 1
#define CONFIG_HAVE_FUNCTION_ERROR_INJECTION 1
#define CONFIG_ARM64_ERRATUM_1286807 1
#define CONFIG_DVB_AF9013_MODULE 1
#define CONFIG_ARM_GIC 1
#define CONFIG_OLD_SIGSUSPEND3 1
#define CONFIG_SERIO_MODULE 1
#define CONFIG_DVB_USB_DTV5100_MODULE 1
#define CONFIG_SCHEDSTATS 1
#define CONFIG_FB_SYS_IMAGEBLIT 1
#define CONFIG_VIDEO_TVEEPROM_MODULE 1
#define CONFIG_SUNRPC_GSS 1
#define CONFIG_HID_LED_MODULE 1
#define CONFIG_CORE_DUMP_DEFAULT_ELF_HEADERS 1
#define CONFIG_KCMP 1
#define CONFIG_NETCONSOLE_MODULE 1
#define CONFIG_RTC_INTF_SYSFS 1
#define CONFIG_SND_SOC_SPDIF_MODULE 1
#define CONFIG_SENSORS_RP1_ADC_MODULE 1
#define CONFIG_GCC_PLUGINS 1
#define CONFIG_RTC_DRV_RS5C372_MODULE 1
#define CONFIG_NET_EMATCH_U32_MODULE 1
#define CONFIG_CPU_FREQ_GOV_COMMON 1
#define CONFIG_BLK_DEV_INITRD 1
#define CONFIG_USB_EMI62_MODULE 1
#define CONFIG_ARCH_ENABLE_MEMORY_HOTREMOVE 1
#define CONFIG_DM_BUFIO_MODULE 1
#define CONFIG_CAN_GS_USB_MODULE 1
#define CONFIG_SMB_SERVER_MODULE 1
#define CONFIG_BT_ATH3K_MODULE 1
#define CONFIG_PCPU_DEV_REFCNT 1
#define CONFIG_LEDS_TRIGGER_TIMER 1
#define CONFIG_RT2800_LIB_MODULE 1
#define CONFIG_SND_SOC_TLV320AIC3X_MODULE 1
#define CONFIG_DEFAULT_SECURITY_APPARMOR 1
#define CONFIG_SND_BCM2708_SOC_IQAUDIO_DAC_MODULE 1
#define CONFIG_CRYPTO_BLOWFISH_COMMON_MODULE 1
#define CONFIG_BT_INTEL_MODULE 1
#define CONFIG_DVB_USB_DW2102_MODULE 1
#define CONFIG_NF_CONNTRACK_SANE_MODULE 1
#define CONFIG_MMC_SDHCI_IPROC 1
#define CONFIG_GPIO_PCF857X_MODULE 1
#define CONFIG_SND_OSSEMUL 1
#define CONFIG_FB_SYSMEM_HELPERS 1
#define CONFIG_USB_SERIAL_MOS7720_MODULE 1
#define CONFIG_XILLYBUS_MODULE 1
#define CONFIG_SERIAL_DEV_BUS 1
#define CONFIG_PREEMPT_NOTIFIERS 1
#define CONFIG_NF_CT_PROTO_DCCP 1
#define CONFIG_ZLIB_INFLATE 1
#define CONFIG_CRYPTO_ARIA_MODULE 1
#define CONFIG_NET_VENDOR_SYNOPSYS 1
#define CONFIG_DVB_TUA6100_MODULE 1
#define CONFIG_SENSORS_SHTC1_MODULE 1
#define CONFIG_NFT_FLOW_OFFLOAD_MODULE 1
#define CONFIG_BMP280_MODULE 1
#define CONFIG_CRC_T10DIF 1
#define CONFIG_BATMAN_ADV_BATMAN_V 1
#define CONFIG_MEDIA_TUNER_QT1010_MODULE 1
#define CONFIG_DVB_DYNAMIC_MINORS 1
#define CONFIG_SSB_PCIHOST_POSSIBLE 1
#define CONFIG_THERMAL_OF 1
#define CONFIG_RTLWIFI_DEBUG 1
#define CONFIG_HWMON 1
#define CONFIG_RTC_DRV_PCF85063_MODULE 1
#define CONFIG_NET_VENDOR_DLINK 1
#define CONFIG_CRYPTO_TWOFISH_COMMON_MODULE 1
#define CONFIG_AUDITSYSCALL 1
#define CONFIG_LOGO_LINUX_CLUT224 1
#define CONFIG_BT_HCIUART_3WIRE 1
#define CONFIG_USB_PHY 1
#define CONFIG_NLS_ISO8859_2_MODULE 1
#define CONFIG_IP_PNP 1
#define CONFIG_RC_DEVICES 1
#define CONFIG_USB_VIDEO_CLASS_MODULE 1
#define CONFIG_RTC_INTF_PROC 1
#define CONFIG_USB_SERIAL_TI_MODULE 1
#define CONFIG_BCMGENET 1
#define CONFIG_PM_CLK 1
#define CONFIG_USB_CONFIGFS_F_HID 1
#define CONFIG_CMA_SIZE_SEL_MBYTES 1
#define CONFIG_IR_TOY_MODULE 1
#define CONFIG_CRYPTO_SERPENT_MODULE 1
#define CONFIG_DVB_SI2168_MODULE 1
#define CONFIG_CC_IMPLICIT_FALLTHROUGH "-Wimplicit-fallthrough=5"
#define CONFIG_CPU_IDLE_GOV_MENU 1
#define CONFIG_PWM_BCM2835_MODULE 1
#define CONFIG_ARCH_HAS_UBSAN_SANITIZE_ALL 1
#define CONFIG_NF_CONNTRACK_OVS 1
#define CONFIG_FB_TFT_TINYLCD_MODULE 1
#define CONFIG_SECURITY_APPARMOR 1
#define CONFIG_SPI_DW_DMA 1
#define CONFIG_STACKTRACE_SUPPORT 1
#define CONFIG_SERIAL_8250_PCILIB 1
#define CONFIG_DVB_USB_AF9035_MODULE 1
#define CONFIG_MEDIA_CONTROLLER_REQUEST_API 1
#define CONFIG_RESET_CONTROLLER 1
#define CONFIG_RCU_TRACE 1
#define CONFIG_CRYPTO_AES_TI_MODULE 1
#define CONFIG_FB_TFT_HX8340BN_MODULE 1
#define CONFIG_LOCKD 1
#define CONFIG_DM_WRITECACHE_MODULE 1
#define CONFIG_USB_F_FS_MODULE 1
#define CONFIG_DVB_S5H1411_MODULE 1
#define CONFIG_SOUND_OSS_CORE 1
#define CONFIG_CRYPTO_LIB_ARC4_MODULE 1
#define CONFIG_CRYPTO_LIB_AES_MODULE 1
#define CONFIG_RT2800USB_RT35XX 1
#define CONFIG_LIBERTAS_MODULE 1
#define CONFIG_WLAN_VENDOR_RALINK 1
#define CONFIG_USB_GSPCA_TV8532_MODULE 1
#define CONFIG_CRYPTO_KPP2 1
#define CONFIG_LATENCYTOP 1
#define CONFIG_NET_VENDOR_MICROCHIP 1
#define CONFIG_NEED_SG_DMA_FLAGS 1
#define CONFIG_JFFS2_FS_MODULE 1
#define CONFIG_FUNCTION_ALIGNMENT 8
#define CONFIG_NFT_REJECT_IPV6_MODULE 1
#define CONFIG_SND_SOC_MA120X0P_MODULE 1
#define CONFIG_BT_RFCOMM_TTY 1
#define CONFIG_ARM64_ERRATUM_2658417 1
#define CONFIG_NET_UDP_TUNNEL_MODULE 1
#define CONFIG_RPCSEC_GSS_KRB5 1
#define CONFIG_CRYPTO_ECC_MODULE 1
#define CONFIG_NO_HZ_IDLE 1
#define CONFIG_SND_SOC_CS4271_I2C_MODULE 1
#define CONFIG_NET_VENDOR_ADAPTEC 1
#define CONFIG_CFG80211_REQUIRE_SIGNED_REGDB 1
#define CONFIG_DVB_STV0299_MODULE 1
#define CONFIG_ARCH_BINFMT_ELF_EXTRA_PHDRS 1
#define CONFIG_SSB_B43_PCI_BRIDGE 1
#define CONFIG_USB_AN2720 1
#define CONFIG_F2FS_STAT_FS 1
#define CONFIG_BSD_PROCESS_ACCT 1
#define CONFIG_NETFILTER_XT_MATCH_STRING_MODULE 1
#define CONFIG_SSB_DRIVER_PCICORE 1
#define CONFIG_SOCK_RX_QUEUE_MAPPING 1
#define CONFIG_MEDIA_TUNER_MAX2165_MODULE 1
#define CONFIG_MDIO_MODULE 1
#define CONFIG_MPTCP 1
#define CONFIG_CRYPTO_DRBG_HMAC 1
#define CONFIG_DRM_BRIDGE 1
#define CONFIG_FB_DEVICE 1
#define CONFIG_USB_F_SERIAL_MODULE 1
#define CONFIG_USB_G_MULTI_RNDIS 1
#define CONFIG_LOGO 1
#define CONFIG_NET_VENDOR_SILAN 1
#define CONFIG_SENSORS_PWM_FAN_MODULE 1
#define CONFIG_SND_SOC_MAX98357A_MODULE 1
#define CONFIG_DLM_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_BPF_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_GOTOP 1
#define CONFIG_ARCH_SUPPORTS_PER_VMA_LOCK 1
#define CONFIG_BT_6LOWPAN_MODULE 1
#define CONFIG_USB_STORAGE 1
#define CONFIG_NET_VENDOR_BROADCOM 1
#define CONFIG_DVB_USB_PCTV452E_MODULE 1
#define CONFIG_NETFILTER_SKIP_EGRESS 1
#define CONFIG_JOYSTICK_PSXPAD_SPI_FF 1
#define CONFIG_DVB_VES1820_MODULE 1
#define CONFIG_GENERIC_CPU_AUTOPROBE 1
#define CONFIG_STANDALONE 1
#define CONFIG_BOSCH_BNO055_MODULE 1
#define CONFIG_BAYCOM_SER_HDX_MODULE 1
#define CONFIG_CRYPTO_SEED_MODULE 1
#define CONFIG_ARM_GIC_V2M 1
#define CONFIG_CPU_FREQ_GOV_PERFORMANCE 1
#define CONFIG_EFI 1
#define CONFIG_RATIONAL 1
#define CONFIG_I2C_MUX_MODULE 1
#define CONFIG_SATA_MV_MODULE 1
#define CONFIG_DVB_TS2020_MODULE 1
#define CONFIG_WLAN_VENDOR_INTEL 1
#define CONFIG_ARM64_LSE_ATOMICS 1
#define CONFIG_SYSTEM_TRUSTED_KEYRING 1
#define CONFIG_MEDIA_TUNER_QM1D1C0042_MODULE 1
#define CONFIG_WATCHDOG_CORE 1
#define CONFIG_GENERIC_EARLY_IOREMAP 1
#define CONFIG_DVB_TUNER_DIB0090_MODULE 1
#define CONFIG_SND_USB_AUDIO_MODULE 1
#define CONFIG_VIDEO_CX231XX_MODULE 1
#define CONFIG_NVME_HWMON 1
#define CONFIG_VIDEO_IMX290_MODULE 1
#define CONFIG_NET_VENDOR_WANGXUN 1
#define CONFIG_NET_L3_MASTER_DEV 1
#define CONFIG_IEEE802154_MODULE 1
#define CONFIG_AMPERE_ERRATUM_AC03_CPU_38 1
#define CONFIG_VIDEO_RASPBERRYPI_PISP_BE_MODULE 1
#define CONFIG_VMAP_STACK 1
#define CONFIG_BLOCK 1
#define CONFIG_IP_VS_LC_MODULE 1
#define CONFIG_ARCH_STACKWALK 1
#define CONFIG_HID_APPLE_MODULE 1
#define CONFIG_SND_BCM2708_SOC_HIFIBERRY_DACPLUS_MODULE 1
#define CONFIG_DVB_DIB9000_MODULE 1
#define CONFIG_MEDIA_TUNER_TDA827X_MODULE 1
#define CONFIG_INIT_ENV_ARG_LIMIT 32
#define CONFIG_IP_NF_ARP_MANGLE_MODULE 1
#define CONFIG_DVB_USB_MODULE 1
#define CONFIG_FB_TFT_SSD1306_MODULE 1
#define CONFIG_P54_LEDS 1
#define CONFIG_F2FS_FS_LZORLE 1
#define CONFIG_DVB_ATBM8830_MODULE 1
#define CONFIG_ROOT_NFS 1
#define CONFIG_EXFAT_FS_MODULE 1
#define CONFIG_AF_UNIX_OOB 1
#define CONFIG_USER_NS 1
#define CONFIG_ARCH_WANT_BATCHED_UNMAP_TLB_FLUSH 1
#define CONFIG_CRYPTO_USER_MODULE 1
#define CONFIG_NF_CONNTRACK_PPTP_MODULE 1
#define CONFIG_DVB_ZL10036_MODULE 1
#define CONFIG_VIDEO_CX231XX_ALSA_MODULE 1
#define CONFIG_HFSPLUS_FS_MODULE 1
#define CONFIG_TMPFS_POSIX_ACL 1
#define CONFIG_STRICT_KERNEL_RWX 1
#define CONFIG_HAVE_ARCH_KCSAN 1
#define CONFIG_SND_USB_UA101_MODULE 1
#define CONFIG_NETLINK_DIAG_MODULE 1
#define CONFIG_BUG 1
#define CONFIG_CONTEXT_SWITCH_TRACER 1
#define CONFIG_MAC80211_HAS_RC 1
#define CONFIG_BATMAN_ADV_BLA 1
#define CONFIG_KDB_KEYBOARD 1
#define CONFIG_LOGIWHEELS_FF 1
#define CONFIG_ARCH_HAS_DEBUG_WX 1
#define CONFIG_OF_OVERLAY 1
#define CONFIG_OCFS2_FS_O2CB_MODULE 1
#define CONFIG_ARM64_VA_BITS_48 1
#define CONFIG_VIDEO_DW9807_VCM_MODULE 1
#define CONFIG_CRYPTO_CAST6_MODULE 1
#define CONFIG_6LOWPAN_NHC_UDP_MODULE 1
#define CONFIG_NET_EMATCH_META_MODULE 1
#define CONFIG_ARCH_HAS_MEMBARRIER_SYNC_CORE 1
#define CONFIG_PM 1
#define CONFIG_PPS 1
#define CONFIG_NETFILTER_XTABLES_COMPAT 1
#define CONFIG_LEDS_TRIGGER_PATTERN_MODULE 1
#define CONFIG_USB_LCD_MODULE 1
#define CONFIG_MEMCG 1
#define CONFIG_SPI 1
#define CONFIG_RTC_SYSTOHC_DEVICE "rtc0"
#define CONFIG_HAVE_KVM_CPU_RELAX_INTERCEPT 1
#define CONFIG_NFT_HASH_MODULE 1
#define CONFIG_NF_CONNTRACK_IRC_MODULE 1
#define CONFIG_SENSORS_GPIO_FAN_MODULE 1
#define CONFIG_L2TP_IP_MODULE 1
#define CONFIG_OF_IRQ 1
#define CONFIG_LIBFDT 1
#define CONFIG_RPCSEC_GSS_KRB5_ENCTYPES_AES_SHA1 1
#define CONFIG_USB_STV06XX_MODULE 1
#define CONFIG_WLAN_VENDOR_PURELIFI 1
#define CONFIG_PPP_DEFLATE_MODULE 1
#define CONFIG_NTFS_RW 1
#define CONFIG_GPIO_BRCMSTB 1
#define CONFIG_TEXTSEARCH_KMP_MODULE 1
#define CONFIG_IO_URING 1
#define CONFIG_MAX31856_MODULE 1
#define CONFIG_CRYPTO_CRC64_ROCKSOFT 1
#define CONFIG_W1_SLAVE_SMEM_MODULE 1
#define CONFIG_VT 1
#define CONFIG_USB_NET_NET1080_MODULE 1
#define CONFIG_DMABUF_HEAPS 1
#define CONFIG_SECRETMEM 1
#define CONFIG_DTC 1
#define CONFIG_NETFILTER_XT_TARGET_CLASSIFY_MODULE 1
#define CONFIG_INET6_ESP_OFFLOAD_MODULE 1
#define CONFIG_CCS811_MODULE 1
#define CONFIG_F2FS_FS_SECURITY 1
#define CONFIG_USB_NET_AQC111_MODULE 1
#define CONFIG_MACB 1
#define CONFIG_REGMAP_SPI_MODULE 1
#define CONFIG_SND_BCM2708_SOC_HIFIBERRY_AMP_MODULE 1
#define CONFIG_BT_BREDR 1
#define CONFIG_WATCHDOG_HANDLE_BOOT_ENABLED 1
#define CONFIG_SPLIT_PTLOCK_CPUS 4
#define CONFIG_SBITMAP 1
#define CONFIG_DVB_TUNER_ITD1000_MODULE 1
#define CONFIG_POWER_SUPPLY 1
#define CONFIG_DM_PERSISTENT_DATA_MODULE 1
#define CONFIG_SND_BCM2708_SOC_JUSTBOOM_DAC_MODULE 1
#define CONFIG_SCTP_COOKIE_HMAC_MD5 1
#define CONFIG_CIFS_XATTR 1
#define CONFIG_CRYPTO_ZSTD_MODULE 1
#define CONFIG_SND_DMAENGINE_PCM_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_NFQUEUE_MODULE 1
#define CONFIG_CAN_8DEV_USB_MODULE 1
#define CONFIG_WEXT_CORE 1
#define CONFIG_I2C_DESIGNWARE_CORE_MODULE 1
#define CONFIG_USB_GSPCA_MR97310A_MODULE 1
#define CONFIG_GENERIC_IRQ_CHIP 1
#define CONFIG_AS_HAS_ARMV8_4 1
#define CONFIG_ROCKCHIP_ERRATUM_3588001 1
#define CONFIG_CRYPTO_SKCIPHER2 1
#define CONFIG_VIDEO_WM8775_MODULE 1
#define CONFIG_NLS 1
#define CONFIG_ARCH_WANTS_NO_INSTR 1
#define CONFIG_MFD_ARIZONA_MODULE 1
#define CONFIG_IP_SET_HASH_IPPORTNET_MODULE 1
#define CONFIG_SCHED_AUTOGROUP 1
#define CONFIG_SPI_SPIDEV_MODULE 1
#define CONFIG_AS_IS_GNU 1
#define CONFIG_MEDIA_CAMERA_SUPPORT 1
#define CONFIG_PRISM2_USB_MODULE 1
#define CONFIG_ARM64_PAN 1
#define CONFIG_FB_TFT_ILI9325_MODULE 1
#define CONFIG_HID_MAGICMOUSE_MODULE 1
#define CONFIG_SND_SOC_AK4554_MODULE 1
#define CONFIG_I2C_GPIO_MODULE 1
#define CONFIG_INET_UDP_DIAG_MODULE 1
#define CONFIG_MEDIA_SDR_SUPPORT 1
#define CONFIG_USB_CONFIGFS_ACM 1
#define CONFIG_CGROUP_BPF 1
#define CONFIG_DVB_USB_ZD1301_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_ETURBO 1
#define CONFIG_PPPOE_MODULE 1
#define CONFIG_XFRM_MIGRATE 1
#define CONFIG_ZONE_DMA 1
#define CONFIG_USB_GSPCA_SPCA508_MODULE 1
#define CONFIG_USB_LEGOTOWER_MODULE 1
#define CONFIG_I2C_ROBOTFUZZ_OSIF_MODULE 1
#define CONFIG_DVB_DRX39XYJ_MODULE 1
#define CONFIG_DRM_V3D_MODULE 1
#define CONFIG_DVB_USB_DIBUSB_MC_MODULE 1
#define CONFIG_DVB_USB_VP702X_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_OWNER_MODULE 1
#define CONFIG_SND_SEQ_DEVICE_MODULE 1
#define CONFIG_IP_NF_TARGET_ECN_MODULE 1
#define CONFIG_SYN_COOKIES 1
#define CONFIG_REED_SOLOMON_DEC8 1
#define CONFIG_IRQ_WORK 1
#define CONFIG_ATH9K_MODULE 1
#define CONFIG_PCI_MSI 1
#define CONFIG_IP_ADVANCED_ROUTER 1
#define CONFIG_ARCH_SUPPORTS_SHADOW_CALL_STACK 1
#define CONFIG_FB_SYS_COPYAREA 1
#define CONFIG_HAVE_ARCH_RANDOMIZE_KSTACK_OFFSET 1
#define CONFIG_HTU21_MODULE 1
#define CONFIG_SPI_BITBANG_MODULE 1
#define CONFIG_MEDIA_TUNER_MT2063_MODULE 1
#define CONFIG_USB_STORAGE_ALAUDA_MODULE 1
#define CONFIG_SPARSEMEM_EXTREME 1
#define CONFIG_CC_HAS_BRANCH_PROT_PAC_RET_BTI 1
#define CONFIG_W1_SLAVE_DS2406_MODULE 1
#define CONFIG_USB_COMMON 1
#define CONFIG_CYPRESS_FIRMWARE_MODULE 1
#define CONFIG_TASK_XACCT 1
#define CONFIG_DRM_DISPLAY_HDMI_HELPER 1
#define CONFIG_MEDIA_TUNER_TDA18271_MODULE 1
#define CONFIG_IP_SET_BITMAP_PORT_MODULE 1
#define CONFIG_IP6_NF_IPTABLES_MODULE 1
#define CONFIG_LZ4_COMPRESS 1
#define CONFIG_KVM_VFIO 1
#define CONFIG_QFMT_V1_MODULE 1
#define CONFIG_DVB_IX2505V_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_ZYTRONIC 1
#define CONFIG_DEBUG_INFO_NONE 1
#define CONFIG_FIXED_PHY 1
#define CONFIG_DVB_SP2_MODULE 1
#define CONFIG_SENSORS_SHT4x_MODULE 1
#define CONFIG_SND_BCM2708_SOC_IQAUDIO_DIGI_MODULE 1
#define CONFIG_CPU_FREQ_GOV_USERSPACE 1
#define CONFIG_LOG_CPU_MAX_BUF_SHIFT 12
#define CONFIG_VIDEO_ARDUCAM_64MP_MODULE 1
#define CONFIG_NF_DUP_IPV4_MODULE 1
#define CONFIG_BLK_DEV_DM_BUILTIN 1
#define CONFIG_HW_RANDOM_CN10K 1
#define CONFIG_USB_SERIAL_IPW_MODULE 1
#define CONFIG_INET_IPCOMP_MODULE 1
#define CONFIG_ARM64_LD_HAS_FIX_ERRATUM_843419 1
#define CONFIG_TASKS_RCU 1
#define CONFIG_DVB_USB_DIB0700_MODULE 1
#define CONFIG_VGA_ARB_MAX_GPUS 16
#define CONFIG_GENERIC_PINCONF 1
#define CONFIG_CAN_PEAK_USB_MODULE 1
#define CONFIG_ARM_ARCH_TIMER 1
#define CONFIG_XILLYBUS_PCIE_MODULE 1
#define CONFIG_EVENT_TRACING 1
#define CONFIG_ARCH_HAS_NMI_SAFE_THIS_CPU_OPS 1
#define CONFIG_ASYNC_PQ_MODULE 1
#define CONFIG_HID_KEYTOUCH_MODULE 1
#define CONFIG_HID_CYPRESS_MODULE 1
#define CONFIG_NFS_V4_2_SSC_HELPER 1
#define CONFIG_SG_POOL 1
#define CONFIG_BRIDGE_EBT_LIMIT_MODULE 1
#define CONFIG_DRM_KMS_HELPER_MODULE 1
#define CONFIG_NET_VENDOR_PACKET_ENGINES 1
#define CONFIG_DRM_PANEL_RASPBERRYPI_TOUCHSCREEN_MODULE 1
#define CONFIG_DMA_COHERENT_POOL 1
#define CONFIG_NF_SOCKET_IPV6_MODULE 1
#define CONFIG_OCFS2_FS_USERSPACE_CLUSTER_MODULE 1
#define CONFIG_MMC_SDHCI_OF_DWCMSHC_MODULE 1
#define CONFIG_ATA_OVER_ETH_MODULE 1
#define CONFIG_BLK_MQ_PCI 1
#define CONFIG_USB_NET_PLUSB_MODULE 1
#define CONFIG_VIDEO_SAA711X_MODULE 1
#define CONFIG_RTL8192C_COMMON_MODULE 1
#define CONFIG_CRYPTO_LIB_CURVE25519_MODULE 1
#define CONFIG_NLS_ISO8859_1_MODULE 1
#define CONFIG_LRU_GEN 1
#define CONFIG_NFC_MODULE 1
#define CONFIG_CIFS_FSCACHE 1
#define CONFIG_R8169_MODULE 1
#define CONFIG_MAX30102_MODULE 1
#define CONFIG_MMC_CQHCI 1
#define CONFIG_HID_KENSINGTON_MODULE 1
#define CONFIG_SMB_SERVER_KERBEROS5 1
#define CONFIG_BATTERY_DS2760_MODULE 1
#define CONFIG_SND_SOC_ADAU1977_MODULE 1
#define CONFIG_TEXTSEARCH_BM_MODULE 1
#define CONFIG_FS_IOMAP 1
#define CONFIG_JFS_SECURITY 1
#define CONFIG_SND_SOC_TLV320AIC32X4_I2C_MODULE 1
#define CONFIG_NF_CONNTRACK_PROCFS 1
#define CONFIG_MFD_SIMPLE_MFD_I2C_MODULE 1
#define CONFIG_HID_ZYDACRON_MODULE 1
#define CONFIG_PPP_MPPE_MODULE 1
#define CONFIG_CAN_CALC_BITTIMING 1
#define CONFIG_SND_PCM_OSS_MODULE 1
#define CONFIG_DVB_B2C2_FLEXCOP_MODULE 1
#define CONFIG_COMPACT_UNEVICTABLE_DEFAULT 1
#define CONFIG_RD_ZSTD 1
#define CONFIG_USB_NET_SR9700_MODULE 1
#define CONFIG_SND_SOC_WM8960_MODULE 1
#define CONFIG_ARCH_BRCMSTB 1
#define CONFIG_RFKILL_MODULE 1
#define CONFIG_VIDEO_TVP5150_MODULE 1
#define CONFIG_MEDIA_TUNER_FC0012_MODULE 1
#define CONFIG_NETDEVICES 1
#define CONFIG_NET_KEY_MODULE 1
#define CONFIG_VIDEO_ADV7180_MODULE 1
#define CONFIG_SMS_SIANO_MDTV_MODULE 1
#define CONFIG_IP6_NF_TARGET_HL_MODULE 1
#define CONFIG_NETFILTER_CONNCOUNT_MODULE 1
#define CONFIG_ARCH_HAS_KCOV 1
#define CONFIG_CGROUP_FREEZER 1
#define CONFIG_HAVE_ARCH_STACKLEAK 1
#define CONFIG_EVENTFD 1
#define CONFIG_SPI_DESIGNWARE_MODULE 1
#define CONFIG_FS_POSIX_ACL 1
#define CONFIG_IPV6_SIT_MODULE 1
#define CONFIG_XFRM 1
#define CONFIG_USB_F_UAC2_MODULE 1
#define CONFIG_BCM2835_POWER 1
#define CONFIG_LINEAR_RANGES 1
#define CONFIG_IP_SET_HASH_IP_MODULE 1
#define CONFIG_TINYDRM_ST7586_MODULE 1
#define CONFIG_AS_HAS_LDAPR 1
#define CONFIG_USB_MR800_MODULE 1
#define CONFIG_SERIAL_8250_CONSOLE 1
#define CONFIG_IPV6_MULTIPLE_TABLES 1
#define CONFIG_USB_ANNOUNCE_NEW_DEVICES 1
#define CONFIG_CRYPTO_GENIV_MODULE 1
#define CONFIG_USB_SERIAL_WHITEHEAT_MODULE 1
#define CONFIG_NET_CLS_ROUTE4_MODULE 1
#define CONFIG_JUMP_LABEL 1
#define CONFIG_NTFS3_FS_MODULE 1
#define CONFIG_ARCH_HAS_TEARDOWN_DMA_OPS 1
#define CONFIG_OVERLAY_FS_MODULE 1
#define CONFIG_IP_SET_HASH_NETPORT_MODULE 1
#define CONFIG_CIFS_ALLOW_INSECURE_LEGACY 1
#define CONFIG_ATH9K_HTC_MODULE 1
#define CONFIG_IP_VS_DH_MODULE 1
#define CONFIG_AX25_DAMA_SLAVE 1
#define CONFIG_RADIO_WL128X_MODULE 1
#define CONFIG_PPPOE_HASH_BITS_4 1
#define CONFIG_IP_NF_TARGET_MASQUERADE_MODULE 1
#define CONFIG_SND_SOC_AD193X_I2C_MODULE 1
#define CONFIG_HAVE_EBPF_JIT 1
#define CONFIG_NF_CONNTRACK_BROADCAST_MODULE 1
#define CONFIG_ECRYPT_FS_MODULE 1
#define CONFIG_NFT_FWD_NETDEV_MODULE 1
#define CONFIG_CRYPTO_LZ4_MODULE 1
#define CONFIG_PROC_PAGE_MONITOR 1
#define CONFIG_USB_CONFIGFS_ECM 1
#define CONFIG_SERIAL_8250_EXTENDED 1
#define CONFIG_NETFILTER_XT_TARGET_MASQUERADE_MODULE 1
#define CONFIG_IGB_HWMON 1
#define CONFIG_DM_CACHE_MODULE 1
#define CONFIG_MEDIA_TUNER_R820T_MODULE 1
#define CONFIG_MTD_SPI_NOR_USE_4K_SECTORS 1
#define CONFIG_BPF 1
#define CONFIG_9P_FS_POSIX_ACL 1
#define CONFIG_SND_BCM2708_SOC_ALLO_PIANO_DAC_PLUS_MODULE 1
#define CONFIG_USB_VIDEO_CLASS_INPUT_EVDEV 1
#define CONFIG_CRYPTO_AES_ARM64_CE_CCM_MODULE 1
#define CONFIG_REGULATOR_RASPBERRYPI_TOUCHSCREEN_ATTINY_MODULE 1
#define CONFIG_VIDEO_MUX_MODULE 1
#define CONFIG_DM_DELAY_MODULE 1
#define CONFIG_USB_SERIAL_CH341_MODULE 1
#define CONFIG_BCMASP 1
#define CONFIG_RD_LZO 1
#define CONFIG_USB_RAINSHADOW_CEC_MODULE 1
#define CONFIG_IP_SET_HASH_IPPORT_MODULE 1
#define CONFIG_VCHIQ_CDEV 1
#define CONFIG_KPROBE_EVENTS 1
#define CONFIG_SENSORS_SHT21_MODULE 1
#define CONFIG_USB_IOWARRIOR_MODULE 1
#define CONFIG_USB_EZUSB_FX2_MODULE 1
#define CONFIG_SND_USB_TONEPORT_MODULE 1
#define CONFIG_F2FS_FS_ZSTD 1
#define CONFIG_RTL8XXXU_MODULE 1
#define CONFIG_HAVE_FUNCTION_GRAPH_RETVAL 1
#define CONFIG_DRM_PANEL_JDI_LT070ME05000_MODULE 1
#define CONFIG_ARM64_RAS_EXTN 1
#define CONFIG_VIDEO_OV7640_MODULE 1
#define CONFIG_CRYPTO_SHA512 1
#define CONFIG_CAN_ISOTP_MODULE 1
#define CONFIG_BACKLIGHT_CLASS_DEVICE_MODULE 1
#define CONFIG_CC_HAS_ASM_INLINE 1
#define CONFIG_B43_HWRNG 1
#define CONFIG_VHOST_MODULE 1
#define CONFIG_MTD_OF_PARTS_MODULE 1
#define CONFIG_USB_M5602_MODULE 1
#define CONFIG_RT2X00_LIB_USB_MODULE 1
#define CONFIG_OF_RESOLVE 1
#define CONFIG_CRYPTO_NULL_MODULE 1
#define CONFIG_DVB_USB_AF9005_REMOTE_MODULE 1
#define CONFIG_GPIO_CDEV_V1 1
#define CONFIG_B43_PHY_G 1
#define CONFIG_NET_VENDOR_SEEQ 1
#define CONFIG_NF_DEFRAG_IPV4_MODULE 1
#define CONFIG_USB_IDMOUSE_MODULE 1
#define CONFIG_HID_LCPOWER_MODULE 1
#define CONFIG_ARCH_HAS_RELR 1
#define CONFIG_FS_ENCRYPTION 1
#define CONFIG_PM_DEBUG 1
#define CONFIG_VIDEO_TW9906_MODULE 1
#define CONFIG_IPV6_ROUTE_INFO 1
#define CONFIG_ARCH_FORCE_MAX_ORDER 10
#define CONFIG_NETFILTER_ADVANCED 1
#define CONFIG_CRYPTO_DEFLATE_MODULE 1
#define CONFIG_GENERIC_STRNLEN_USER 1
#define CONFIG_ARM64_TAGGED_ADDR_ABI 1
#define CONFIG_NFT_DUP_NETDEV_MODULE 1
#define CONFIG_USB_APPLEDISPLAY_MODULE 1
#define CONFIG_USB_SERIAL_KLSI_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_TCPMSS_MODULE 1
#define CONFIG_IGB_MODULE 1
#define CONFIG_MFD_RP1 1
#define CONFIG_SND_SOC_AD193X_SPI_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_IPCOMP_MODULE 1
#define CONFIG_IPV6_ROUTER_PREF 1
#define CONFIG_MITIGATE_SPECTRE_BRANCH_HISTORY 1
#define CONFIG_JFFS2_FS_DEBUG 0
#define CONFIG_SND_AUDIOINJECTOR_ISOLATED_SOUNDCARD_MODULE 1
#define CONFIG_WLAN_VENDOR_RSI 1
#define CONFIG_SLIP_COMPRESSED 1
#define CONFIG_CRYPTO_JITTERENTROPY 1
#define CONFIG_JOYSTICK_PSXPAD_SPI_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_L2TP_MODULE 1
#define CONFIG_DVB_MXL692_MODULE 1
#define CONFIG_BT_HCIUART_SERDEV 1
#define CONFIG_CRYPTO_GCM_MODULE 1
#define CONFIG_NETFILTER_NETLINK_LOG_MODULE 1
#define CONFIG_HAVE_DYNAMIC_FTRACE 1
#define CONFIG_CDROM_MODULE 1
#define CONFIG_NLS_ISO8859_14_MODULE 1
#define CONFIG_ARM64_SME 1
#define CONFIG_MAGIC_SYSRQ 1
#define CONFIG_QCOM_FALKOR_ERRATUM_1009 1
#define CONFIG_USB_CONFIGFS_F_FS 1
#define CONFIG_DMI 1
#define CONFIG_IPV6_SIT_6RD 1
#define CONFIG_ARM64_ERRATUM_845719 1
#define CONFIG_CRYPTO_KPP 1
#define CONFIG_PNFS_BLOCK_MODULE 1
#define CONFIG_NET_VENDOR_RDC 1
#define CONFIG_PGTABLE_LEVELS 4
#define CONFIG_CPUSETS 1
#define CONFIG_NETFILTER_XT_MATCH_MARK_MODULE 1
#define CONFIG_VIDEO_PVRUSB2_SYSFS 1
#define CONFIG_FUNCTION_PROFILER 1
#define CONFIG_SMBFS_MODULE 1
#define CONFIG_MAC80211_RC_DEFAULT_MINSTREL 1
#define CONFIG_SPARSE_IRQ 1
#define CONFIG_DVB_LGS8GXX_MODULE 1
#define CONFIG_XILLYUSB_MODULE 1
#define CONFIG_NET_SCH_MQPRIO_LIB_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_TCPOPTSTRIP_MODULE 1
#define CONFIG_ARM64_ERRATUM_1508412 1
#define CONFIG_IP_NF_MANGLE_MODULE 1
#define CONFIG_PINCTRL_RP1 1
#define CONFIG_USB_MASS_STORAGE_MODULE 1
#define CONFIG_DVB_VES1X93_MODULE 1
#define CONFIG_FB_TFT_ILI9341_MODULE 1
#define CONFIG_DRM_UDL_MODULE 1
#define CONFIG_SECURITYFS 1
#define CONFIG_ARM64_ERRATUM_2067961 1
#define CONFIG_RCU_STALL_COMMON 1
#define CONFIG_BT_DEBUGFS 1
#define CONFIG_BRIDGE_EBT_VLAN_MODULE 1
#define CONFIG_PCIEPORTBUS 1
#define CONFIG_MEDIA_SUPPORT_MODULE 1
#define CONFIG_NFT_FIB_IPV6_MODULE 1
#define CONFIG_DEBUG_BUGVERBOSE 1
#define CONFIG_EFI_GENERIC_STUB 1
#define CONFIG_IP_NF_FILTER_MODULE 1
#define CONFIG_HID_ZEROPLUS_MODULE 1
#define CONFIG_SND_AUDIOINJECTOR_PI_SOUNDCARD_MODULE 1
#define CONFIG_DM_INTEGRITY_MODULE 1
#define CONFIG_MAC802154_MODULE 1
#define CONFIG_ARM64_PTR_AUTH 1
#define CONFIG_NETFILTER_XT_MATCH_LENGTH_MODULE 1
#define CONFIG_BRIDGE_EBT_PKTTYPE_MODULE 1
#define CONFIG_MODULES_TREE_LOOKUP 1
#define CONFIG_FAT_FS 1
#define CONFIG_CRYPTO_SIG 1
#define CONFIG_BLK_DEBUG_FS_ZONED 1
#define CONFIG_TEXTSEARCH_FSM_MODULE 1
#define CONFIG_SND_BCM2835_MODULE 1
#define CONFIG_SENSORS_LM75_MODULE 1
#define CONFIG_ARM64_ERRATUM_832075 1
#define CONFIG_DVB_STV0910_MODULE 1
#define CONFIG_IP6_NF_RAW_MODULE 1
#define CONFIG_BUILDTIME_TABLE_SORT 1
#define CONFIG_SPEAKUP_SYNTH_SOFT_MODULE 1
#define CONFIG_DVB_USB_EC168_MODULE 1
#define CONFIG_USB_ZD1201_MODULE 1
#define CONFIG_NVMEM 1
#define CONFIG_INET_TUNNEL_MODULE 1
#define CONFIG_NF_LOG_ARP_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_NOTRACK_MODULE 1
#define CONFIG_MT76x0_COMMON_MODULE 1
#define CONFIG_EEPROM_93CX6_MODULE 1
#define CONFIG_PINCONF 1
#define CONFIG_BLOCK_HOLDER_DEPRECATED 1
#define CONFIG_DRM_PANEL_WAVESHARE_TOUCHSCREEN_MODULE 1
#define CONFIG_GENERIC_CLOCKEVENTS 1
#define CONFIG_OID_REGISTRY 1
#define CONFIG_DVB_USB_DTT200U_MODULE 1
#define CONFIG_CIFS_UPCALL 1
#define CONFIG_RADIO_TEA575X_MODULE 1
#define CONFIG_LIB80211_MODULE 1
#define CONFIG_MEDIA_CEC_SUPPORT 1
#define CONFIG_MFD_CORE 1
#define CONFIG_SCTP_DEFAULT_COOKIE_HMAC_MD5 1
#define CONFIG_USB_CXACRU_MODULE 1
#define CONFIG_SERIAL_AMBA_PL011 1
#define CONFIG_CAN_NETLINK 1
#define CONFIG_RFKILL_LEDS 1
#define CONFIG_BT_HCIBTUSB_BCM 1
#define CONFIG_CONSOLE_TRANSLATIONS 1
#define CONFIG_ARCH_SUPPORTS_ATOMIC_RMW 1
#define CONFIG_GENERIC_LIB_DEVMEM_IS_ALLOWED 1
#define CONFIG_USB_F_UVC_MODULE 1
#define CONFIG_RAID6_PQ 1
#define CONFIG_NET_IPGRE_MODULE 1
#define CONFIG_LIBERTAS_SDIO_MODULE 1
#define CONFIG_TINYDRM_ST7735R_MODULE 1
#define CONFIG_BRIDGE_EBT_IP6_MODULE 1
#define CONFIG_CRYPTO_AES_ARM64_CE_MODULE 1
#define CONFIG_NF_NAT_SNMP_BASIC_MODULE 1
#define CONFIG_NFT_FIB_NETDEV_MODULE 1
#define CONFIG_SERIAL_EARLYCON 1
#define CONFIG_CLS_U32_MARK 1
#define CONFIG_DVB_CX24120_MODULE 1
#define CONFIG_NET_VENDOR_NI 1
#define CONFIG_SND_SOC_ARIZONA_MODULE 1
#define CONFIG_GENERIC_IRQ_INJECTION 1
#define CONFIG_CC_HAS_KASAN_SW_TAGS 1
#define CONFIG_CRYPTO_AKCIPHER 1
#define CONFIG_SND_SOC_SIGMADSP_I2C_MODULE 1
#define CONFIG_ETHTOOL_NETLINK 1
#define CONFIG_LEDS_TRIGGER_BACKLIGHT 1
#define CONFIG_CPU_FREQ 1
#define CONFIG_ARCH_SUPPORTS_KEXEC_FILE 1
#define CONFIG_USB_GSPCA_MODULE 1
#define CONFIG_DM_MIRROR_MODULE 1
#define CONFIG_CRYPTO_BLOWFISH_MODULE 1
#define CONFIG_DUMMY_CONSOLE 1
#define CONFIG_SERIAL_AMBA_PL011_CONSOLE 1
#define CONFIG_USB_PCI 1
#define CONFIG_I2C_BCM2708_BAUDRATE 100000
#define CONFIG_NLS_ASCII 1
#define CONFIG_USB_G_PRINTER_MODULE 1
#define CONFIG_B43_MODULE 1
#define CONFIG_BAYCOM_SER_FDX_MODULE 1
#define CONFIG_NF_REJECT_IPV4_MODULE 1
#define CONFIG_RTC_DRV_M41T94_MODULE 1
#define CONFIG_GENERIC_IOREMAP 1
#define CONFIG_ARCH_MMAP_RND_BITS_MAX 33
#define CONFIG_USB_LAN78XX 1
#define CONFIG_NFT_CONNLIMIT_MODULE 1
#define CONFIG_BPF_EVENTS 1
#define CONFIG_CRYPTO_NHPOLY1305_MODULE 1
#define CONFIG_HAVE_ARCH_TRANSPARENT_HUGEPAGE 1
#define CONFIG_BACKLIGHT_GPIO_MODULE 1
#define CONFIG_6LOWPAN_NHC_MOBILITY_MODULE 1
#define CONFIG_IEEE802154_MRF24J40_MODULE 1
#define CONFIG_TRACE_IRQFLAGS_SUPPORT 1
#define CONFIG_MTD_NAND_CORE_MODULE 1
#define CONFIG_MFD_SYSCON 1
#define CONFIG_NFS_V3_ACL 1
#define CONFIG_BCM2708_VCMEM 1
#define CONFIG_CHARGER_GPIO_MODULE 1
#define CONFIG_SND_BCM2708_SOC_DIONAUDIO_LOCO_V2_MODULE 1
#define CONFIG_NFT_NUMGEN_MODULE 1
#define CONFIG_DETECT_HUNG_TASK 1
#define CONFIG_CRYPTO_AES_ARM64_NEON_BLK_MODULE 1
#define CONFIG_CAN_MCP251X_MODULE 1
#define CONFIG_CRYPTO_CCM_MODULE 1
#define CONFIG_TCP_CONG_ADVANCED 1
#define CONFIG_USB_NET_CDC_SUBSET_MODULE 1
#define CONFIG_ARM_PMUV3 1
#define CONFIG_BT_RTL_MODULE 1
#define CONFIG_VIDEO_VIMC_MODULE 1
#define CONFIG_QFMT_V2_MODULE 1
#define CONFIG_ARM64_ERRATUM_824069 1
#define CONFIG_USB_S2255_MODULE 1
#define CONFIG_TAP_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_CONNMARK_MODULE 1
#define CONFIG_ATH9K_HW_MODULE 1
#define CONFIG_BLK_CGROUP 1
#define CONFIG_USB_SERIAL_MCT_U232_MODULE 1
#define CONFIG_PCIE_BUS_DEFAULT 1
#define CONFIG_UIO_PDRV_GENIRQ_MODULE 1
#define CONFIG_LEDS_TRIGGERS 1
#define CONFIG_NET_FOU_MODULE 1
#define CONFIG_CRYPTO_RNG 1
#define CONFIG_USB_SERIAL_GARMIN_MODULE 1
#define CONFIG_W1_MASTER_GPIO_MODULE 1
#define CONFIG_XFS_QUOTA 1
#define CONFIG_DRM_TTM_HELPER_MODULE 1
#define CONFIG_ARCH_MMAP_RND_COMPAT_BITS_MIN 11
#define CONFIG_CRYPTO_LIB_UTILS 1
#define CONFIG_SND_USB 1
#define CONFIG_LOGIG940_FF 1
#define CONFIG_VIDEOBUF2_MEMOPS_MODULE 1
#define CONFIG_RTC_DRV_DS3232_HWMON 1
#define CONFIG_RD_GZIP 1
#define CONFIG_TOUCHSCREEN_USB_E2I 1
#define CONFIG_HAVE_REGS_AND_STACK_ACCESS_API 1
#define CONFIG_BLK_PM 1
#define CONFIG_BCMA_HOST_PCI_POSSIBLE 1
#define CONFIG_CRYPTO_ARCH_HAVE_LIB_POLY1305_MODULE 1
#define CONFIG_SECURITY_APPARMOR_PARANOID_LOAD 1
#define CONFIG_USB_SERIAL_KEYSPAN_MODULE 1
#define CONFIG_MDIO_BUS 1
#define CONFIG_TREE_RCU 1
#define CONFIG_PWM_SYSFS 1
#define CONFIG_SND_BCM2835_SOC_I2S_MODULE 1
#define CONFIG_ALLOW_DEV_COREDUMP 1
#define CONFIG_SWIOTLB 1
#define CONFIG_SND_USB_CAIAQ_MODULE 1
#define CONFIG_USB_STORAGE_CYPRESS_ATACB_MODULE 1
#define CONFIG_EXT4_FS_SECURITY 1
#define CONFIG_BCM2835_WDT 1
#define CONFIG_GRO_CELLS 1
#define CONFIG_SECURITY_APPARMOR_HASH_DEFAULT 1
#define CONFIG_DVB_S5H1432_MODULE 1
#define CONFIG_IR_XMP_DECODER_MODULE 1
#define CONFIG_HAVE_VIRT_CPU_ACCOUNTING_GEN 1
#define CONFIG_HID_ROCCAT_MODULE 1
#define CONFIG_ARM64_BTI 1
#define CONFIG_CRYPTO_MD5_MODULE 1
#define CONFIG_VIDEO_CS53L32A_MODULE 1
#define CONFIG_IR_REDRAT3_MODULE 1
#define CONFIG_USB_GSPCA_VICAM_MODULE 1
#define CONFIG_VSOCKETS_LOOPBACK_MODULE 1
#define CONFIG_USB_F_SS_LB_MODULE 1
#define CONFIG_ISCSI_TCP_MODULE 1
#define CONFIG_ARCH_DEFAULT_KEXEC_IMAGE_VERIFY_SIG 1
#define CONFIG_MFD_WL1273_CORE_MODULE 1
#define CONFIG_RT2800USB_RT53XX 1
#define CONFIG_NET_VENDOR_CORTINA 1
#define CONFIG_MEDIA_TUNER_FC0011_MODULE 1
#define CONFIG_DVB_TDA10023_MODULE 1
#define CONFIG_MEDIA_TUNER_TEA5767_MODULE 1
#define CONFIG_BATMAN_ADV_MODULE 1
#define CONFIG_ELFCORE 1
#define CONFIG_HAVE_KVM 1
#define CONFIG_USB_GSPCA_OV519_MODULE 1
#define CONFIG_BINFMT_ELF 1
#define CONFIG_RTC_DRV_RX4581_MODULE 1
#define CONFIG_AUDIT_GENERIC 1
#define CONFIG_I2C_HID 1
#define CONFIG_MD_RAID456_MODULE 1
#define CONFIG_IIO_TRIGGER 1
#define CONFIG_JOYSTICK_IFORCE_USB_MODULE 1
#define CONFIG_SCHED_TRACER 1
#define CONFIG_HAVE_PERF_REGS 1
#define CONFIG_V4L2_ASYNC_MODULE 1
#define CONFIG_CIFS_DEBUG 1
#define CONFIG_MEDIA_ANALOG_TV_SUPPORT 1
#define CONFIG_IP_PIMSM_V1 1
#define CONFIG_HAVE_KVM_MSI 1
#define CONFIG_BCACHE_MODULE 1
#define CONFIG_INET6_AH_MODULE 1
#define CONFIG_KVM_GENERIC_DIRTYLOG_READ_PROTECT 1
#define CONFIG_HID_XINMO_MODULE 1
#define CONFIG_NFS_V4_SECURITY_LABEL 1
#define CONFIG_USB_SERIAL_MODULE 1
#define CONFIG_NET_VENDOR_ALTEON 1
#define CONFIG_NFT_DUP_IPV4_MODULE 1
#define CONFIG_USB_MON_MODULE 1
#define CONFIG_REGULATOR_FIXED_VOLTAGE 1
#define CONFIG_INET_MPTCP_DIAG_MODULE 1
#define CONFIG_NET_VENDOR_RENESAS 1
#define CONFIG_QCA7000_UART_MODULE 1
#define CONFIG_TCG_TIS_I2C_MODULE 1
#define CONFIG_KEYS 1
#define CONFIG_INET_XFRM_TUNNEL_MODULE 1
#define CONFIG_RTC_DRV_FM3130_MODULE 1
#define CONFIG_BRCMDBG 1
#define CONFIG_SND_VMASTER 1
#define CONFIG_NETFILTER_XT_MARK_MODULE 1
#define CONFIG_NETFILTER_XTABLES_MODULE 1
#define CONFIG_DRM_PANEL_ORIENTATION_QUIRKS_MODULE 1
#define CONFIG_IP_VS_LBLC_MODULE 1
#define CONFIG_HAVE_KVM_IRQ_BYPASS 1
#define CONFIG_LEDS_TRIGGER_INPUT 1
#define CONFIG_DVB_USB_OPERA1_MODULE 1
#define CONFIG_ARMV8_DEPRECATED 1
#define CONFIG_MFD_STMPE 1
#define CONFIG_CRYPTO_ECHAINIV_MODULE 1
#define CONFIG_HAVE_ARCH_AUDITSYSCALL 1
#define CONFIG_LEGACY_TIOCSTI 1
#define CONFIG_ARM64_PA_BITS_48 1
#define CONFIG_TI_ADS1015_MODULE 1
#define CONFIG_USB_STORAGE_DATAFAB_MODULE 1
#define CONFIG_DVB_USB_AF9005_MODULE 1
#define CONFIG_CRYPTO_USER_API_HASH_MODULE 1
#define CONFIG_BOOT_PRINTK_DELAY 1
#define CONFIG_USB_STORAGE_KARMA_MODULE 1
#define CONFIG_TTPCI_EEPROM_MODULE 1
#define CONFIG_ARM64_ERRATUM_3117295 1
#define CONFIG_RESET_RASPBERRYPI 1
#define CONFIG_HID_GREENASIA_MODULE 1
#define CONFIG_TOUCHSCREEN_ILI210X_MODULE 1
#define CONFIG_HAVE_DYNAMIC_FTRACE_WITH_ARGS 1
#define CONFIG_SND_BCM2708_SOC_ALLO_BOSS2_DAC_MODULE 1
#define CONFIG_MAGIC_SYSRQ_DEFAULT_ENABLE 0x1f6
#define CONFIG_IIO_INV_SENSORS_TIMESTAMP_MODULE 1
#define CONFIG_SMS_USB_DRV_MODULE 1
#define CONFIG_HARDIRQS_SW_RESEND 1
#define CONFIG_JFFS2_FS_WRITEBUFFER 1
#define CONFIG_SPI_MASTER 1
#define CONFIG_FB_TFT_RA8875_MODULE 1
#define CONFIG_USB_SERIAL_OPTICON_MODULE 1
#define CONFIG_LWTUNNEL 1
#define CONFIG_IEEE802154_AT86RF230_MODULE 1
#define CONFIG_REGULATOR_ARIZONA_MICSUPP_MODULE 1
#define CONFIG_SERIAL_SC16IS7XX_I2C 1
#define CONFIG_DVB_TC90522_MODULE 1
#define CONFIG_DVB_NXT200X_MODULE 1
#define CONFIG_ARCH_HAS_KEEPINITRD 1
#define CONFIG_BLK_DEV_THROTTLING 1
#define CONFIG_VT_HW_CONSOLE_BINDING 1
#define CONFIG_MPLS 1
#define CONFIG_NF_TABLES_NETDEV 1
#define CONFIG_VIDEO_TW9903_MODULE 1
#define CONFIG_NET_ACT_GACT_MODULE 1
#define CONFIG_HID_GYRATION_MODULE 1
#define CONFIG_USB_WDM_MODULE 1
#define CONFIG_BT_HCIBCM203X_MODULE 1
#define CONFIG_THERMAL_HWMON 1
#define CONFIG_TOUCHSCREEN_USB_COMPOSITE_MODULE 1
#define CONFIG_SND_SOC_PCM186X_I2C_MODULE 1
#define CONFIG_UNMAP_KERNEL_AT_EL0 1
#define CONFIG_SND_USB_HIFACE_MODULE 1
#define CONFIG_VIDEO_EM28XX_DVB_MODULE 1
#define CONFIG_USB_SERIAL_KOBIL_SCT_MODULE 1
#define CONFIG_CRYPTO_SKCIPHER 1
#define CONFIG_USB_GSPCA_TOUPTEK_MODULE 1
#define CONFIG_ZSWAP_COMPRESSOR_DEFAULT_LZO 1
#define CONFIG_XZ_DEC_X86 1
#define CONFIG_SERIAL_OF_PLATFORM 1
#define CONFIG_MAC80211_LEDS 1
#define CONFIG_INPUT_JOYDEV_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_TPROXY_MODULE 1
#define CONFIG_THERMAL_EMERGENCY_POWEROFF_DELAY_MS 0
#define CONFIG_CONSOLE_LOGLEVEL_QUIET 4
#define CONFIG_USB_ACM_MODULE 1
#define CONFIG_USB_RTL8150_MODULE 1
#define CONFIG_NVME_CORE 1
#define CONFIG_GPIO_MAX7300_MODULE 1
#define CONFIG_CRC16 1
#define CONFIG_USB_NET_AX8817X_MODULE 1
#define CONFIG_GENERIC_CALIBRATE_DELAY 1
#define CONFIG_ARM_RASPBERRYPI_CPUFREQ 1
#define CONFIG_NLS_ISO8859_6_MODULE 1
#define CONFIG_NET_CLS 1
#define CONFIG_XFS_RT 1
#define CONFIG_AX25_MODULE 1
#define CONFIG_MFD_RPISENSE_CORE_MODULE 1
#define CONFIG_TMPFS 1
#define CONFIG_HOSTAP_MODULE 1
#define CONFIG_SND_BCM2708_SOC_JUSTBOOM_BOTH_MODULE 1
#define CONFIG_NFT_CT_MODULE 1
#define CONFIG_NET_VENDOR_NETERION 1
#define CONFIG_DRM_VC4_HDMI_CEC 1
#define CONFIG_RANDSTRUCT_NONE 1
#define CONFIG_VIDEO_EM28XX_MODULE 1
#define CONFIG_NLS_CODEPAGE_936_MODULE 1
#define CONFIG_FUTEX 1
#define CONFIG_IP_VS_MH_TAB_INDEX 12
#define CONFIG_CRYPTO_ANUBIS_MODULE 1
#define CONFIG_IP_PNP_DHCP 1
#define CONFIG_DRM_VRAM_HELPER_MODULE 1
#define CONFIG_GENERIC_PHY_MIPI_DPHY 1
#define CONFIG_FB_TFT_HX8357D_MODULE 1
#define CONFIG_UNIX_SCM 1
#define CONFIG_MCP320X_MODULE 1
#define CONFIG_MMC_SPI_MODULE 1
#define CONFIG_CONSOLE_LOGLEVEL_DEFAULT 7
#define CONFIG_USB_GSPCA_SQ930X_MODULE 1
#define CONFIG_REGMAP_I2C 1
#define CONFIG_GENERIC_SCHED_CLOCK 1
#define CONFIG_ARCH_HAS_FAST_MULTIPLIER 1
#define CONFIG_INPUT_MATRIXKMAP_MODULE 1
#define CONFIG_DVB_CXD2099_MODULE 1
#define CONFIG_NET_VENDOR_REALTEK 1
#define CONFIG_USB_G_MULTI_MODULE 1
#define CONFIG_VIDEO_VIVID_CEC 1
#define CONFIG_ARCH_HAVE_NMI_SAFE_CMPXCHG 1
#define CONFIG_JOYSTICK_XPAD_FF 1
#define CONFIG_NETFILTER_XT_TARGET_HL_MODULE 1
#define CONFIG_MT792x_LIB_MODULE 1
#define CONFIG_DVB_CORE_MODULE 1
#define CONFIG_NFSD_V2_ACL 1
#define CONFIG_CRYPTO_USER_API_MODULE 1
#define CONFIG_RTC_HCTOSYS 1
#define CONFIG_SND_BCM2708_SOC_IQAUDIO_CODEC_MODULE 1
#define CONFIG_DRM_SIMPLE_BRIDGE_MODULE 1
#define CONFIG_HAVE_ARCH_BITREVERSE 1
#define CONFIG_SECURITY_NETWORK 1
#define CONFIG_SERIAL_CORE_CONSOLE 1
#define CONFIG_HW_RANDOM_TPM 1
#define CONFIG_HAVE_ARCH_KASAN_HW_TAGS 1
#define CONFIG_BRCM_USB_PINMAP 1
#define CONFIG_NET_VENDOR_EMULEX 1
#define CONFIG_WIZNET_W5100_MODULE 1
#define CONFIG_CRYPTO_LIB_POLY1305_MODULE 1
#define CONFIG_REGMAP_IRQ 1
#define CONFIG_USB_HID 1
#define CONFIG_LD_ORPHAN_WARN_LEVEL "warn"
#define CONFIG_DVB_USB_AF9015_MODULE 1
#define CONFIG_RODATA_FULL_DEFAULT_ENABLED 1
#define CONFIG_UBIFS_FS_MODULE 1
#define CONFIG_RTL8192CU_MODULE 1
#define CONFIG_ATM_DRIVERS 1
#define CONFIG_BLK_DEV_RBD_MODULE 1
#define CONFIG_VSOCKETS_DIAG_MODULE 1
#define CONFIG_NF_TABLES_MODULE 1
#define CONFIG_BATMAN_ADV_MCAST 1
#define CONFIG_SLUB_DEBUG 1
#define CONFIG_BLK_DEV_MD_MODULE 1
#define CONFIG_UCS2_STRING 1
#define CONFIG_USB_SERIAL_AIRCABLE_MODULE 1
#define CONFIG_IP_SET_BITMAP_IP_MODULE 1
#define CONFIG_VIDEO_RP1_CFE_MODULE 1
#define CONFIG_USB_F_RNDIS_MODULE 1
#define CONFIG_NET_SCH_INGRESS_MODULE 1
#define CONFIG_BCMA_MODULE 1
#define CONFIG_DMADEVICES 1
#define CONFIG_VIDEO_AK7375_MODULE 1
#define CONFIG_PAHOLE_VERSION 0
#define CONFIG_NF_CONNTRACK_EVENTS 1
#define CONFIG_PINCTRL 1
#define CONFIG_ARCH_SUPPORTS_CFI_CLANG 1
#define CONFIG_IPV6_NDISC_NODETYPE 1
#define CONFIG_HFS_FS_MODULE 1
#define CONFIG_DVB_USB_TECHNISAT_USB2_MODULE 1
#define CONFIG_PCI_LABEL 1
#define CONFIG_NLS_CODEPAGE_1251_MODULE 1
#define CONFIG_USB_F_MIDI_MODULE 1
#define CONFIG_FANOTIFY 1
#define CONFIG_MEDIA_TUNER_MXL301RF_MODULE 1
#define CONFIG_IP_VS_PROTO_SCTP 1
#define CONFIG_NETFILTER_XT_MATCH_CONNLABEL_MODULE 1
#define CONFIG_ARCH_WANT_DEFAULT_BPF_JIT 1
#define CONFIG_PWM_RASPBERRYPI_POE_MODULE 1
#define CONFIG_CGROUP_SCHED 1
#define CONFIG_QUEUED_RWLOCKS 1
#define CONFIG_SYSVIPC 1
#define CONFIG_RAID6_PQ_BENCHMARK 1
#define CONFIG_ARCH_HAS_GIGANTIC_PAGE 1
#define CONFIG_USB_CONFIGFS_ECM_SUBSET 1
#define CONFIG_HAVE_DEBUG_KMEMLEAK 1
#define CONFIG_DVB_TDA10071_MODULE 1
#define CONFIG_ARM_GIC_V3_ITS 1
#define CONFIG_DVB_OR51211_MODULE 1
#define CONFIG_RT2X00_MODULE 1
#define CONFIG_NLS_CODEPAGE_863_MODULE 1
#define CONFIG_SND_DESIGNWARE_I2S_MODULE 1
#define CONFIG_SENSORS_ADT7X10_MODULE 1
#define CONFIG_USB_G_HID_MODULE 1
#define CONFIG_KEYBOARD_GPIO_MODULE 1
#define CONFIG_NF_CONNTRACK_FTP_MODULE 1
#define CONFIG_PAGE_SIZE_LESS_THAN_64KB 1
#define CONFIG_MODULES 1
#define CONFIG_IP_NF_MATCH_ECN_MODULE 1
#define CONFIG_VIDEO_IMX219_MODULE 1
#define CONFIG_USB_GADGET 1
#define CONFIG_USB_GSPCA_SPCA506_MODULE 1
#define CONFIG_CONTEXT_TRACKING 1
#define CONFIG_CRYPTO_SHA512_ARM64_CE_MODULE 1
#define CONFIG_MQ_IOSCHED_DEADLINE 1
#define CONFIG_VIDEO_EM28XX_ALSA_MODULE 1
#define CONFIG_MEDIA_TUNER_MXL5005S_MODULE 1
#define CONFIG_USB_HIDDEV 1
#define CONFIG_GENERIC_IRQ_IPI 1
#define CONFIG_IOMMU_IOVA 1
#define CONFIG_DUMMY_CONSOLE_COLUMNS 80
#define CONFIG_USB_ETH_RNDIS 1
#define CONFIG_DVB_SI21XX_MODULE 1
#define CONFIG_XXHASH 1
#define CONFIG_SOUND 1
#define CONFIG_NFT_MASQ_MODULE 1
#define CONFIG_SPS30_MODULE 1
#define CONFIG_NFT_QUOTA_MODULE 1
#define CONFIG_JOLIET 1
#define CONFIG_SERIAL_SC16IS7XX_MODULE 1
#define CONFIG_DVB_USB_VP7045_MODULE 1
#define CONFIG_ARCH_SUPPORTS_MEMORY_FAILURE 1
#define CONFIG_RTW88_8821C_MODULE 1
#define CONFIG_ARM64_ERRATUM_2051678 1
#define CONFIG_MEDIA_TUNER_TDA9887_MODULE 1
#define CONFIG_CRYPTO_TEA_MODULE 1
#define CONFIG_ARCH_HIBERNATION_POSSIBLE 1
#define CONFIG_DVB_USB_LME2510_MODULE 1
#define CONFIG_ARCH_USE_SYM_ANNOTATIONS 1
#define CONFIG_PROC_CHILDREN 1
#define CONFIG_SND_USB_LINE6_MODULE 1
#define CONFIG_UNIX 1
#define CONFIG_USB_CATC_MODULE 1
#define CONFIG_USB_NET_DRIVERS 1
#define CONFIG_CC_CAN_LINK 1
#define CONFIG_LD_IS_BFD 1
#define CONFIG_NO_HZ_COMMON 1
#define CONFIG_DRM_MIPI_DSI 1
#define CONFIG_HAVE_CLK 1
#define CONFIG_CRYPTO_HASH2 1
#define CONFIG_CARL9170_MODULE 1
#define CONFIG_LEDS_CLASS_MULTICOLOR_MODULE 1
#define CONFIG_NET_VENDOR_VERTEXCOM 1
#define CONFIG_DVB_CX24117_MODULE 1
#define CONFIG_THERMAL_GOV_STEP_WISE 1
#define CONFIG_BT_HCIBTUSB_POLL_SYNC 1
#define CONFIG_DEFAULT_HOSTNAME "(none)"
#define CONFIG_NLS_KOI8_R_MODULE 1
#define CONFIG_SENSORS_ADT7410_MODULE 1
#define CONFIG_MMC_HSQ 1
#define CONFIG_USB_GADGET_STORAGE_NUM_BUFFERS 2
#define CONFIG_NEED_KVM_DIRTY_RING_WITH_BITMAP 1
#define CONFIG_CC_HAS_NO_PROFILE_FN_ATTR 1
#define CONFIG_USB_GSPCA_SONIXB_MODULE 1
#define CONFIG_CAN_RX_OFFLOAD 1
#define CONFIG_DVB_USB_RTL28XXU_MODULE 1
#define CONFIG_USB_STORAGE_ISD200_MODULE 1
#define CONFIG_CPU_FREQ_GOV_POWERSAVE 1
#define CONFIG_USB_GSPCA_OV534_9_MODULE 1
#define CONFIG_NFS_FS 1
#define CONFIG_USB_NET_SMSC95XX 1
#define CONFIG_MEMBARRIER 1
#define CONFIG_CEC_CORE_MODULE 1
#define CONFIG_BLK_DEV_IO_TRACE 1
#define CONFIG_SERIAL_8250_BCM2835AUX 1
#define CONFIG_XPS 1
#define CONFIG_NET_ACT_SKBEDIT_MODULE 1
#define CONFIG_INET_ESP_MODULE 1
#define CONFIG_SGL_ALLOC 1
#define CONFIG_LZ4_DECOMPRESS 1
#define CONFIG_NF_TPROXY_IPV6_MODULE 1
#define CONFIG_NF_CONNTRACK_ZONES 1
#define CONFIG_DMA_BCM2708 1
#define CONFIG_FONT_SUPPORT 1
#define CONFIG_ADVISE_SYSCALLS 1
#define CONFIG_MD 1
#define CONFIG_CRYPTO_ALGAPI 1
#define CONFIG_CEC_PIN 1
#define CONFIG_GENERIC_IRQ_SHOW_LEVEL 1
#define CONFIG_CP15_BARRIER_EMULATION 1
#define CONFIG_ARM64_ERRATUM_1463225 1
#define CONFIG_RTW88_CORE_MODULE 1
#define CONFIG_CEPH_FSCACHE 1
#define CONFIG_ZSWAP_ZPOOL_DEFAULT_ZBUD 1
#define CONFIG_BSD_PROCESS_ACCT_V3 1
#define CONFIG_DRM_PANEL_SIMPLE_MODULE 1
#define CONFIG_NET_VENDOR_WIZNET 1
#define CONFIG_BRIDGE_MODULE 1
#define CONFIG_MEDIA_TUNER_MODULE 1
#define CONFIG_SND_SOC_WM8731_I2C_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_CGROUP_MODULE 1
#define CONFIG_USB_CYPRESS_CY7C63_MODULE 1
#define CONFIG_BACKLIGHT_RPI_MODULE 1
#define CONFIG_EEPROM_AT25_MODULE 1
#define CONFIG_SCHED_MM_CID 1
#define CONFIG_RD_BZIP2 1
#define CONFIG_ARM64_HW_AFDBM 1
#define CONFIG_RTC_DRV_BRCMSTB 1
#define CONFIG_WANT_DEV_COREDUMP 1
#define CONFIG_INPUT_UINPUT_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_CHECKSUM_MODULE 1
#define CONFIG_HAVE_ARM_SMCCC_DISCOVERY 1
#define CONFIG_SKB_EXTENSIONS 1
#define CONFIG_PM_OPP 1
#define CONFIG_RTLWIFI_USB_MODULE 1
#define CONFIG_SND_BCM2708_SOC_ADAU1977_ADC_MODULE 1
#define CONFIG_TINYDRM_MI0283QT_MODULE 1
#define CONFIG_GPIO_CDEV 1
#define CONFIG_CRYPTO_SHA2_ARM64_CE_MODULE 1
#define CONFIG_DVB_MB86A16_MODULE 1
#define CONFIG_MEDIA_TUNER_SIMPLE_MODULE 1
#define CONFIG_CC_VERSION_TEXT "gcc (GCC) 12.1.0"
#define CONFIG_NET_IP_TUNNEL_MODULE 1
#define CONFIG_MTD_CFI_I1 1
#define CONFIG_NF_NAT_MODULE 1
#define CONFIG_LEDS_PWM 1
#define CONFIG_W1_SLAVE_DS2780_MODULE 1
#define CONFIG_UBIFS_FS_ZLIB 1
#define CONFIG_BLOCK_LEGACY_AUTOLOAD 1
#define CONFIG_QCA7000_SPI_MODULE 1
#define CONFIG_BLK_DEV_INTEGRITY 1
#define CONFIG_DVB_USB_AZ6027_MODULE 1
#define CONFIG_NET_VENDOR_OKI 1
#define CONFIG_CPU_IDLE 1
#define CONFIG_WLAN_VENDOR_INTERSIL 1
#define CONFIG_IP6_NF_MATCH_RPFILTER_MODULE 1
#define CONFIG_NF_TABLES_INET 1
#define CONFIG_NFS_COMMON 1
#define CONFIG_6LOWPAN_NHC_IPV6_MODULE 1
#define CONFIG_REGULATOR 1
#define CONFIG_NF_TABLES_IPV6 1
#define CONFIG_FAIR_GROUP_SCHED 1
#define CONFIG_RT2800USB_MODULE 1
#define CONFIG_CRYPTO_HASH 1
#define CONFIG_EFI_PARTITION 1
#define CONFIG_PROBE_EVENTS 1
#define CONFIG_TRACE_CLOCK 1
#define CONFIG_HID_STEAM_MODULE 1
#define CONFIG_BCMA_BLOCKIO 1
#define CONFIG_LOG_BUF_SHIFT 18
#define CONFIG_RTW88_USB_MODULE 1
#define CONFIG_WLAN_VENDOR_ATH 1
#define CONFIG_USB_RTL8153_ECM_MODULE 1
#define CONFIG_BH1750_MODULE 1
#define CONFIG_NLS_CODEPAGE_857_MODULE 1
#define CONFIG_SOUND_OSS_CORE_PRECLAIM 1
#define CONFIG_NETFILTER_XT_TARGET_DSCP_MODULE 1
#define CONFIG_EXTRA_FIRMWARE ""
#define CONFIG_TCG_TPM_MODULE 1
#define CONFIG_NET_VENDOR_8390 1
#define CONFIG_MFD_WM5102 1
#define CONFIG_IPV6_MROUTE 1
#define CONFIG_SENSORS_SHT3x_MODULE 1
#define CONFIG_HAVE_KCSAN_COMPILER 1
#define CONFIG_VFAT_FS 1
#define CONFIG_ARCH_SUPPORTS_ACPI 1
#define CONFIG_NF_FLOW_TABLE_INET_MODULE 1
#define CONFIG_PID_NS 1
#define CONFIG_SND_SOC_DMIC_MODULE 1
#define CONFIG_MD_RAID1_MODULE 1
#define CONFIG_RTW88_8822B_MODULE 1
#define CONFIG_PSI 1
#define CONFIG_MEDIA_PLATFORM_DRIVERS 1
#define CONFIG_IIO_CONFIGFS_MODULE 1
#define CONFIG_RADIO_TEF6862_MODULE 1
#define CONFIG_CRC32_SLICEBY8 1
#define CONFIG_MT7921U_MODULE 1
#define CONFIG_ARM64_PTR_AUTH_KERNEL 1
#define CONFIG_USB_LIBCOMPOSITE_MODULE 1
#define CONFIG_CRYPTO_SM3_MODULE 1
#define CONFIG_EFI_PARAMS_FROM_FDT 1
#define CONFIG_NET_SCH_FQ_MODULE 1
#define CONFIG_VIDEO_HDPVR_MODULE 1
#define CONFIG_ARCH_BCM 1
#define CONFIG_GPIO_ARIZONA_MODULE 1
#define CONFIG_BLK_DEV_SR_MODULE 1
#define CONFIG_CPU_RMAP 1
#define CONFIG_SND_HWDEP_MODULE 1
#define CONFIG_BCM2835_MBOX 1
#define CONFIG_BLK_DEV_LOOP 1
#define CONFIG_DEFAULT_HUNG_TASK_TIMEOUT 120
#define CONFIG_L2TP_ETH_MODULE 1
#define CONFIG_SPI_MEM 1
#define CONFIG_ARM64_ERRATUM_843419 1
#define CONFIG_NF_NAT_IRC_MODULE 1
#define CONFIG_MEDIA_TUNER_XC2028_MODULE 1
#define CONFIG_INPUT_MISC 1
#define CONFIG_SND_COMPRESS_OFFLOAD_MODULE 1
#define CONFIG_VIDEO_TC358743_MODULE 1
#define CONFIG_MT76x0U_MODULE 1
#define CONFIG_DVB_STV0288_MODULE 1
#define CONFIG_MULTIUSER 1
#define CONFIG_DMA_OF 1
#define CONFIG_GENERIC_VDSO_TIME_NS 1
#define CONFIG_CROSS_MEMORY_ATTACH 1
#define CONFIG_MTD_NAND_ECC 1
#define CONFIG_CRYPTO_CBC_MODULE 1
#define CONFIG_MMC_BCM2835_SDHOST 1
#define CONFIG_MEDIA_CONTROLLER 1
#define CONFIG_NETFILTER_XT_TARGET_HMARK_MODULE 1
#define CONFIG_EFI_ARMSTUB_DTB_LOADER 1
#define CONFIG_IP6_NF_MATCH_RT_MODULE 1
#define CONFIG_SQUASHFS_DECOMP_SINGLE 1
#define CONFIG_SERIAL_8250_RUNTIME_UARTS 0
#define CONFIG_BCM2835_SMI_MODULE 1
#define CONFIG_PREEMPT_BUILD 1
#define CONFIG_CRYPTO_CHACHA20_NEON_MODULE 1
#define CONFIG_CLANG_VERSION 0
#define CONFIG_TSL4531_MODULE 1
#define CONFIG_KPROBES 1
#define CONFIG_FS_MBCACHE 1
#define CONFIG_MMC_BCM2835_MMC 1
#define CONFIG_SENSORS_JC42_MODULE 1
#define CONFIG_GFS2_FS_MODULE 1
#define CONFIG_MEDIA_TUNER_TUA9001_MODULE 1
#define CONFIG_RTC_CLASS 1
#define CONFIG_DVB_TUNER_DIB0070_MODULE 1
#define CONFIG_CRC7_MODULE 1
#define CONFIG_CRYPTO_RNG_DEFAULT 1
#define CONFIG_USB_EMI26_MODULE 1
#define CONFIG_IP_VS_PROTO_ESP 1
#define CONFIG_F2FS_FS_LZO 1
#define CONFIG_MEDIA_TUNER_IT913X_MODULE 1
#define CONFIG_TMPFS_XATTR 1
#define CONFIG_EXT4_USE_FOR_EXT2 1
#define CONFIG_MT76x2_COMMON_MODULE 1
#define CONFIG_ARM64_ERRATUM_1742098 1
#define CONFIG_TOUCHSCREEN_TSC2007_MODULE 1
#define CONFIG_NETFILTER_FAMILY_ARP 1
#define CONFIG_BCM_NET_PHYLIB 1
#define CONFIG_W1_MODULE 1
#define CONFIG_ARM_AMBA 1
#define CONFIG_FB_TFT_MODULE 1
#define CONFIG_USB_GSPCA_VC032X_MODULE 1
#define CONFIG_OPENVSWITCH_GRE_MODULE 1
#define CONFIG_CPU_PM 1
#define CONFIG_SND_SOC_PCM5102A_MODULE 1
#define CONFIG_V4L2_FWNODE_MODULE 1
#define CONFIG_LEDS_TRIGGER_NETDEV_MODULE 1
#define CONFIG_DVB_ISL6421_MODULE 1
#define CONFIG_VIDEO_AU0828_RC 1
#define CONFIG_RTC_DRV_DS1374_MODULE 1
#define CONFIG_CRYPTO_KDF800108_CTR 1
#define CONFIG_QCOM_FALKOR_ERRATUM_1003 1
#define CONFIG_DRM_RP1_DPI_MODULE 1
#define CONFIG_GENERIC_TRACER 1
#define CONFIG_CFG80211_USE_KERNEL_REGDB_KEYS 1
#define CONFIG_BCM_VCIO 1
#define CONFIG_TIMER_OF 1
#define CONFIG_NLS_ISO8859_5_MODULE 1
#define CONFIG_IP_VS_WLC_MODULE 1
#define CONFIG_ARCH_HAS_DMA_PREP_COHERENT 1
#define CONFIG_MT792x_USB_MODULE 1
#define CONFIG_HAVE_FUNCTION_TRACER 1
#define CONFIG_GENERIC_PHY 1
#define CONFIG_CPU_ISOLATION 1
#define CONFIG_NF_NAT_TFTP_MODULE 1
#define CONFIG_GCC_ASM_GOTO_OUTPUT_WORKAROUND 1
#define CONFIG_NETFILTER_XT_MATCH_MULTIPORT_MODULE 1
#define CONFIG_MTD_SPI_NOR_MODULE 1
#define CONFIG_FW_LOADER_COMPRESS_XZ 1
#define CONFIG_NET_SCH_NETEM_MODULE 1
#define CONFIG_USB_STORAGE_REALTEK_MODULE 1
#define CONFIG_CRYPTO_CAMELLIA_MODULE 1
#define CONFIG_LRU_GEN_ENABLED 1
#define CONFIG_RTC_DRV_DS1307 1
#define CONFIG_VIDEO_CODEC_BCM2835_MODULE 1
#define CONFIG_NFSD_V4 1
#define CONFIG_I2C_SI4713_MODULE 1
#define CONFIG_ARM64_ERRATUM_2645198 1
#define CONFIG_BCM_NET_PHYPTP 1
#define CONFIG_NETFILTER_XT_TARGET_REDIRECT_MODULE 1
#define CONFIG_CRYPTO_MANAGER2 1
#define CONFIG_USB_GADGET_VBUS_DRAW 2
#define CONFIG_ARCH_HAS_PTE_SPECIAL 1
#define CONFIG_NET_VENDOR_MYRI 1
#define CONFIG_ARM64_AS_HAS_MTE 1
#define CONFIG_NF_NAT_MASQUERADE 1
#define CONFIG_PM_GENERIC_DOMAINS_OF 1
#define CONFIG_CLZ_TAB 1
#define CONFIG_TOUCHSCREEN_USB_3M 1
#define CONFIG_TOUCHSCREEN_USB_EGALAX 1
#define CONFIG_BRIDGE_EBT_DNAT_MODULE 1
#define CONFIG_ARCH_SUPPORTS_KEXEC_IMAGE_VERIFY_SIG 1
#define CONFIG_GENERIC_PCI_IOMAP 1
#define CONFIG_HID_PLAYSTATION_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_LOG_MODULE 1
#define CONFIG_SLUB 1
#define CONFIG_NET_SCH_HHF_MODULE 1
#define CONFIG_CONFIGFS_FS 1
#define CONFIG_MTD_UBI_MODULE 1
#define CONFIG_RTC_DRV_RV3032_MODULE 1
#define CONFIG_XZ_DEC_BCJ 1
#define CONFIG_SLIP_MODULE 1
#define CONFIG_ARCH_SUPPORTS_LTO_CLANG_THIN 1
#define CONFIG_F2FS_FS_XATTR 1
#define CONFIG_I2C 1
#define CONFIG_ZSWAP_ZPOOL_DEFAULT "zbud"
#define CONFIG_JFFS2_ZLIB 1
#define CONFIG_VIDEO_TC358743_CEC 1
#define CONFIG_ARM64_ERRATUM_2457168 1
#define CONFIG_PPP_MULTILINK 1
#define CONFIG_ARM64_WORKAROUND_SPECULATIVE_AT 1
#define CONFIG_MMU_GATHER_TABLE_FREE 1
#define CONFIG_BINFMT_SCRIPT 1
#define CONFIG_EFI_STUB 1
#define CONFIG_VIDEO_CX25840_MODULE 1
#define CONFIG_BFQ_GROUP_IOSCHED 1
#define CONFIG_ARM64_WORKAROUND_TSB_FLUSH_FAILURE 1
#define CONFIG_DVB_MN88472_MODULE 1
#define CONFIG_PPS_CLIENT_GPIO_MODULE 1
#define CONFIG_IIO_SW_TRIGGER_MODULE 1
#define CONFIG_FRAME_POINTER 1
#define CONFIG_BT_HIDP_MODULE 1
#define CONFIG_VIDEO_CX231XX_RC 1
#define CONFIG_TICK_CPU_ACCOUNTING 1
#define CONFIG_BRCM_CHAR_DRIVERS 1
#define CONFIG_TINYDRM_HX8357D_MODULE 1
#define CONFIG_VM_EVENT_COUNTERS 1
#define CONFIG_MEDIA_COMMON_OPTIONS 1
#define CONFIG_RELAY 1
#define CONFIG_USB_GSPCA_FINEPIX_MODULE 1
#define CONFIG_CRYPTO_ECB 1
#define CONFIG_SND_SOC_TLV320AIC32X4_MODULE 1
#define CONFIG_USB_GSPCA_ETOMS_MODULE 1
#define CONFIG_WLAN_VENDOR_BROADCOM 1
#define CONFIG_SQUASHFS_LZO 1
#define CONFIG_SND_DYNAMIC_MINORS 1
#define CONFIG_SND_PCM_IEC958 1
#define CONFIG_6LOWPAN_NHC_HOP_MODULE 1
#define CONFIG_NF_CONNTRACK_AMANDA_MODULE 1
#define CONFIG_CRYPTO_SM4_GENERIC_MODULE 1
#define CONFIG_BCM2835_SMI_DEV_MODULE 1
#define CONFIG_DEBUG_FS 1
#define CONFIG_ARM_BRCMSTB_AVS_CPUFREQ 1
#define CONFIG_JOYSTICK_RPISENSE_MODULE 1
#define CONFIG_NET_VENDOR_AMD 1
#define CONFIG_NET_PKTGEN_MODULE 1
#define CONFIG_USB_SERIAL_EDGEPORT_MODULE 1
#define CONFIG_DRM_TTM_MODULE 1
#define CONFIG_BASE_FULL 1
#define CONFIG_FB_CFB_IMAGEBLIT 1
#define CONFIG_ZLIB_DEFLATE 1
#define CONFIG_NFT_REJECT_INET_MODULE 1
#define CONFIG_SUNRPC 1
#define CONFIG_TOUCHSCREEN_TSC2007_IIO 1
#define CONFIG_XFRM_INTERFACE_MODULE 1
#define CONFIG_INPUT_ATI_REMOTE2_MODULE 1
#define CONFIG_ARCH_USES_HIGH_VMA_FLAGS 1
#define CONFIG_CACHESTAT_SYSCALL 1
#define CONFIG_SWP_EMULATION 1
#define CONFIG_RSEQ 1
#define CONFIG_NLS_CODEPAGE_864_MODULE 1
#define CONFIG_IIO_BUFFER 1
#define CONFIG_IP_VS_LBLCR_MODULE 1
#define CONFIG_GPIO_SYSFS 1
#define CONFIG_USB_YUREX_MODULE 1
#define CONFIG_FW_LOADER 1
#define CONFIG_IP6_NF_NAT_MODULE 1
#define CONFIG_KALLSYMS 1
#define CONFIG_COMMON_CLK 1
#define CONFIG_USB_GSPCA_SPCA501_MODULE 1
#define CONFIG_RTC_DRV_RV8803_MODULE 1
#define CONFIG_STACKPROTECTOR_STRONG 1
#define CONFIG_PCI 1
#define CONFIG_RTC_HCTOSYS_DEVICE "rtc0"
#define CONFIG_HAVE_ARCH_COMPILER_H 1
#define CONFIG_NET_VENDOR_FUNGIBLE 1
#define CONFIG_CONTIG_ALLOC 1
#define CONFIG_CRYPTO_XTS 1
#define CONFIG_PWM 1
#define CONFIG_NETFILTER_XT_MATCH_RECENT_MODULE 1
#define CONFIG_NET_VENDOR_ASIX 1
#define CONFIG_DECOMPRESS_XZ 1
#define CONFIG_SERIAL_DEV_CTRL_TTYPORT 1
#define CONFIG_PCI_QUIRKS 1
#define CONFIG_BT_BCM_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_PKTTYPE_MODULE 1
#define CONFIG_MII 1
#define CONFIG_KEYBOARD_TCA8418_MODULE 1
#define CONFIG_GPIO_MOCKUP_MODULE 1
#define CONFIG_MD_BITMAP_FILE 1
#define CONFIG_SIGNALFD 1
#define CONFIG_NET_CORE 1
#define CONFIG_BPF_JIT_DEFAULT_ON 1
#define CONFIG_EXT4_FS 1
#define CONFIG_NET_SCH_DRR_MODULE 1
#define CONFIG_BRIDGE_EBT_802_3_MODULE 1
#define CONFIG_SERIAL_SC16IS7XX_SPI 1
#define CONFIG_UNINLINE_SPIN_UNLOCK 1
#define CONFIG_HAVE_HW_BREAKPOINT 1
#define CONFIG_KRETPROBES 1
#define CONFIG_SND_JACK_INPUT_DEV 1
#define CONFIG_CRYPTO_SHA1 1
#define CONFIG_BPQETHER_MODULE 1
#define CONFIG_USB_ADUTUX_MODULE 1
#define CONFIG_VIDEO_UDA1342_MODULE 1
#define CONFIG_MT7601U_MODULE 1
#define CONFIG_SPS30_I2C_MODULE 1
#define CONFIG_LEDS_TRIGGER_ACTPWR 1
#define CONFIG_WIREGUARD_MODULE 1
#define CONFIG_NLS_KOI8_U_MODULE 1
#define CONFIG_RADIO_SHARK2_MODULE 1
#define CONFIG_CRC8_MODULE 1
#define CONFIG_BLK_DEV_ZONED 1
#define CONFIG_HAVE_SAMPLE_FTRACE_DIRECT 1
#define CONFIG_USB_BELKIN 1
#define CONFIG_SATA_PMP 1
#define CONFIG_XZ_DEC 1
#define CONFIG_CAN_VCAN_MODULE 1
#define CONFIG_ATH_COMMON_MODULE 1
#define CONFIG_NET_VENDOR_TI 1
#define CONFIG_LOCKD_V4 1
#define CONFIG_DUMMY_MODULE 1
#define CONFIG_W1_SLAVE_DS2431_MODULE 1
#define CONFIG_NET_VENDOR_ALACRITECH 1
#define CONFIG_DVB_TUNER_CX24113_MODULE 1
#define CONFIG_BRIDGE_EBT_MARK_T_MODULE 1
#define CONFIG_WATCHDOG 1
#define CONFIG_CC_HAVE_SHADOW_CALL_STACK 1
#define CONFIG_HAS_IOMEM 1
#define CONFIG_SND_RAWMIDI_MODULE 1
#define CONFIG_MFD_ARIZONA_SPI_MODULE 1
#define CONFIG_NF_LOG_IPV6_MODULE 1
#define CONFIG_LEDS_IS31FL32XX_MODULE 1
#define CONFIG_BCM2711_THERMAL 1
#define CONFIG_DRM_VC4_MODULE 1
#define CONFIG_IEEE802154_SOCKET_MODULE 1
#define CONFIG_CRYPTO_RSA 1
#define CONFIG_USB_GSPCA_STK1135_MODULE 1
#define CONFIG_DMA_DIRECT_REMAP 1
#define CONFIG_GENERIC_IRQ_PROBE 1
#define CONFIG_ATH6KL_USB_MODULE 1
#define CONFIG_USB_NET_CDC_EEM_MODULE 1
#define CONFIG_USB_STORAGE_SDDR09_MODULE 1
#define CONFIG_CRYPTO_SIG2 1
#define CONFIG_IP_NF_MATCH_TTL_MODULE 1
#define CONFIG_ASYNC_RAID6_RECOV_MODULE 1
#define CONFIG_PWRSEQ_EMMC 1
#define CONFIG_HAVE_MOVE_PUD 1
#define CONFIG_SI7020_MODULE 1
#define CONFIG_VIDEOMODE_HELPERS 1
#define CONFIG_CRYPTO_ACOMP2 1
#define CONFIG_VHOST_TASK 1
#define CONFIG_ARM64_ERRATUM_2054223 1
#define CONFIG_FB_TFT_SSD1289_MODULE 1
#define CONFIG_VSOCKMON_MODULE 1
#define CONFIG_VIDEO_OV7251_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_TRACE_MODULE 1
#define CONFIG_ARCH_HAS_SETUP_DMA_OPS 1
#define CONFIG_HAVE_ARCH_KASAN_VMALLOC 1
#define CONFIG_MODULE_COMPRESS_XZ 1
#define CONFIG_USB_GADGETFS_MODULE 1
#define CONFIG_CPU_FREQ_DEFAULT_GOV_ONDEMAND 1
#define CONFIG_RTC_DRV_X1205_MODULE 1
#define CONFIG_MTD_MAP_BANK_WIDTH_1 1
#define CONFIG_IP6_NF_MATCH_FRAG_MODULE 1
#define CONFIG_HDC100X_MODULE 1
#define CONFIG_USB_SERIAL_CYBERJACK_MODULE 1
#define CONFIG_NET_SCH_PRIO_MODULE 1
#define CONFIG_ANDROID_BINDER_DEVICES "binder,hwbinder,vndbinder"
#define CONFIG_SCHED_HRTICK 1
#define CONFIG_TOUCHSCREEN_EXC3000_MODULE 1
#define CONFIG_DVB_DRXK_MODULE 1
#define CONFIG_USB_SERIAL_IUU_MODULE 1
#define CONFIG_VIDEO_GO7007_USB_S2250_BOARD_MODULE 1
#define CONFIG_EPOLL 1
#define CONFIG_CRYPTO_LZO 1
#define CONFIG_SND_PCM_MODULE 1
#define CONFIG_BRIDGE_EBT_SNAT_MODULE 1
#define CONFIG_SATA_MOBILE_LPM_POLICY 0
#define CONFIG_SND_PISOUND_MODULE 1
#define CONFIG_APERTURE_HELPERS 1
#define CONFIG_SND_SEQ_MIDI_EVENT_MODULE 1
#define CONFIG_DYNAMIC_FTRACE_WITH_CALL_OPS 1
#define CONFIG_MMC_BCM2835_DMA 1
#define CONFIG_PARTITION_ADVANCED 1
#define CONFIG_NETFILTER_XT_MATCH_DCCP_MODULE 1
#define CONFIG_CEC_CH7322_MODULE 1
#define CONFIG_USB_U_ETHER_MODULE 1
#define CONFIG_BT_BNEP_MC_FILTER 1
#define CONFIG_CRYPTO_CRC32 1
#define CONFIG_SCSI_ISCSI_ATTRS 1
#define CONFIG_VIDEO_IMX519_MODULE 1
#define CONFIG_USB_SERIAL_EMPEG_MODULE 1
#define CONFIG_DRM_TOSHIBA_TC358762_MODULE 1
#define CONFIG_IR_SONY_DECODER_MODULE 1
#define CONFIG_NLS_CODEPAGE_852_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_IDEALTEK 1
#define CONFIG_CRYPTO_CRCT10DIF_ARM64_CE_MODULE 1
#define CONFIG_VIDEO_PVRUSB2_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_COMMENT_MODULE 1
#define CONFIG_NFS_SWAP 1
#define CONFIG_FB_SSD1307_MODULE 1
#define CONFIG_GENERIC_PTDUMP 1
#define CONFIG_VIDEO_OV9282_MODULE 1
#define CONFIG_AS_HAS_ARMV8_5 1
#define CONFIG_USB_NET_RNDIS_HOST_MODULE 1
#define CONFIG_NET 1
#define CONFIG_MTD_SPI_NOR_SWP_DISABLE_ON_VOLATILE 1
#define CONFIG_INPUT_EVDEV 1
#define CONFIG_FS_ENCRYPTION_ALGS 1
#define CONFIG_SND_JACK 1
#define CONFIG_CC_HAS_AUTO_VAR_INIT_PATTERN 1
#define CONFIG_SECURITY_PATH 1
#define CONFIG_NETFILTER_XT_TARGET_TCPMSS_MODULE 1
#define CONFIG_FB_TFT_SSD1351_MODULE 1
#define CONFIG_I2C_BCM2708_MODULE 1
#define CONFIG_B43LEGACY_DMA 1
#define CONFIG_BMP280_SPI_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_DSCP_MODULE 1
#define CONFIG_CRYPTO_WP512_MODULE 1
#define CONFIG_STMPE_SPI 1
#define CONFIG_CHARLCD_BL_FLASH 1
#define CONFIG_HID_DRAGONRISE_MODULE 1
#define CONFIG_CRYPTO_LIB_BLAKE2S_GENERIC 1
#define CONFIG_NETFILTER_XT_MATCH_CONNTRACK_MODULE 1
#define CONFIG_ARM_ARCH_TIMER_EVTSTREAM 1
#define CONFIG_ARM64_ERRATUM_2441007 1
#define CONFIG_IR_IGUANA_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_RATEEST_MODULE 1
#define CONFIG_PWRSEQ_SIMPLE 1
#define CONFIG_SND_ALOOP_MODULE 1
#define CONFIG_SND_AUDIO_GRAPH_CARD_MODULE 1
#define CONFIG_PINMUX 1
#define CONFIG_USB_LD_MODULE 1
#define CONFIG_LAN743X_MODULE 1
#define CONFIG_QUOTA_TREE_MODULE 1
#define CONFIG_IRQ_DOMAIN_HIERARCHY 1
#define CONFIG_ATA_FORCE 1
#define CONFIG_NETFILTER_BPF_LINK 1
#define CONFIG_DRM_MIPI_DBI_MODULE 1
#define CONFIG_HW_RANDOM_ARM_SMCCC_TRNG 1
#define CONFIG_MPILIB 1
#define CONFIG_USB_NET_CDCETHER_MODULE 1
#define CONFIG_PACKET 1
#define CONFIG_MODULE_SRCVERSION_ALL 1
#define CONFIG_XFRM_ALGO 1
#define CONFIG_SND_SIMPLE_CARD_UTILS_MODULE 1
#define CONFIG_NF_CONNTRACK_TIMESTAMP 1
#define CONFIG_BLK_ICQ 1
#define CONFIG_HAVE_CLK_PREPARE 1
#define CONFIG_CRYPTO_AKCIPHER2 1
#define CONFIG_MWIFIEX_SDIO_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_IPRANGE_MODULE 1
#define CONFIG_NET_CLS_BASIC_MODULE 1
#define CONFIG_ASYMMETRIC_PUBLIC_KEY_SUBTYPE 1
#define CONFIG_FB_IOMEM_FOPS 1
#define CONFIG_SND_CTL_FAST_LOOKUP 1
#define CONFIG_I2C_TINY_USB_MODULE 1
#define CONFIG_NETROM_MODULE 1
#define CONFIG_CRYPTO_SM3_ARM64_CE_MODULE 1
#define CONFIG_BTRFS_FS_POSIX_ACL 1
#define CONFIG_USB_GSPCA_OV534_MODULE 1
#define CONFIG_KEYBOARD_TCA6416_MODULE 1
#define CONFIG_DVB_USB_GL861_MODULE 1
#define CONFIG_ARM64_WORKAROUND_SPECULATIVE_UNPRIV_LOAD 1
#define CONFIG_DUMMY_CONSOLE_ROWS 25
#define CONFIG_PINCTRL_MCP23S08_SPI_MODULE 1
#define CONFIG_MFD_ARIZONA_I2C_MODULE 1
#define CONFIG_USB_XHCI_PLATFORM 1
#define CONFIG_SND_SOC_TLV320AIC23_I2C_MODULE 1
#define CONFIG_NF_CONNTRACK_TFTP_MODULE 1
#define CONFIG_NFS_V3 1
#define CONFIG_RTC_DRV_MAX6902_MODULE 1
#define CONFIG_DVB_USB_ANYSEE_MODULE 1
#define CONFIG_HAVE_KVM_IRQFD 1
#define CONFIG_NLS_CODEPAGE_949_MODULE 1
#define CONFIG_DVB_CX24110_MODULE 1
#define CONFIG_SENSORS_TMP102_MODULE 1
#define CONFIG_NOP_TRACER 1
#define CONFIG_INET 1
#define CONFIG_IP_ROUTE_VERBOSE 1
#define CONFIG_XZ_DEC_POWERPC 1
#define CONFIG_DVB_RTL2832_MODULE 1
#define CONFIG_ARM64_MTE 1
#define CONFIG_NETFILTER_XT_MATCH_ADDRTYPE_MODULE 1
#define CONFIG_NET_VENDOR_HUAWEI 1
#define CONFIG_PREVENT_FIRMWARE_BUILD 1
#define CONFIG_USB_NET_MCS7830_MODULE 1
#define CONFIG_CRYPTO_TWOFISH_MODULE 1
#define CONFIG_FREEZER 1
#define CONFIG_USB_F_SUBSET_MODULE 1
#define CONFIG_W1_SLAVE_DS2413_MODULE 1
#define CONFIG_USB_TEST_MODULE 1
#define CONFIG_BT_MODULE 1
#define CONFIG_BT_HCIVHCI_MODULE 1
#define CONFIG_INPUT_CM109_MODULE 1
#define CONFIG_ARM64_4K_PAGES 1
#define CONFIG_PCI_DOMAINS 1
#define CONFIG_MS5637_MODULE 1
#define CONFIG_NFT_QUEUE_MODULE 1
#define CONFIG_DVB_USB_MXL111SF_MODULE 1
#define CONFIG_SPI_BCM2835_MODULE 1
#define CONFIG_NET_CLS_ACT 1
#define CONFIG_PCIE_BRCMSTB 1
#define CONFIG_HID_BIGBEN_FF_MODULE 1
#define CONFIG_REED_SOLOMON 1
#define CONFIG_CIFS_DFS_UPCALL 1
#define CONFIG_NET_VENDOR_CHELSIO 1
#define CONFIG_LZ4HC_COMPRESS 1
#define CONFIG_EFIVAR_FS_MODULE 1
#define CONFIG_SND_BCM2708_SOC_HIFIBERRY_DACPLUSADC_MODULE 1
#define CONFIG_BRIDGE_EBT_BROUTE_MODULE 1
#define CONFIG_USB_NET_SMSC75XX_MODULE 1
#define CONFIG_HAVE_ARCH_VMAP_STACK 1
#define CONFIG_NETFILTER_XT_MATCH_IPVS_MODULE 1
#define CONFIG_NET_CLS_BPF 1
#define CONFIG_NFS_V4_1_IMPLEMENTATION_ID_DOMAIN "kernel.org"
#define CONFIG_BT_LE_L2CAP_ECRED 1
#define CONFIG_IP_SET_MAX 256
#define CONFIG_HID_WACOM_MODULE 1
#define CONFIG_USB_F_ACM_MODULE 1
#define CONFIG_ARM64_ERRATUM_1319367 1
#define CONFIG_USB_SERIAL_CP210X_MODULE 1
#define CONFIG_RTC_LIB 1
#define CONFIG_NET_SCH_SFQ_MODULE 1
#define CONFIG_FW_LOADER_PAGED_BUF 1
#define CONFIG_USB_UEAGLEATM_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_POLICY_MODULE 1
#define CONFIG_ARM64_ERRATUM_826319 1
#define CONFIG_HAVE_KPROBES 1
#define CONFIG_FB_TFT_AGM1264K_FL_MODULE 1
#define CONFIG_SND_DESIGNWARE_PCM 1
#define CONFIG_IP_ROUTE_CLASSID 1
#define CONFIG_NETFILTER_XT_TARGET_TEE_MODULE 1
#define CONFIG_ENC28J60_MODULE 1
#define CONFIG_USB_SERIAL_XSENS_MT_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_ITM 1
#define CONFIG_CRYPTO_AES_MODULE 1
#define CONFIG_HAVE_GENERIC_VDSO 1
#define CONFIG_DVB_DIB7000P_MODULE 1
#define CONFIG_GPIOLIB 1
#define CONFIG_ARCH_WANT_DEFAULT_TOPDOWN_MMAP_LAYOUT 1
#define CONFIG_SSB_MODULE 1
#define CONFIG_FUTEX_PI 1
#define CONFIG_CLK_BCM2711_DVP 1
#define CONFIG_DM_BIO_PRISON_MODULE 1
#define CONFIG_GENERIC_CPU_VULNERABILITIES 1
#define CONFIG_VIDEO_EM28XX_RC_MODULE 1
#define CONFIG_NFT_LIMIT_MODULE 1
#define CONFIG_RADIO_TEA5764_MODULE 1
#define CONFIG_DVB_LNBH25_MODULE 1
#define CONFIG_PINCTRL_MCP23S08_MODULE 1
#define CONFIG_USB_GSPCA_SPCA1528_MODULE 1
#define CONFIG_HID_PID 1
#define CONFIG_USB_SERIAL_QT2_MODULE 1
#define CONFIG_SND_SOC_PCM179X_MODULE 1
#define CONFIG_AUTOFS_FS 1
#define CONFIG_GAMEPORT_MODULE 1
#define CONFIG_ISO9660_FS_MODULE 1
#define CONFIG_NETFILTER_XT_NAT_MODULE 1
#define CONFIG_BT_HCIUART_H4 1
#define CONFIG_USB_CONFIGFS_F_MIDI 1
#define CONFIG_DMA_NONCOHERENT_MMAP 1
#define CONFIG_RTC_DRV_DS3232_MODULE 1
#define CONFIG_CLKSRC_MMIO 1
#define CONFIG_RTC_DRV_RPI 1
#define CONFIG_SND_PCM_ELD 1
#define CONFIG_DVB_USB_M920X_MODULE 1
#define CONFIG_UIO_MODULE 1
#define CONFIG_NVMEM_RMEM_MODULE 1
#define CONFIG_SND_BCM2708_SOC_GOOGLEVOICEHAT_SOUNDCARD_MODULE 1
#define CONFIG_HID_WALTOP_MODULE 1
#define CONFIG_BACKLIGHT_LM3630A_MODULE 1
#define CONFIG_B43LEGACY_DEBUG 1
#define CONFIG_MEDIA_PCI_HAILO_MODULE 1
#define CONFIG_ARM_ARCH_TIMER_OOL_WORKAROUND 1
#define CONFIG_NET_VENDOR_AQUANTIA 1
#define CONFIG_NF_CONNTRACK_MARK 1
#define CONFIG_NETFILTER 1
#define CONFIG_NFT_REJECT_IPV4_MODULE 1
#define CONFIG_RC_LOOPBACK_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_HASHLIMIT_MODULE 1
#define CONFIG_BRIDGE_EBT_AMONG_MODULE 1
#define CONFIG_B43_PIO 1
#define CONFIG_B43_BUSES_BCMA_AND_SSB 1
#define CONFIG_HAVE_ARCH_KASAN 1
#define CONFIG_BME680_MODULE 1
#define CONFIG_NET_VENDOR_SMSC 1
#define CONFIG_NETFILTER_NETLINK_ACCT_MODULE 1
#define CONFIG_BOSCH_BNO055_I2C_MODULE 1
#define CONFIG_GENERIC_ARCH_TOPOLOGY 1
#define CONFIG_NFS_DISABLE_UDP_SUPPORT 1
#define CONFIG_NETFILTER_XT_MATCH_CLUSTER_MODULE 1
#define CONFIG_USB_KC2190 1
#define CONFIG_F2FS_FS_COMPRESSION 1
#define CONFIG_USB_MDC800_MODULE 1
#define CONFIG_6LOWPAN_MODULE 1
#define CONFIG_SERIO_SERPORT_MODULE 1
#define CONFIG_NLS_CODEPAGE_950_MODULE 1
#define CONFIG_DVB_STV0297_MODULE 1
#define CONFIG_DVB_TTUSB_DEC_MODULE 1
#define CONFIG_CLONE_BACKWARDS 1
#define CONFIG_LEDS_TRIGGER_ONESHOT 1
#define CONFIG_HAVE_NMI 1
#define CONFIG_LIRC 1
#define CONFIG_BT_BNEP_MODULE 1
#define CONFIG_NET_SCH_QFQ_MODULE 1
#define CONFIG_DVB_TDA826X_MODULE 1
#define CONFIG_BLK_DEV_RAM_COUNT 16
#define CONFIG_RD_XZ 1
#define CONFIG_HAVE_PREEMPT_DYNAMIC_KEY 1
#define CONFIG_AUXILIARY_BUS 1
#define CONFIG_IP_MROUTE 1
#define CONFIG_PREEMPT_RCU 1
#define CONFIG_SND_SOC_TLV320AIC23_MODULE 1
#define CONFIG_CRYPTO_ECDH_MODULE 1
#define CONFIG_ATA_VERBOSE_ERROR 1
#define CONFIG_MT76_USB_MODULE 1
#define CONFIG_NF_CONNTRACK_SNMP_MODULE 1
#define CONFIG_SND_DRIVERS 1
#define CONFIG_USB_SERIAL_BELKIN_MODULE 1
#define CONFIG_W1_MASTER_DS2490_MODULE 1
#define CONFIG_MEDIA_TUNER_MT2266_MODULE 1
#define CONFIG_NET_FLOW_LIMIT 1
#define CONFIG_XFS_FS_MODULE 1
#define CONFIG_INPUT_KEYSPAN_REMOTE_MODULE 1
#define CONFIG_USB_GSPCA_PAC7302_MODULE 1
#define CONFIG_LOCKDEP_SUPPORT 1
#define CONFIG_NLS_CODEPAGE_869_MODULE 1
#define CONFIG_NET_SCH_CAKE_MODULE 1
#define CONFIG_IP6_NF_TARGET_MASQUERADE_MODULE 1
#define CONFIG_NFT_REDIR_MODULE 1
#define CONFIG_TOUCHSCREEN_EGALAX_MODULE 1
#define CONFIG_CRYPTO_LIB_CURVE25519_GENERIC_MODULE 1
#define CONFIG_SPI_BCM2835AUX_MODULE 1
#define CONFIG_ARCH_WANT_COMPAT_IPC_PARSE_VERSION 1
#define CONFIG_NO_HZ 1
#define CONFIG_ARCH_WANT_HUGE_PMD_SHARE 1
#define CONFIG_NFT_TUNNEL_MODULE 1
#define CONFIG_POSIX_MQUEUE 1
#define CONFIG_CC_HAS_WORKING_NOSANITIZE_ADDRESS 1
#define CONFIG_NETFILTER_INGRESS 1
#define CONFIG_CRYPTO_LIB_GF128MUL_MODULE 1
#define CONFIG_SERIAL_8250_BCM7271 1
#define CONFIG_SND_BCM2708_SOC_PIFI_40_MODULE 1
#define CONFIG_USB_NET_CDC_MBIM_MODULE 1
#define CONFIG_USB_DWC3_OF_SIMPLE 1
#define CONFIG_PSTORE_RAM 1
#define CONFIG_CPU_FREQ_STAT 1
#define CONFIG_JFS_STATISTICS 1
#define CONFIG_NET_XGRESS 1
#define CONFIG_GENERIC_STRNCPY_FROM_USER 1
#define CONFIG_VIDEO_IMX296_MODULE 1
#define CONFIG_MEDIA_PLATFORM_SUPPORT 1
#define CONFIG_FB_TFT_SSD1331_MODULE 1
#define CONFIG_MTD_BLKDEVS_MODULE 1
#define CONFIG_DVB_TDA10086_MODULE 1
#define CONFIG_HAVE_RSEQ 1
#define CONFIG_NET_SCH_MQPRIO_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_NETMAP_MODULE 1
#define CONFIG_ARM64_ERRATUM_858921 1
#define CONFIG_OF_KOBJ 1
#define CONFIG_CONTEXT_TRACKING_IDLE 1
#define CONFIG_SENSORS_EMC2305_MODULE 1
#define CONFIG_FB_BCM2708 1
#define CONFIG_DVB_NXT6000_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_SCTP_MODULE 1
#define CONFIG_SMS_SIANO_RC 1
#define CONFIG_SND_PCM_OSS_PLUGINS 1
#define CONFIG_NET_VENDOR_DEC 1
#define CONFIG_NLS_ISO8859_15_MODULE 1
#define CONFIG_INET6_ESP_MODULE 1
#define CONFIG_QRTR_MODULE 1
#define CONFIG_IP_VS_WRR_MODULE 1
#define CONFIG_NET_NSH_MODULE 1
#define CONFIG_ILLEGAL_POINTER_VALUE 0xdead000000000000
#define CONFIG_GENERIC_GETTIMEOFDAY 1
#define CONFIG_CAN_MCP251XFD_MODULE 1
#define CONFIG_F2FS_IOSTAT 1
#define CONFIG_NETFILTER_XT_SET_MODULE 1
#define CONFIG_OF_CONFIGFS 1
#define CONFIG_ARCH_USE_MEMTEST 1
#define CONFIG_TASKSTATS 1
#define CONFIG_NLS_CODEPAGE_932_MODULE 1
#define CONFIG_JFS_POSIX_ACL 1
#define CONFIG_PPPOE_HASH_BITS 4
#define CONFIG_NET_VENDOR_PENSANDO 1
#define CONFIG_IP6_NF_FILTER_MODULE 1
#define CONFIG_SYSTEM_DATA_VERIFICATION 1
#define CONFIG_INPUT_MOUSEDEV_SCREEN_X 1024
#define CONFIG_EFI_ESRT 1
#define CONFIG_NEED_DMA_MAP_STATE 1
#define CONFIG_FB_TFT_ILI9340_MODULE 1
#define CONFIG_IIO_MODULE 1
#define CONFIG_SND_HDA_PREALLOC_SIZE 64
#define CONFIG_GARP_MODULE 1
#define CONFIG_RT2500USB_MODULE 1
#define CONFIG_BLK_DEV_DRBD_MODULE 1
#define CONFIG_IP_VS_PROTO_TCP 1
#define CONFIG_ISCSI_BOOT_SYSFS_MODULE 1
#define CONFIG_NET_SCH_RED_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_NFACCT_MODULE 1
#define CONFIG_HAVE_ARCH_KASAN_SW_TAGS 1
#define CONFIG_NETFILTER_XT_MATCH_CONNBYTES_MODULE 1
#define CONFIG_KDB_CONTINUE_CATASTROPHIC 0
#define CONFIG_F2FS_FS_LZ4HC 1
#define CONFIG_USB_SERIAL_METRO_MODULE 1
#define CONFIG_USB_PRINTER_MODULE 1
#define CONFIG_FONT_8x8 1
#define CONFIG_SSB_SPROM 1
#define CONFIG_USB_GSPCA_PAC207_MODULE 1
#define CONFIG_NET_VENDOR_ATHEROS 1
#define CONFIG_USB_SERIAL_IR_MODULE 1
#define CONFIG_FB_SIMPLE 1
#define CONFIG_RELOCATABLE 1
#define CONFIG_CRYPTO_POLY1305_MODULE 1
#define CONFIG_QUEUED_SPINLOCKS 1
#define CONFIG_XOR_BLOCKS 1
#define CONFIG_HID_TWINHAN_MODULE 1
#define CONFIG_TIME_NS 1
#define CONFIG_DMABUF_HEAPS_CMA 1
#define CONFIG_CRYPTO_SHA3_ARM64_MODULE 1
#define CONFIG_NET_VENDOR_SUN 1
#define CONFIG_DMIID 1
#define CONFIG_PANIC_TIMEOUT 0
#define CONFIG_SENSORS_DS1621_MODULE 1
#define CONFIG_NF_NAT_OVS 1
#define CONFIG_INPUT_JOYSTICK 1
#define CONFIG_NET_ACT_SIMP_MODULE 1
#define CONFIG_RT2X00_LIB_MODULE 1
#define CONFIG_USB_DWC2_MODULE 1
#define CONFIG_HID_BATTERY_STRENGTH 1
#define CONFIG_YAM_MODULE 1
#define CONFIG_W1_SLAVE_DS28E17_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_ECN_MODULE 1
#define CONFIG_USB_GSPCA_STV0680_MODULE 1
#define CONFIG_ATH9K_PCOEM 1
#define CONFIG_USB_STORAGE_SDDR55_MODULE 1
#define CONFIG_HAVE_ARCH_SECCOMP 1
#define CONFIG_FB_TFT_S6D02A1_MODULE 1
#define CONFIG_IP_NF_TARGET_TTL_MODULE 1
#define CONFIG_STACKDEPOT 1
#define CONFIG_LWTUNNEL_BPF 1
#define CONFIG_CFG80211_DEFAULT_PS 1
#define CONFIG_USBIP_HOST_MODULE 1
#define CONFIG_NET_VENDOR_XILINX 1
#define CONFIG_DECOMPRESS_LZ4 1
#define CONFIG_SND_SOC_ADAU7002_MODULE 1
#define CONFIG_ARM_SMCCC_SOC_ID 1
#define CONFIG_NETFILTER_NETLINK_OSF_MODULE 1
#define CONFIG_IP6_NF_MATCH_SRH_MODULE 1
#define CONFIG_POWER_RESET_GPIO 1
#define CONFIG_DVB_OR51132_MODULE 1
#define CONFIG_RT2X00_LIB_FIRMWARE 1
#define CONFIG_VIDEO_V4L2_I2C 1
#define CONFIG_BPF_SYSCALL 1
#define CONFIG_SMP 1
#define CONFIG_NET_VENDOR_CADENCE 1
#define CONFIG_DVB_ZL10353_MODULE 1
#define CONFIG_NET_VENDOR_MICROSOFT 1
#define CONFIG_TTY 1
#define CONFIG_NETFILTER_XT_MATCH_TIME_MODULE 1
#define CONFIG_IP_VS_MODULE 1
#define CONFIG_MT76x02_USB_MODULE 1
#define CONFIG_ZSMALLOC_MODULE 1
#define CONFIG_NET_VENDOR_I825XX 1
#define CONFIG_USB_XUSBATM_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_MAC_MODULE 1
#define CONFIG_IOMMU_DMA 1
#define CONFIG_RCU_EXP_CPU_STALL_TIMEOUT 0
#define CONFIG_NET_ACT_PEDIT_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_NFLOG_MODULE 1
#define CONFIG_DVB_ZD1301_DEMOD_MODULE 1
#define CONFIG_XFRM_OFFLOAD 1
#define CONFIG_TOUCHSCREEN_USB_JASTEC 1
#define CONFIG_GENERIC_ALLOCATOR 1
#define CONFIG_OPENVSWITCH_MODULE 1
#define CONFIG_RTC_DRV_DS1390_MODULE 1
#define CONFIG_L2TP_MODULE 1
#define CONFIG_DVB_B2C2_FLEXCOP_USB_MODULE 1
#define CONFIG_MMC_SDHCI_IO_ACCESSORS 1
#define CONFIG_HAVE_DYNAMIC_FTRACE_WITH_DIRECT_CALLS 1
#define CONFIG_FB_SYSMEM_HELPERS_DEFERRED 1
#define CONFIG_TCP_CONG_WESTWOOD_MODULE 1
#define CONFIG_RTC_DRV_M41T93_MODULE 1
#define CONFIG_KALLSYMS_ALL 1
#define CONFIG_USB_GSPCA_SPCA561_MODULE 1
#define CONFIG_COMMON_CLK_RP1 1
#define CONFIG_LIBCRC32C 1
#define CONFIG_KEYBOARD_MATRIX_MODULE 1
#define CONFIG_GENERIC_BUG 1
#define CONFIG_CRYPTO_SHA256 1
#define CONFIG_HAVE_FTRACE_MCOUNT_RECORD 1
#define CONFIG_VIDEO_AU0828_MODULE 1
#define CONFIG_POSIX_TIMERS 1
#define CONFIG_PSTORE_CONSOLE 1
#define CONFIG_INET_TCP_DIAG_MODULE 1
#define CONFIG_HID_SONY_MODULE 1
#define CONFIG_VIDEO_PVRUSB2_DVB 1
#define CONFIG_USB_F_PRINTER_MODULE 1
#define CONFIG_HW_CONSOLE 1
#define CONFIG_MDIO_BITBANG_MODULE 1
#define CONFIG_NET_ACT_IPT_MODULE 1
#define CONFIG_ZSMALLOC_CHAIN_SIZE 8
#define CONFIG_DVB_AS102_MODULE 1
#define CONFIG_HAVE_KVM_IRQ_ROUTING 1
#define CONFIG_RAS 1
#define CONFIG_VIDEO_GO7007_LOADER_MODULE 1
#define CONFIG_SMSC_PHY 1
#define CONFIG_DEVMEM 1
#define CONFIG_SECURITY_APPARMOR_INTROSPECT_POLICY 1
#define CONFIG_ARM_PMU 1
#define CONFIG_USB_GSPCA_ZC3XX_MODULE 1
#define CONFIG_CRYPTO_LIB_SHA1 1
#define CONFIG_SND_SPI 1
#define CONFIG_NFT_LOG_MODULE 1
#define CONFIG_BRIDGE_EBT_IP_MODULE 1
#define CONFIG_HID_MONTEREY_MODULE 1
#define CONFIG_CGROUP_RDMA 1
#define CONFIG_USB_SERIAL_CYPRESS_M8_MODULE 1
#define CONFIG_ARCH_USES_PG_ARCH_X 1
#define CONFIG_HID_EZKEY_MODULE 1
#define CONFIG_USB_PULSE8_CEC_MODULE 1
#define CONFIG_DVB_S5H1409_MODULE 1
#define CONFIG_MDIO_BCM_UNIMAC 1
#define CONFIG_DM_THIN_PROVISIONING_MODULE 1
#define CONFIG_HAVE_UID16 1
#define CONFIG_COMPAT_OLD_SIGACTION 1
#define CONFIG_W1_SLAVE_DS2438_MODULE 1
#define CONFIG_IRQ_MSI_IOMMU 1
#define CONFIG_RTC_NVMEM 1
#define CONFIG_JOYSTICK_XPAD_LEDS 1
#define CONFIG_TINYDRM_ILI9486_MODULE 1
#define CONFIG_BACKLIGHT_PWM_MODULE 1
#define CONFIG_BT_MRVL_MODULE 1
#define CONFIG_QUOTACTL 1
#define CONFIG_RTC_DRV_RX8581_MODULE 1
#define CONFIG_V4L2_MEM2MEM_DEV_MODULE 1
#define CONFIG_NLS_UCS2_UTILS_MODULE 1
#define CONFIG_CRYPTO_CRYPTD_MODULE 1
#define CONFIG_ZSTD_COMMON 1
#define CONFIG_NF_SOCKET_IPV4_MODULE 1
#define CONFIG_JOYSTICK_FSIA6B_MODULE 1
#define CONFIG_HAVE_IOREMAP_PROT 1
#define CONFIG_BUILTIN_RETURN_ADDRESS_STRIPS_PAC 1
#define CONFIG_CC_HAS_KASAN_GENERIC 1
#define CONFIG_DVB_STV6111_MODULE 1
#define CONFIG_USBIP_VHCI_HCD_MODULE 1
#define CONFIG_HAVE_ARM_SMCCC 1
#define CONFIG_DEBUG_KERNEL 1
#define CONFIG_INV_MPU6050_IIO_MODULE 1
#define CONFIG_DM_ZONED_MODULE 1
#define CONFIG_VIDEO_CX2341X_MODULE 1
#define CONFIG_SND_BCM2708_SOC_HIFIBERRY_DACPLUSADCPRO_MODULE 1
#define CONFIG_CHARLCD_MODULE 1
#define CONFIG_LOCALVERSION "-MANJARO-RPI4"
#define CONFIG_REISERFS_FS_SECURITY 1
#define CONFIG_DVB_STV6110x_MODULE 1
#define CONFIG_ARCH_HAS_SYNC_DMA_FOR_CPU 1
#define CONFIG_GENERIC_IRQ_EFFECTIVE_AFF_MASK 1
#define CONFIG_ARCH_SUPPORTS_PAGE_TABLE_CHECK 1
#define CONFIG_RADIO_ADAPTERS_MODULE 1
#define CONFIG_NFSD_V2 1
#define CONFIG_NFS_FSCACHE 1
#define CONFIG_MAC80211_MESH 1
#define CONFIG_USB_GSPCA_TOPRO_MODULE 1
#define CONFIG_USB_GSPCA_MARS_MODULE 1
#define CONFIG_CAN_RAW_MODULE 1
#define CONFIG_SYMBOLIC_ERRNAME 1
#define CONFIG_DVB_SI2165_MODULE 1
#define CONFIG_CRYPTO 1
#define CONFIG_I2C_MUX_PCA954x_MODULE 1
#define CONFIG_FUNCTION_TRACER 1
#define CONFIG_DRM_PANEL_SITRONIX_ST7701_MODULE 1
#define CONFIG_USB_TRANCEVIBRATOR_MODULE 1
#define CONFIG_SCHED_DEBUG 1
#define CONFIG_NET_VENDOR_BROCADE 1
#define CONFIG_BTRFS_FS 1
#define CONFIG_BLK_WBT_MQ 1
#define CONFIG_DEFAULT_MMAP_MIN_ADDR 4096
#define CONFIG_SYSTEM_TRUSTED_KEYS ""
#define CONFIG_SND_USB_6FIRE_MODULE 1
#define CONFIG_INPUT_AD714X_I2C_MODULE 1
#define CONFIG_MEDIA_TUNER_TDA18218_MODULE 1
#define CONFIG_IP_NF_IPTABLES_MODULE 1
#define CONFIG_CMDLINE "console=ttyAMA0,115200 kgdboc=ttyAMA0,115200 root=/dev/mmcblk0p2 rootfstype=ext4 rootwait"
#define CONFIG_VSOCKETS_MODULE 1
#define CONFIG_BT_BNEP_PROTO_FILTER 1
#define CONFIG_SENSORS_DRIVETEMP_MODULE 1
#define CONFIG_NET_VENDOR_QLOGIC 1
#define CONFIG_SPI_GPIO_MODULE 1
#define CONFIG_DRM_PANEL_TPO_Y17P_MODULE 1
#define CONFIG_USB_GSPCA_CPIA1_MODULE 1
#define CONFIG_GCC10_NO_ARRAY_BOUNDS 1
#define CONFIG_RUNTIME_TESTING_MENU 1
#define CONFIG_VIDEOBUF2_DMA_CONTIG_MODULE 1
#define CONFIG_USB_XHCI_HCD 1
#define CONFIG_DEFAULT_CUBIC 1
#define CONFIG_HID_SAMSUNG_MODULE 1
#define CONFIG_IP_SET_LIST_SET_MODULE 1
#define CONFIG_IP_PIMSM_V2 1
#define CONFIG_CFS_BANDWIDTH 1
#define CONFIG_RTW88_MODULE 1
#define CONFIG_HW_PERF_EVENTS 1
#define CONFIG_NET_SELFTESTS 1
#define CONFIG_MUX_GPIO_MODULE 1
#define CONFIG_XFRM_STATISTICS 1
#define CONFIG_VIDEO_TW2804_MODULE 1
#define CONFIG_USB_ISIGHTFW_MODULE 1
#define CONFIG_DMA_VIRTUAL_CHANNELS 1
#define CONFIG_ZSWAP_COMPRESSOR_DEFAULT "lzo"
#define CONFIG_SND_SEQ_HRTIMER_DEFAULT 1
#define CONFIG_USB_ARCH_HAS_HCD 1
#define CONFIG_DVB_DIB3000MC_MODULE 1
#define CONFIG_CACHEFILES 1
#define CONFIG_DVB_MXL5XX_MODULE 1
#define CONFIG_NET_REDIRECT 1
#define CONFIG_GENERIC_IRQ_SHOW 1
#define CONFIG_TINYDRM_REPAPER_MODULE 1
#define CONFIG_BCM2712_MIP 1
#define CONFIG_NVMEM_SYSFS 1
#define CONFIG_HAVE_ARCH_JUMP_LABEL_RELATIVE 1
#define CONFIG_ARCH_HAS_ELF_RANDOMIZE 1
#define CONFIG_9P_FS_MODULE 1
#define CONFIG_NETFS_SUPPORT 1
#define CONFIG_HAVE_FUNCTION_ARG_ACCESS_API 1
#define CONFIG_PANIC_ON_OOPS_VALUE 0
#define CONFIG_NET_VENDOR_SAMSUNG 1
#define CONFIG_NET_VENDOR_ADI 1
#define CONFIG_IIO_MS_SENSORS_I2C_MODULE 1
#define CONFIG_ZRAM_DEF_COMP "lzo-rle"
#define CONFIG_SOC_BRCMSTB 1
#define CONFIG_INITRAMFS_PRESERVE_MTIME 1
#define CONFIG_SCSI_MOD 1
#define CONFIG_NET_VENDOR_MICREL 1
#define CONFIG_CRYPTO_ESSIV_MODULE 1
#define CONFIG_FB_TFT_UPD161704_MODULE 1
#define CONFIG_F2FS_FS_POSIX_ACL 1
#define CONFIG_VIDEOBUF2_DMA_SG_MODULE 1
#define CONFIG_USB_SERIAL_SPCP8X5_MODULE 1
#define CONFIG_RC_DECODERS 1
#define CONFIG_B43_LEDS 1
#define CONFIG_UBIFS_FS_XATTR 1
#define CONFIG_P54_USB_MODULE 1
#define CONFIG_USB_GSPCA_KINECT_MODULE 1
#define CONFIG_USB_SERIAL_WISHBONE_MODULE 1
#define CONFIG_USB_NET_HUAWEI_CDC_NCM_MODULE 1
#define CONFIG_CRYPTO_CRC32C 1
#define CONFIG_SERIAL_CORE 1
#define CONFIG_FUSE_FS_MODULE 1
#define CONFIG_USB_CONFIGFS_SERIAL 1
#define CONFIG_UID16 1
#define CONFIG_SND_SOC_PCM512x_MODULE 1
#define CONFIG_HID_MICROSOFT_MODULE 1
#define CONFIG_EXFAT_DEFAULT_IOCHARSET "utf8"
#define CONFIG_HAVE_KVM_DIRTY_RING 1
#define CONFIG_RTC_DRV_S35390A_MODULE 1
#define CONFIG_HAVE_KRETPROBES 1
#define CONFIG_ASSOCIATIVE_ARRAY 1
#define CONFIG_USB_CONFIGFS_F_UVC 1
#define CONFIG_NF_DEFRAG_IPV6_MODULE 1
#define CONFIG_USB_GSPCA_CONEX_MODULE 1
#define CONFIG_MICREL_PHY 1
#define CONFIG_DRM_LOAD_EDID_FIRMWARE 1
#define CONFIG_VIDEO_DEV_MODULE 1
#define CONFIG_CC_HAS_ZERO_CALL_USED_REGS 1
#define CONFIG_NFS_V4 1
#define CONFIG_PPP_FILTER 1
#define CONFIG_DYNAMIC_FTRACE 1
#define CONFIG_MAILBOX 1
#define CONFIG_INPUT_LEDS 1
#define CONFIG_RCU_NEED_SEGCBLIST 1
#define CONFIG_XFS_SUPPORT_V4 1
#define CONFIG_HAS_DMA 1
#define CONFIG_NF_CT_PROTO_SCTP 1
#define CONFIG_USB_SERIAL_VISOR_MODULE 1
#define CONFIG_BROADCOM_PHY 1
#define CONFIG_USB_DWCOTG 1
#define CONFIG_DVB_AS102_FE_MODULE 1
#define CONFIG_SND_SOC_CS42XX8_I2C_MODULE 1
#define CONFIG_SCSI 1
#define CONFIG_CC_HAVE_STACKPROTECTOR_SYSREG 1
#define CONFIG_ARCH_BINFMT_ELF_STATE 1
#define CONFIG_LEDS_TRIGGER_PANIC 1
#define CONFIG_DVB_CXD2841ER_MODULE 1
#define CONFIG_FB_CFB_FILLRECT 1
#define CONFIG_AT76C50X_USB_MODULE 1
#define CONFIG_NF_NAT_PPTP_MODULE 1
#define CONFIG_FUNCTION_GRAPH_TRACER 1
#define CONFIG_ARM64_ERRATUM_1542419 1
#define CONFIG_HID_CHICONY_MODULE 1
#define CONFIG_HAVE_ARCH_THREAD_STRUCT_WHITELIST 1
#define CONFIG_HID 1
#define CONFIG_CC_HAS_BRANCH_PROT_PAC_RET 1
#define CONFIG_VIDEO_VIVID_MODULE 1
#define CONFIG_DMA_DECLARE_COHERENT 1
#define CONFIG_LIBERTAS_THINFIRM_USB_MODULE 1
#define CONFIG_CGROUP_NET_PRIO 1
#define CONFIG_RANDOMIZE_BASE 1
#define CONFIG_USB_CONFIGFS_F_UAC1 1
#define CONFIG_USB_DWC3_DUAL_ROLE 1
#define CONFIG_VIDEO_VICODEC_MODULE 1
#define CONFIG_ANDROID_BINDERFS 1
#define CONFIG_SLIP_SMART 1
#define CONFIG_NLS_ISO8859_9_MODULE 1
#define CONFIG_SND_SERIAL_U16550_MODULE 1
#define CONFIG_USB_ARMLINUX 1
#define CONFIG_IP_VS_PE_SIP_MODULE 1
#define CONFIG_RTLWIFI_MODULE 1
#define CONFIG_MT76_CORE_MODULE 1
#define CONFIG_LEDS_TRIGGER_DEFAULT_ON 1
#define CONFIG_FONT_8x16 1
#define CONFIG_FUNCTION_ALIGNMENT_8B 1
#define CONFIG_NET_VENDOR_MELLANOX 1
#define CONFIG_MAC80211_HWSIM_MODULE 1
#define CONFIG_DVB_LGDT330X_MODULE 1
#define CONFIG_SERIAL_8250_FSL 1
#define CONFIG_ARCH_ENABLE_MEMORY_HOTPLUG 1
#define CONFIG_CRYPTO_USER_API_AEAD_MODULE 1
#define CONFIG_ARCH_HAS_CURRENT_STACK_POINTER 1
#define CONFIG_PTP_1588_CLOCK 1
#define CONFIG_NF_DUP_NETDEV_MODULE 1
#define CONFIG_VHOST_CROSS_ENDIAN_LEGACY 1
#define CONFIG_IEEE802154_DRIVERS_MODULE 1
#define CONFIG_RTC_DRV_RV3029_HWMON 1
#define CONFIG_TCP_CONG_BBR_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_IRTOUCH 1
#define CONFIG_USB_PWC_MODULE 1
#define CONFIG_SQUASHFS_FRAGMENT_CACHE_SIZE 3
#define CONFIG_MEDIA_TUNER_TDA8290_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_PANJIT 1
#define CONFIG_BONDING_MODULE 1
#define CONFIG_SQUASHFS_COMPILE_DECOMP_SINGLE 1
#define CONFIG_MEDIA_TUNER_TDA18212_MODULE 1
#define CONFIG_MCP3422_MODULE 1
#define CONFIG_RTC_DRV_EM3027_MODULE 1
#define CONFIG_ARCH_HAS_CACHE_LINE_SIZE 1
#define CONFIG_6LOWPAN_NHC_DEST_MODULE 1
#define CONFIG_VEML6070_MODULE 1
#define CONFIG_JBD2 1
#define CONFIG_USBIP_CORE_MODULE 1
#define CONFIG_SPARSEMEM_VMEMMAP 1
#define CONFIG_SND_BCM2708_SOC_RPI_DAC_MODULE 1
#define CONFIG_INET6_IPCOMP_MODULE 1
#define CONFIG_MEMCG_KMEM 1
#define CONFIG_NET_VENDOR_MARVELL 1
#define CONFIG_PHYLIB 1
#define CONFIG_REGULATOR_GPIO 1
#define CONFIG_IPV6_TUNNEL_MODULE 1
#define CONFIG_NET_VENDOR_NVIDIA 1
#define CONFIG_DVB_TDA665x_MODULE 1
#define CONFIG_CRYPTO_SHA256_ARM64_MODULE 1
#define CONFIG_NLS_CODEPAGE_874_MODULE 1
#define CONFIG_IRQ_DOMAIN 1
#define CONFIG_INTEGRITY_AUDIT 1
#define CONFIG_PPS_CLIENT_LDISC_MODULE 1
#define CONFIG_ARCH_HAS_DEBUG_VIRTUAL 1
#define CONFIG_MEDIA_TUNER_MT20XX_MODULE 1
#define CONFIG_IIO_HRTIMER_TRIGGER_MODULE 1
#define CONFIG_JFFS2_RTIME 1
#define CONFIG_HAVE_ASM_MODVERSIONS 1
#define CONFIG_IPC_NS 1
#define CONFIG_CRYPTO_LIB_CHACHA20POLY1305_MODULE 1
#define CONFIG_CRYPTO_SHA512_ARM64_MODULE 1
#define CONFIG_DVB_HORUS3A_MODULE 1
#define CONFIG_MISC_FILESYSTEMS 1
#define CONFIG_ARCH_MMAP_RND_BITS_MIN 18
#define CONFIG_FTRACE 1
#define CONFIG_NETFILTER_XT_MATCH_CONNLIMIT_MODULE 1
#define CONFIG_IP_NF_RAW_MODULE 1
#define CONFIG_ARCH_SUPPORTS_LTO_CLANG 1
#define CONFIG_IP_NF_ARPFILTER_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_ETT_TC45USB 1
#define CONFIG_W1_CON 1
#define CONFIG_NETFILTER_XT_MATCH_SOCKET_MODULE 1
#define CONFIG_PPPOL2TP_MODULE 1
#define CONFIG_FB_TFT_TLS8204_MODULE 1
#define CONFIG_R8712U_MODULE 1
#define CONFIG_HID_TOPSEED_MODULE 1
#define CONFIG_B43_PHY_HT 1
#define CONFIG_DECOMPRESS_BZIP2 1
#define CONFIG_CORDIC_MODULE 1
#define CONFIG_ATH9K_RFKILL 1
#define CONFIG_PER_VMA_LOCK 1
#define CONFIG_ARCH_SUPPORTS_UPROBES 1
#define CONFIG_NET_VENDOR_STMICRO 1
#define CONFIG_OF_DYNAMIC 1
#define CONFIG_NF_NAT_H323_MODULE 1
#define CONFIG_XZ_DEC_SPARC 1
#define CONFIG_V4L2_CCI_MODULE 1
#define CONFIG_SECURITY_APPARMOR_EXPORT_BINARY 1
#define CONFIG_JFFS2_SUMMARY 1
#define CONFIG_USB_NET_QMI_WWAN_MODULE 1
#define CONFIG_ARCH_HAS_SYNC_DMA_FOR_DEVICE 1
#define CONFIG_INPUT_CMA3000_MODULE 1
#define CONFIG_OF_GPIO 1
#define CONFIG_CEC_NOTIFIER 1
#define CONFIG_FB_TFT_S6D1121_MODULE 1
#define CONFIG_ARCH_SUPPORTS_HUGETLBFS 1
#define CONFIG_GACT_PROB 1
#define CONFIG_SERIAL_MCTRL_GPIO 1
#define CONFIG_REALTEK_PHY_MODULE 1
#define CONFIG_HID_A4TECH_MODULE 1
#define CONFIG_MEDIA_TUNER_MC44S803_MODULE 1
#define CONFIG_NLS_CODEPAGE_860_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_ESP_MODULE 1
#define CONFIG_ARM64_ERRATUM_2441009 1
#define CONFIG_SND_BCM2708_SOC_RPI_CIRRUS_MODULE 1
#define CONFIG_SND_BCM2708_SOC_DIONAUDIO_LOCO_MODULE 1
#define CONFIG_IP_NF_TARGET_NETMAP_MODULE 1
#define CONFIG_DST_CACHE 1
#define CONFIG_USB_GSPCA_SPCA505_MODULE 1
#define CONFIG_KVM_GENERIC_HARDWARE_ENABLING 1
#define CONFIG_NF_REJECT_IPV6_MODULE 1
#define CONFIG_RCU_CPU_STALL_TIMEOUT 21
#define CONFIG_USB_GSPCA_SQ905C_MODULE 1
#define CONFIG_POSIX_CPU_TIMERS_TASK_WORK 1
#define CONFIG_CHECKPOINT_RESTORE 1
#define CONFIG_RTC_DRV_ISL1208_MODULE 1
#define CONFIG_SND_SOC_CS4265_MODULE 1
#define CONFIG_SND_DIGIDAC1_SOUNDCARD_MODULE 1
#define CONFIG_SND_VERBOSE_PROCFS 1
#define CONFIG_BPF_LIRC_MODE2 1
#define CONFIG_BT_HCIUART_BCM 1
#define CONFIG_PWM_RP1 1
#define CONFIG_VIDEO_RPIVID_MODULE 1
#define CONFIG_IP_ROUTE_MULTIPATH 1
#define CONFIG_RTC_DRV_PCF2123_MODULE 1
#define CONFIG_DVB_LNBP21_MODULE 1
#define CONFIG_DVB_TDA10048_MODULE 1
#define CONFIG_INPUT_FF_MEMLESS_MODULE 1
#define CONFIG_USB_CONFIGFS_F_PRINTER 1
#define CONFIG_CHR_DEV_SG_MODULE 1
#define CONFIG_IP_SET_HASH_NET_MODULE 1
#define CONFIG_ARM64_ERRATUM_819472 1
#define CONFIG_LLD_VERSION 0
#define CONFIG_SECTION_MISMATCH_WARN_ONLY 1
#define CONFIG_ARM64_ERRATUM_827319 1
#define CONFIG_HW_RANDOM_BCM2835 1
#define CONFIG_SSB_DRIVER_PCICORE_POSSIBLE 1
#define CONFIG_NETFILTER_EGRESS 1
#define CONFIG_CAVIUM_TX2_ERRATUM_219 1
#define CONFIG_MDIO_DEVICE 1
#define CONFIG_NEED_SG_DMA_LENGTH 1
#define CONFIG_TIMER_PROBE 1
#define CONFIG_MODPROBE_PATH "/sbin/modprobe"
#define CONFIG_SND_MPU401_MODULE 1
#define CONFIG_DVB_CX24116_MODULE 1
#define CONFIG_POWER_RESET 1
#define CONFIG_CRYPTO_XCBC_MODULE 1
#define CONFIG_NF_NAT_AMANDA_MODULE 1
#define CONFIG_BRIDGE_EBT_MARK_MODULE 1
#define CONFIG_DRM_DISPLAY_HELPER_MODULE 1
#define CONFIG_IR_GPIO_CIR_MODULE 1
#define CONFIG_IP6_NF_MATCH_IPV6HEADER_MODULE 1
#define CONFIG_VIDEO_OV5647_MODULE 1
#define CONFIG_ARM64_EPAN 1
#define CONFIG_MACVLAN_MODULE 1
#define CONFIG_L2TP_V3 1
#define CONFIG_BPF_JIT 1
#define CONFIG_INV_MPU6050_I2C_MODULE 1
#define CONFIG_NINTENDO_FF 1
#define CONFIG_IIO_INTERRUPT_TRIGGER_MODULE 1
#define CONFIG_VIDEO_IMX708_MODULE 1
#define CONFIG_SENSORS_INA2XX_MODULE 1
#define CONFIG_JOYSTICK_IFORCE_MODULE 1
#define CONFIG_PROFILING 1
#define CONFIG_INTERVAL_TREE 1
#define CONFIG_FB_TFT_ST7735R_MODULE 1
#define CONFIG_SND_SOC_WM8731_MODULE 1
#define CONFIG_NET_VENDOR_AMAZON 1
#define CONFIG_SPARSEMEM 1
#define CONFIG_BLK_MQ_STACKING 1
#define CONFIG_CRYPTO_ARC4_MODULE 1
#define CONFIG_DRM_GEM_SHMEM_HELPER_MODULE 1
#define CONFIG_HD44780_MODULE 1
#define CONFIG_IEEE802154_6LOWPAN_MODULE 1
#define CONFIG_VHOST_NET_MODULE 1
#define CONFIG_WLAN_VENDOR_ATMEL 1
#define CONFIG_NET_VENDOR_HISILICON 1
#define CONFIG_DVB_STV0900_MODULE 1
#define CONFIG_USB_SERIAL_DIGI_ACCELEPORT_MODULE 1
#define CONFIG_USB_GL860_MODULE 1
#define CONFIG_GRACE_PERIOD 1
#define CONFIG_SLHC_MODULE 1
#define CONFIG_NET_VENDOR_TEHUTI 1
#define CONFIG_CRYPTO_MANAGER 1
#define CONFIG_NET_SCH_HTB_MODULE 1
#define CONFIG_ARCH_HAS_SUBPAGE_FAULTS 1
#define CONFIG_EEPROM_AT24_MODULE 1
#define CONFIG_PPP_BSDCOMP_MODULE 1
#define CONFIG_DVB_USB_TTUSB2_MODULE 1
#define CONFIG_EDAC_SUPPORT 1
#define CONFIG_RT_MUTEXES 1
#define CONFIG_LOCK_SPIN_ON_OWNER 1
#define CONFIG_HID_ORTEK_MODULE 1
#define CONFIG_VIDEO_V4L2_TPG_MODULE 1
#define CONFIG_KEYBOARD_CAP11XX_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_MARK_MODULE 1
#define CONFIG_NFT_SYNPROXY_MODULE 1
#define CONFIG_HID_ASUS_MODULE 1
#define CONFIG_FSL_ERRATUM_A008585 1
#define CONFIG_RTW88_8822CU_MODULE 1
#define CONFIG_NVIDIA_CARMEL_CNP_ERRATUM 1
#define CONFIG_AR5523_MODULE 1
#define CONFIG_PCI_SYSCALL 1
#define CONFIG_CC_NO_ARRAY_BOUNDS 1
#define CONFIG_MEDIA_TUNER_MXL5007T_MODULE 1
#define CONFIG_MD_LINEAR_MODULE 1
#define CONFIG_DVB_TDA10021_MODULE 1
#define CONFIG_VIDEO_CX231XX_DVB_MODULE 1
#define CONFIG_SLAB_MERGE_DEFAULT 1
#define CONFIG_KERNFS 1
#define CONFIG_CXD2880_SPI_DRV_MODULE 1
#define CONFIG_I2C_ALGOBIT_MODULE 1
#define CONFIG_IPV6_SUBTREES 1
#define CONFIG_MMC_BLOCK 1
#define CONFIG_NET_CLS_FW_MODULE 1
#define CONFIG_KVM 1
#define CONFIG_PAGE_COUNTER 1
#define CONFIG_IOMMU_DEFAULT_DMA_STRICT 1
#define CONFIG_SND_SIMPLE_CARD_MODULE 1
#define CONFIG_W1_SLAVE_DS2781_MODULE 1
#define CONFIG_SND_PCI 1
#define CONFIG_EXPERT 1
#define CONFIG_IR_SANYO_DECODER_MODULE 1
#define CONFIG_CFG80211_CRDA_SUPPORT 1
#define CONFIG_RTW88_8723D_MODULE 1
#define CONFIG_VIDEO_MT9V011_MODULE 1
#define CONFIG_WIRELESS 1
#define CONFIG_WEXT_PROC 1
#define CONFIG_CRYPTO_AES_ARM64_CE_BLK_MODULE 1
#define CONFIG_BCMA_DRIVER_PCI 1
#define CONFIG_SQUASHFS_MODULE 1
#define CONFIG_6LOWPAN_NHC_MODULE 1
#define CONFIG_HZ_250 1
#define CONFIG_ARCH_HAS_STRICT_KERNEL_RWX 1
#define CONFIG_NFT_DUP_IPV6_MODULE 1
#define CONFIG_MMC_BCM2835_PIO_DMA_BARRIER 2
#define CONFIG_USB_GSPCA_KONICA_MODULE 1
#define CONFIG_LOCK_DEBUGGING_SUPPORT 1
#define CONFIG_SND_SOC_ICS43432_MODULE 1
#define CONFIG_NET_SCH_TBF_MODULE 1
#define CONFIG_BT_HCIBTUSB_MODULE 1
#define CONFIG_PKCS7_MESSAGE_PARSER 1
#define CONFIG_FB_TFT_ILI9481_MODULE 1
#define CONFIG_IRQ_SIM 1
#define CONFIG_DVB_CX22702_MODULE 1
#define CONFIG_KGDB 1
#define CONFIG_STAGING_MEDIA_DEPRECATED 1
#define CONFIG_SERIO_RAW_MODULE 1
#define CONFIG_TASK_IO_ACCOUNTING 1
#define CONFIG_NF_LOG_SYSLOG_MODULE 1
#define CONFIG_FAT_DEFAULT_IOCHARSET "ascii"
#define CONFIG_USBIP_VHCI_NR_HCS 1
#define CONFIG_VIDEO_IMX258_MODULE 1
#define CONFIG_ASYNC_XOR_MODULE 1
#define CONFIG_USB_CONFIGFS_MASS_STORAGE 1
#define CONFIG_FB_TFT_ILI9163_MODULE 1
#define CONFIG_DVB_STB6100_MODULE 1
#define CONFIG_MD_RAID0_MODULE 1
#define CONFIG_FRAME_WARN 2048
#define CONFIG_NET_VENDOR_AGERE 1
#define CONFIG_USB_NET_CDC_NCM_MODULE 1
#define CONFIG_UVC_COMMON_MODULE 1
#define CONFIG_HID_GENERIC 1
#define CONFIG_ARCH_MMAP_RND_BITS 18
#define CONFIG_QCOM_FALKOR_ERRATUM_E1041 1
#define CONFIG_USB_ETH_MODULE 1
#define CONFIG_ARM64_ERRATUM_1530923 1
#define CONFIG_VIDEO_VIM2M_MODULE 1
#define CONFIG_FB_TFT_ILI9320_MODULE 1
#define CONFIG_SND_SOC_ADAU1701_MODULE 1
#define CONFIG_GENERIC_HWEIGHT 1
#define CONFIG_INITRAMFS_SOURCE ""
#define CONFIG_RTL_CARDS_MODULE 1
#define CONFIG_ARCH_MHP_MEMMAP_ON_MEMORY_ENABLE 1
#define CONFIG_DHT11_MODULE 1
#define CONFIG_VIDEO_ARDUCAM_PIVARIETY_MODULE 1
#define CONFIG_TASKS_TRACE_RCU 1
#define CONFIG_CGROUPS 1
#define CONFIG_SND_USB_CAIAQ_INPUT 1
#define CONFIG_MMC 1
#define CONFIG_LZO_COMPRESS 1
#define CONFIG_GUEST_PERF_EVENTS 1
#define CONFIG_HAVE_ARCH_MMAP_RND_COMPAT_BITS 1
#define CONFIG_TOUCHSCREEN_USB_GUNZE 1
#define CONFIG_CRYPTO_SEQIV_MODULE 1
#define CONFIG_BRCMFMAC_MODULE 1
#define CONFIG_TTY_PRINTK 1
#define CONFIG_HID_LOGITECH_MODULE 1
#define CONFIG_DM_LOG_USERSPACE_MODULE 1
#define CONFIG_DM_AUDIT 1
#define CONFIG_CRYPTO_USER_API_RNG_MODULE 1
#define CONFIG_HAVE_GCC_PLUGINS 1
#define CONFIG_PINCTRL_BCM2712 1
#define CONFIG_DYNAMIC_EVENTS 1
#define CONFIG_REGULATOR_RASPBERRYPI_TOUCHSCREEN_V2_MODULE 1
#define CONFIG_DVB_SP887X_MODULE 1
#define CONFIG_STACKTRACE 1
#define CONFIG_HAVE_PCI 1
#define CONFIG_EXTCON 1
#define CONFIG_AUDIT_COMPAT_GENERIC 1
#define CONFIG_RTW88_8723DU_MODULE 1
#define CONFIG_IPV6_GRE_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_IDLETIMER_MODULE 1
#define CONFIG_BCM2835_VCHIQ_MMAL_MODULE 1
#define CONFIG_USB_NET_RNDIS_WLAN_MODULE 1
#define CONFIG_ARCH_SUPPORTS_DEBUG_PAGEALLOC 1
#define CONFIG_VIDEO_TUNER_MODULE 1
#define CONFIG_IFB_MODULE 1
#define CONFIG_HAS_IOPORT 1
#define CONFIG_USB_SEVSEG_MODULE 1
#define CONFIG_CC_HAS_SIGN_RETURN_ADDRESS 1
#define CONFIG_SND_MPU401_UART_MODULE 1
#define CONFIG_PHYLIB_LEDS 1
#define CONFIG_IPV6_VTI_MODULE 1
#define CONFIG_CRYPTO_DRBG 1
#define CONFIG_RTC_DRV_PCF8563_MODULE 1
#define CONFIG_SND_MAX_CARDS 32
#define CONFIG_MEDIA_TUNER_MSI001_MODULE 1
#define CONFIG_OF_EARLY_FLATTREE 1
#define CONFIG_DVB_USB_V2_MODULE 1
#define CONFIG_USB_CDC_COMPOSITE_MODULE 1
#define CONFIG_USB_DSBR_MODULE 1
#define CONFIG_KGDB_KDB 1
#define CONFIG_DRM_PANEL_ILITEK_ILI9806E_MODULE 1
#define CONFIG_XILLYBUS_CLASS_MODULE 1
#define CONFIG_WLAN_VENDOR_ADMTEK 1
#define CONFIG_CGROUP_CPUACCT 1
#define CONFIG_USB_SERIAL_OTI6858_MODULE 1
#define CONFIG_SERIAL_SC16IS7XX_CORE_MODULE 1
#define CONFIG_VIDEO_GO7007_USB_MODULE 1
#define CONFIG_CAN_BCM_MODULE 1
#define CONFIG_HAS_IOPORT_MAP 1
#define CONFIG_HAVE_FAST_GUP 1
#define CONFIG_ARM64_PA_BITS 48
#define CONFIG_NET_VENDOR_VIA 1
#define CONFIG_UBIFS_FS_SECURITY 1
#define CONFIG_USB_ATM_MODULE 1
#define CONFIG_HZ 250
#define CONFIG_SERIAL_8250_SHARE_IRQ 1
#define CONFIG_MT76x2U_MODULE 1
#define CONFIG_SND_BCM2708_SOC_HIFIBERRY_DIGI_MODULE 1
#define CONFIG_IXGBE_HWMON 1
#define CONFIG_USB_RTL8152_MODULE 1
#define CONFIG_USB_CONFIGFS_F_UAC2 1
#define CONFIG_I2C_HELPER_AUTO 1
#define CONFIG_NETFILTER_XT_MATCH_U32_MODULE 1
#define CONFIG_KVM_XFER_TO_GUEST_WORK 1
#define CONFIG_VIDEO_SONY_BTF_MPX_MODULE 1
#define CONFIG_SQUASHFS_ZLIB 1
#define CONFIG_HISILICON_ERRATUM_161010101 1
#define CONFIG_NLS_ISO8859_4_MODULE 1
#define CONFIG_SERIAL_8250_PERICOM 1
#define CONFIG_FB_BACKLIGHT_MODULE 1
#define CONFIG_RTC_DRV_RX8025_MODULE 1
#define CONFIG_SERIAL_8250_NR_UARTS 5
#define CONFIG_ARCH_HAS_STRICT_MODULE_RWX 1
#define CONFIG_ARM64_WORKAROUND_CLEAN_CACHE 1
#define CONFIG_IR_GPIO_TX_MODULE 1
#define CONFIG_NET_EMATCH_IPSET_MODULE 1
#define CONFIG_CC_IS_GCC 1
#define CONFIG_IR_IMON_MODULE 1
#define CONFIG_BCM7XXX_PHY 1
#define CONFIG_DMA_OPS 1
#define CONFIG_NET_EGRESS 1
#define CONFIG_NET_VENDOR_ARC 1
#define CONFIG_FB_TFT_BD663474_MODULE 1
#define CONFIG_INET_AH_MODULE 1
#define CONFIG_AS_HAS_CFI_NEGATE_RA_STATE 1
#define CONFIG_RANDOMIZE_KSTACK_OFFSET 1
#define CONFIG_CRYPTO_SM4_ARM64_CE_MODULE 1
#define CONFIG_MTD_UBI_BEB_LIMIT 20
#define CONFIG_SETEND_EMULATION 1
#define CONFIG_UDF_FS_MODULE 1
#define CONFIG_NFT_SOCKET_MODULE 1
#define CONFIG_HAVE_PERF_USER_STACK_DUMP 1
#define CONFIG_CGROUP_PERF 1
#define CONFIG_NLATTR 1
#define CONFIG_ZD1211RW_MODULE 1
#define CONFIG_TCP_CONG_CUBIC 1
#define CONFIG_CEPH_FS_MODULE 1
#define CONFIG_NR_CPUS 256
#define CONFIG_IXGBE_MODULE 1
#define CONFIG_ARM64_ERRATUM_1418040 1
#define CONFIG_IIO_BUFFER_CB_MODULE 1
#define CONFIG_MMC_SDHCI 1
#define CONFIG_B43_SSB 1
#define CONFIG_SND_SUPPORT_OLD_API 1
#define CONFIG_DVB_DIB7000M_MODULE 1
#define CONFIG_NETFILTER_XT_CONNMARK_MODULE 1
#define CONFIG_SOCIONEXT_SYNQUACER_PREITS 1
#define CONFIG_LOGITECH_FF 1
#define CONFIG_DVB_AF9033_MODULE 1
#define CONFIG_IPV6_FOU_TUNNEL_MODULE 1
#define CONFIG_HID_KYE_MODULE 1
#define CONFIG_SND_SOC_ADAU1977_I2C_MODULE 1
#define CONFIG_CRYPTO_CHACHA20_MODULE 1
#define CONFIG_HID_GEMBIRD_MODULE 1
#define CONFIG_IP_MROUTE_MULTIPLE_TABLES 1
#define CONFIG_NFT_COMPAT_MODULE 1
#define CONFIG_LEDS_PCA963X_MODULE 1
#define CONFIG_SYSFS 1
#define CONFIG_IP_SET_BITMAP_IPMAC_MODULE 1
#define CONFIG_NETFS_STATS 1
#define CONFIG_USB_DEFAULT_PERSIST 1
#define CONFIG_AS_HAS_NON_CONST_LEB128 1
#define CONFIG_DVB_MN88473_MODULE 1
#define CONFIG_LIB80211_CRYPT_WEP_MODULE 1
#define CONFIG_INPUT_TOUCHSCREEN 1
#define CONFIG_RT2800USB_UNKNOWN 1
#define CONFIG_RADIO_SI4713_MODULE 1
#define CONFIG_DRM_PANEL_BRIDGE 1
#define CONFIG_USB_GSPCA_NW80X_MODULE 1
#define CONFIG_NF_CONNTRACK_LABELS 1
#define CONFIG_IP_NF_MATCH_AH_MODULE 1
#define CONFIG_CARL9170_WPC 1
#define CONFIG_ARM64_SVE 1
#define CONFIG_DVB_S5H1420_MODULE 1
#define CONFIG_COMMON_CLK_HIFIBERRY_DACPRO_MODULE 1
#define CONFIG_DVB_NET 1
#define CONFIG_MEDIA_CEC_RC 1
#define CONFIG_BLK_DEV_BSG_COMMON 1
#define CONFIG_ASN1 1
#define CONFIG_NETFILTER_XT_MATCH_LIMIT_MODULE 1
#define CONFIG_XZ_DEC_ARM 1
#define CONFIG_NLS_CODEPAGE_775_MODULE 1
#define CONFIG_USB_CONFIGFS_EEM 1
#define CONFIG_PTP_1588_CLOCK_OPTIONAL 1
#define CONFIG_FB_DMAMEM_HELPERS 1
#define CONFIG_CRYPTO_HASH_INFO 1
#define CONFIG_FB_SYS_FOPS 1
#define CONFIG_JOYSTICK_ANALOG_MODULE 1
#define CONFIG_HAVE_SYSCALL_TRACEPOINTS 1
#define CONFIG_HAVE_ARCH_HUGE_VMALLOC 1
#define CONFIG_MEDIA_TUNER_XC4000_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_DEVGROUP_MODULE 1
#define CONFIG_IO_WQ 1
#define CONFIG_DECOMPRESS_ZSTD 1
#define CONFIG_SND_SOC_TAS571X_MODULE 1
#define CONFIG_DVB_LGDT3305_MODULE 1
#define CONFIG_VIDEO_USBTV_MODULE 1
#define CONFIG_FB 1
#define CONFIG_TRACING 1
#define CONFIG_IIO_SYSFS_TRIGGER_MODULE 1
#define CONFIG_IP_NF_MATCH_RPFILTER_MODULE 1
#define CONFIG_PSI_DEFAULT_DISABLED 1
#define CONFIG_NLS_CODEPAGE_865_MODULE 1
#define CONFIG_TASKS_RUDE_RCU 1
#define CONFIG_I2C_COMPAT 1
#define CONFIG_DRM_SCHED_MODULE 1
#define CONFIG_WLAN_VENDOR_ZYDAS 1
#define CONFIG_INET_SCTP_DIAG_MODULE 1
#define CONFIG_NFSD_V3_ACL 1
#define CONFIG_USB_GSPCA_SPCA500_MODULE 1
#define CONFIG_SPARSEMEM_VMEMMAP_ENABLE 1
#define CONFIG_LEDS_TRIGGER_CPU 1
#define CONFIG_HID_ELO_MODULE 1
#define CONFIG_ARM_GIC_V3 1
#define CONFIG_IPVLAN_MODULE 1
#define CONFIG_ARCH_SUPPORTS_KEXEC_SIG 1
#define CONFIG_RTC_DRV_RV3028_MODULE 1
#define CONFIG_SND_SOC_DA7213_MODULE 1
#define CONFIG_NET_ACT_NAT_MODULE 1
#define CONFIG_FTRACE_MCOUNT_RECORD 1
#define CONFIG_OCFS2_FS_STATS 1
#define CONFIG_VIRTUALIZATION 1
#define CONFIG_MSDOS_PARTITION 1
#define CONFIG_DMA_BCM2835 1
#define CONFIG_RTC_I2C_AND_SPI 1
#define CONFIG_BT_HCIUART_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_NEXIO 1
#define CONFIG_RT2800USB_RT33XX 1
#define CONFIG_DVB_LNBP22_MODULE 1
#define CONFIG_SND_BCM2708_SOC_HIFIBERRY_DAC_MODULE 1
#define CONFIG_ARM64_TLB_RANGE 1
#define CONFIG_RASPBERRYPI_POWER 1
#define CONFIG_DVB_RTL2832_SDR_MODULE 1
#define CONFIG_HAVE_POSIX_CPU_TIMERS_TASK_WORK 1
#define CONFIG_USB_GSPCA_SN9C2028_MODULE 1
#define CONFIG_BMP280_I2C_MODULE 1
#define CONFIG_IR_STREAMZAP_MODULE 1
#define CONFIG_SND_BCM2708_SOC_ALLO_PIANO_DAC_MODULE 1
#define CONFIG_ARM_PSCI_FW 1
#define CONFIG_LEGACY_DIRECT_IO 1
#define CONFIG_IP_SET_MODULE 1
#define CONFIG_THERMAL 1
#define CONFIG_SYNC_FILE 1
#define CONFIG_USB_XHCI_PCI 1
#define CONFIG_INPUT_POWERMATE_MODULE 1
#define CONFIG_IP_PNP_RARP 1
#define CONFIG_BRCMUTIL_MODULE 1
#define CONFIG_BRCMSTB_L2_IRQ 1
#define CONFIG_DVB_TTUSB_BUDGET_MODULE 1
#define CONFIG_VETH_MODULE 1
#define CONFIG_RTC_DRV_PCF8583_MODULE 1
#define CONFIG_DVB_MT312_MODULE 1
#define CONFIG_DVB_USB_DIBUSB_MB_FAULTY 1
#define CONFIG_NET_VENDOR_3COM 1
#define CONFIG_HID_PETALYNX_MODULE 1
#define CONFIG_STACKPROTECTOR 1
#define CONFIG_IRQ_BYPASS_MANAGER 1
#define CONFIG_ARCH_ENABLE_SPLIT_PMD_PTLOCK 1
#define CONFIG_CMA_SIZE_MBYTES 5
#define CONFIG_CRYPTO_LIB_CHACHA_MODULE 1
#define CONFIG_NET_ACT_MIRRED_MODULE 1
#define CONFIG_HAVE_ARCH_KGDB 1
#define CONFIG_SND_SOC_I_SABRE_CODEC_MODULE 1
#define CONFIG_VIDEO_IMX477_MODULE 1
#define CONFIG_ARCH_USE_QUEUED_SPINLOCKS 1
#define CONFIG_NF_TPROXY_IPV4_MODULE 1
#define CONFIG_B43_PCICORE_AUTOSELECT 1
#define CONFIG_BLK_DEBUG_FS 1
#define CONFIG_USB_VL600_MODULE 1
#define CONFIG_ARCH_HAS_ZONE_DMA_SET 1
#define CONFIG_B43LEGACY_HWRNG 1
#define CONFIG_ATH9K_BTCOEX_SUPPORT 1
#define CONFIG_SND_DUMMY_MODULE 1
#define CONFIG_VIDEOBUF2_V4L2_MODULE 1
#define CONFIG_CPU_FREQ_GOV_SCHEDUTIL 1
#define CONFIG_NET_VENDOR_INTEL 1
#define CONFIG_HAVE_SOFTIRQ_ON_OWN_STACK 1
#define CONFIG_ARM64_WORKAROUND_REPEAT_TLBI 1
#define CONFIG_RPS 1
#define CONFIG_PACKET_DIAG_MODULE 1
#define CONFIG_DVB_AU8522_DTV_MODULE 1
#define CONFIG_USB_NET_ZAURUS_MODULE 1
#define CONFIG_SERIAL_8250_EXAR 1
#define CONFIG_INET6_XFRM_TUNNEL_MODULE 1
#define CONFIG_PROC_PID_CPUSET 1
#define CONFIG_SND_RPI_SIMPLE_SOUNDCARD_MODULE 1
#define CONFIG_QCA7000_MODULE 1
#define CONFIG_REALTEK_AUTOPM 1
#define CONFIG_USB_NET_AX88179_178A_MODULE 1
#define CONFIG_NF_TABLES_BRIDGE_MODULE 1
#define CONFIG_HW_RANDOM_IPROC_RNG200 1
#define CONFIG_BATTERY_GAUGE_LTC2941_MODULE 1
#define CONFIG_PM_GENERIC_DOMAINS 1
#define CONFIG_MEDIA_TUNER_E4000_MODULE 1
#define CONFIG_IPV6_FOU_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_DMC_TSC10 1
#define CONFIG_GENERIC_CSUM 1
#define CONFIG_DVB_ZL10039_MODULE 1
#define CONFIG_MTD_MAP_BANK_WIDTH_2 1
#define CONFIG_USB_AUDIO_MODULE 1
#define CONFIG_NFT_REJECT_MODULE 1
#define CONFIG_USB_SERIAL_DEBUG_MODULE 1
#define CONFIG_IP_SET_HASH_IPPORTIP_MODULE 1
#define CONFIG_GENERIC_IDLE_POLL_SETUP 1
#define CONFIG_NET_EMATCH_NBYTE_MODULE 1
#define CONFIG_RESET_SIMPLE 1
#define CONFIG_FB_TFT_UC1611_MODULE 1
#define CONFIG_PWM_BRCMSTB 1
#define CONFIG_USB_BDC_UDC 1
#define CONFIG_ZISOFS 1
#define CONFIG_WLAN_VENDOR_MEDIATEK 1
#define CONFIG_CUSE_MODULE 1
#define CONFIG_USB_ZERO_MODULE 1
#define CONFIG_NF_TABLES_IPV4 1
#define CONFIG_IP_MULTICAST 1
#define CONFIG_DM_CACHE_SMQ_MODULE 1
#define CONFIG_DVB_MT352_MODULE 1
#define CONFIG_RC_ATI_REMOTE_MODULE 1
#define CONFIG_SQUASHFS_XZ 1
#define CONFIG_USB_NET_CX82310_ETH_MODULE 1
#define CONFIG_NET_VENDOR_CISCO 1
#define CONFIG_HID_LOGITECH_DJ_MODULE 1
#define CONFIG_ARCH_HAS_PTE_DEVMAP 1
#define CONFIG_VIDEO_STK1160_MODULE 1
#define CONFIG_CRYPTO_DH 1
#define CONFIG_TICK_ONESHOT 1
#define CONFIG_XFS_SUPPORT_ASCII_CI 1
#define CONFIG_HID_BETOP_FF_MODULE 1
#define CONFIG_USB_SERIAL_SIERRAWIRELESS_MODULE 1
#define CONFIG_CRYPTO_CTR_MODULE 1
#define CONFIG_AS_HAS_ARMV8_2 1
#define CONFIG_XARRAY_MULTI 1
#define CONFIG_LOCK_MM_AND_FIND_VMA 1
#define CONFIG_DVB_STV090x_MODULE 1
#define CONFIG_B43LEGACY_PCICORE_AUTOSELECT 1
#define CONFIG_USB_CONFIGFS_F_LB_SS 1
#define CONFIG_USB_SERIAL_KEYSPAN_PDA_MODULE 1
#define CONFIG_WIRELESS_EXT 1
#define CONFIG_MEDIA_TUNER_MT2060_MODULE 1
#define CONFIG_RESET_BRCMSTB_RESCAL 1
#define CONFIG_RTC_DRV_RS5C348_MODULE 1
#define CONFIG_MODVERSIONS 1
#define CONFIG_HW_RANDOM 1
#define CONFIG_B43_PCI_AUTOSELECT 1
#define CONFIG_MUTEX_SPIN_ON_OWNER 1
#define CONFIG_DVB_USB_AU6610_MODULE 1
#define CONFIG_BT_HCIBTUSB_RTL 1
#define CONFIG_VIRTIO_VSOCKETS_COMMON_MODULE 1
#define CONFIG_SND_SOC_WM8804_I2C_MODULE 1
#define CONFIG_CGROUP_NET_CLASSID 1
#define CONFIG_NETFILTER_SYNPROXY_MODULE 1
#define CONFIG_NLS_CODEPAGE_737_MODULE 1
#define CONFIG_HAVE_FUNCTION_GRAPH_TRACER 1
#define CONFIG_I2C_DESIGNWARE_PLATFORM_MODULE 1
#define CONFIG_BUFFER_HEAD 1
#define CONFIG_CRYPTO_LIB_POLY1305_GENERIC_MODULE 1
#define CONFIG_ARM64_AMU_EXTN 1
#define CONFIG_OF_MDIO 1
#define CONFIG_HAVE_CMPXCHG_LOCAL 1
#define CONFIG_VIDEOBUF2_CORE_MODULE 1
#define CONFIG_DVB_HELENE_MODULE 1
#define CONFIG_RANDOMIZE_MODULE_REGION_FULL 1
#define CONFIG_SMB_SERVER_CHECK_CAP_NET_ADMIN 1
#define CONFIG_CRYPTO_BLAKE2B 1
#define CONFIG_INPUT_ADXL34X_I2C_MODULE 1
#define CONFIG_TREE_SRCU 1
#define CONFIG_CRYPTO_NULL2_MODULE 1
#define CONFIG_NTFS_FS_MODULE 1
#define CONFIG_VIDEO_AU0828_V4L2 1
#define CONFIG_RT2X00_LIB_CRYPTO 1
#define CONFIG_CRYPTO_LIB_DES 1
#define CONFIG_IP_SCTP_MODULE 1
#define CONFIG_DVB_STB0899_MODULE 1
#define CONFIG_FUNCTION_ALIGNMENT_4B 1
#define CONFIG_BASE_SMALL 0
#define CONFIG_RTL8187_MODULE 1
#define CONFIG_VIDEO_CMDLINE 1
#define CONFIG_SND_SEQ_DUMMY_MODULE 1
#define CONFIG_B43LEGACY_PCI_AUTOSELECT 1
#define CONFIG_DM_RAID_MODULE 1
#define CONFIG_COMPACTION 1
#define CONFIG_BCM7120_L2_IRQ 1
#define CONFIG_NFS_V2 1
#define CONFIG_DVB_TDA18271C2DD_MODULE 1
#define CONFIG_DVB_CXD2820R_MODULE 1
#define CONFIG_BCM2835_THERMAL 1
#define CONFIG_NF_DUP_IPV6_MODULE 1
#define CONFIG_Z3FOLD_MODULE 1
#define CONFIG_USB_GSPCA_SONIXJ_MODULE 1
#define CONFIG_GPIO_STMPE 1
#define CONFIG_STMPE_I2C 1
#define CONFIG_RPI_POE_POWER_MODULE 1
#define CONFIG_USB_SERIAL_F81232_MODULE 1
#define CONFIG_BLK_CGROUP_PUNT_BIO 1
#define CONFIG_CRYPTO_KHAZAD_MODULE 1
#define CONFIG_PROC_FS 1
#define CONFIG_MTD_BLOCK_MODULE 1
#define CONFIG_CRYPTO_USER_API_ENABLE_OBSOLETE 1
#define CONFIG_VIDEOBUF2_VMALLOC_MODULE 1
#define CONFIG_NFT_BRIDGE_REJECT_MODULE 1
#define CONFIG_GENERIC_BUG_RELATIVE_POINTERS 1
#define CONFIG_6LOWPAN_NHC_FRAGMENT_MODULE 1
#define CONFIG_RC_MAP 1
#define CONFIG_WEXT_PRIV 1
#define CONFIG_MMU_GATHER_RCU_TABLE_FREE 1
#define CONFIG_NET_VENDOR_ROCKER 1
#define CONFIG_XFRM_AH_MODULE 1
#define CONFIG_SCSI_LOWLEVEL 1
#define CONFIG_CRYPTO_DH_RFC7919_GROUPS 1
#define CONFIG_ROSE_MODULE 1
#define CONFIG_INPUT_GPIO_ROTARY_ENCODER_MODULE 1
#define CONFIG_IP_VS_PROTO_AH_ESP 1
#define CONFIG_MEMFD_CREATE 1
#define CONFIG_IRQ_FORCED_THREADING 1
#define CONFIG_ARM64_CONT_PTE_SHIFT 4
#define CONFIG_NILFS2_FS_MODULE 1
#define CONFIG_ATH9K_PCI 1
#define CONFIG_USB_F_HID_MODULE 1
#define CONFIG_NLS_ISO8859_3_MODULE 1
#define CONFIG_CRYPTO_CMAC_MODULE 1
#define CONFIG_MEDIA_TUNER_TDA18250_MODULE 1
#define CONFIG_HID_PANTHERLORD_MODULE 1
#define CONFIG_DRM_FBDEV_EMULATION 1
#define CONFIG_SND_MODULE 1
#define CONFIG_ARCH_HAVE_ELF_PROT 1
#define CONFIG_NET_SCH_TEQL_MODULE 1
#define CONFIG_SND_SOC_TAS5713_MODULE 1
#define CONFIG_IR_RC6_DECODER_MODULE 1
#define CONFIG_SND_BCM2708_SOC_HIFIBERRY_DACPLUSDSP_MODULE 1
#define CONFIG_PINCTRL_MCP23S08_I2C_MODULE 1
#define CONFIG_IP_VS_SH_MODULE 1
#define CONFIG_GPIO_FSM_MODULE 1
#define CONFIG_VIDEO_MSP3400_MODULE 1
#define CONFIG_ARCH_USE_GNU_PROPERTY 1
#define CONFIG_USB_F_OBEX_MODULE 1
#define CONFIG_TCG_TIS_SPI_MODULE 1
#define CONFIG_MT7921_COMMON_MODULE 1
#define CONFIG_USB_PEGASUS_MODULE 1
#define CONFIG_FB_TFT_UC1701_MODULE 1
#define CONFIG_USB_TMC_MODULE 1
#define CONFIG_NET_VRF_MODULE 1
#define CONFIG_USB_G_WEBCAM_MODULE 1
#define CONFIG_LD_ORPHAN_WARN 1
#define CONFIG_V4L_PLATFORM_DRIVERS 1
#define CONFIG_W1_SLAVE_DS2408_READBACK 1
#define CONFIG_RFKILL_INPUT 1
#define CONFIG_NET_VENDOR_NATSEMI 1
#define CONFIG_BLK_DEV_BSGLIB 1
#define CONFIG_MEDIA_TUNER_FC2580_MODULE 1
#define CONFIG_USB_DWC3_HAPS 1
#define CONFIG_USB_F_MASS_STORAGE_MODULE 1
#define CONFIG_ATH9K_COMMON_MODULE 1
#define CONFIG_IKCONFIG_MODULE 1
#define CONFIG_NFT_XFRM_MODULE 1
#define CONFIG_NET_VENDOR_GOOGLE 1
#define CONFIG_DVB_STB6000_MODULE 1
#define CONFIG_FW_CS_DSP_MODULE 1
#define CONFIG_USB_SERIAL_QCAUX_MODULE 1
#define CONFIG_NET_VENDOR_NETRONOME 1
#define CONFIG_COMMON_CLK_RP1_SDIO 1
#define CONFIG_NFS_USE_KERNEL_DNS 1
#define CONFIG_ARCH_HAS_FORTIFY_SOURCE 1
#define CONFIG_GCC_VERSION 120100
#define CONFIG_CRYPTO_LIB_POLY1305_RSIZE 9
#define CONFIG_DRM_RP1_DSI_MODULE 1
#define CONFIG_SYSCTL 1
#define CONFIG_CC_CAN_LINK_STATIC 1
#define CONFIG_ARCH_HAS_GCOV_PROFILE_ALL 1
#define CONFIG_SND_USB_AUDIO_USE_MEDIA_CONTROLLER 1
#define CONFIG_DRM_RP1_VEC_MODULE 1
#define CONFIG_BRIDGE_IGMP_SNOOPING 1
#define CONFIG_MTD_BLOCK2MTD_MODULE 1
#define CONFIG_W1_SLAVE_THERM_MODULE 1
#define CONFIG_CAN_SLCAN_MODULE 1
#define CONFIG_SND_SOC_WM_ADSP_MODULE 1
#define CONFIG_PHYS_ADDR_T_64BIT 1
#define CONFIG_THREAD_INFO_IN_TASK 1
#define CONFIG_DVB_M88DS3103_MODULE 1
#define CONFIG_NET_VENDOR_LITEX 1
#define CONFIG_TOUCHSCREEN_STMPE_MODULE 1
#define CONFIG_HAVE_C_RECORDMCOUNT 1
#define CONFIG_GENERIC_MSI_IRQ 1
#define CONFIG_DYNAMIC_FTRACE_WITH_ARGS 1
#define CONFIG_MEDIA_TUNER_MT2131_MODULE 1
#define CONFIG_ARCH_BCM2835 1
#define CONFIG_HID_THINGM_MODULE 1
#define CONFIG_USB_NET_KALMIA_MODULE 1
#define CONFIG_IR_TTUSBIR_MODULE 1
#define CONFIG_USB_NET_DM9601_MODULE 1
#define CONFIG_HAVE_ARCH_TRACEHOOK 1
#define CONFIG_VIDEO_ISP_BCM2835_MODULE 1
#define CONFIG_SSB_PCIHOST 1
#define CONFIG_IR_MCEUSB_MODULE 1
#define CONFIG_PCI_DOMAINS_GENERIC 1
#define CONFIG_CIFS_MODULE 1
#define CONFIG_DRM_FBDEV_OVERALLOC 100
#define CONFIG_XFRM_USER 1
#define CONFIG_TCP_CONG_BIC_MODULE 1
#define CONFIG_CPUFREQ_DT_PLATDEV 1
#define CONFIG_BCM7038_L1_IRQ 1
#define CONFIG_LEDS_PCA9532_MODULE 1
#define CONFIG_TASK_DELAY_ACCT 1
#define CONFIG_CEC_PIN_ERROR_INJ 1
#define CONFIG_ARCH_HAS_NON_OVERLAPPING_ADDRESS_SPACE 1
#define CONFIG_NET_NS 1
#define CONFIG_REISERFS_FS_XATTR 1
#define CONFIG_HAVE_PERF_EVENTS 1
#define CONFIG_ATA_SFF 1
#define CONFIG_QRTR_TUN_MODULE 1
#define CONFIG_NET_EMATCH_CMP_MODULE 1
#define CONFIG_USB_GSPCA_T613_MODULE 1
#define CONFIG_SND_MTPAV_MODULE 1
#define CONFIG_PPP_ASYNC_MODULE 1
#define CONFIG_MD_RAID10_MODULE 1
#define CONFIG_HID_NINTENDO_MODULE 1
#define CONFIG_HAVE_ALIGNED_STRUCT_PAGE 1
#define CONFIG_SSB_SDIOHOST_POSSIBLE 1
#define CONFIG_NET_VENDOR_SOLARFLARE 1
#define CONFIG_CAN_GW_MODULE 1
#define CONFIG_NLS_CODEPAGE_866_MODULE 1
#define CONFIG_COMMON_CLK_HIFIBERRY_DACPLUSHD_MODULE 1
#define CONFIG_RADIO_SAA7706H_MODULE 1
#define CONFIG_TINYDRM_ILI9341_MODULE 1
#define CONFIG_LEDS_TRIGGER_TRANSIENT_MODULE 1
#define CONFIG_VIDEO_IRS1125_MODULE 1
#define CONFIG_HAVE_KVM_VCPU_RUN_PID_CHANGE 1
#define CONFIG_CEPH_FS_POSIX_ACL 1
#define CONFIG_DEBUG_MEMORY_INIT 1
#define CONFIG_XFRM_ESP_MODULE 1
#define CONFIG_AUDIT 1
#define CONFIG_CHR_DEV_ST_MODULE 1
#define CONFIG_ARCH_HAS_RESET_CONTROLLER 1
#define CONFIG_KERNEL_MODE_NEON 1
#define CONFIG_DVB_GP8PSK_FE_MODULE 1
#define CONFIG_V4L2_CCI_I2C_MODULE 1
#define CONFIG_THERMAL_DEFAULT_GOV_STEP_WISE 1
#define CONFIG_DM_MULTIPATH_MODULE 1
#define CONFIG_CRYPTO_USER_API_SKCIPHER_MODULE 1
#define CONFIG_NET_9P_FD_MODULE 1
#define CONFIG_CMA_AREAS 7
#define CONFIG_LTO_NONE 1
#define CONFIG_PCIEASPM 1
#define CONFIG_DEBUG_FS_ALLOW_ALL 1
#define CONFIG_MT76_LEDS 1
#define CONFIG_ARM_GIC_MAX_NR 1
#define CONFIG_B43LEGACY_MODULE 1
#define CONFIG_HID_MULTITOUCH_MODULE 1
#define CONFIG_RTW88_8821CU_MODULE 1
#define CONFIG_FB_DEFERRED_IO 1
#define CONFIG_SATA_AHCI_MODULE 1
#define CONFIG_SLAB_FREELIST_RANDOM 1
#define CONFIG_DVB_USB_A800_MODULE 1
#define CONFIG_SECURITY 1
#define CONFIG_I2C_SI470X_MODULE 1
#define CONFIG_DVB_A8293_MODULE 1
#define CONFIG_BLK_CGROUP_RWSTAT 1
#define CONFIG_MAX_SKB_FRAGS 17
#define CONFIG_HID_ELECOM_MODULE 1
#define CONFIG_FB_TFT_PCD8544_MODULE 1
#define CONFIG_SND_TIMER_MODULE 1
#define CONFIG_KVM_MMIO 1
#define CONFIG_RESET_BRCMSTB 1
#define CONFIG_FAT_DEFAULT_CODEPAGE 437
#define CONFIG_IPV6_MROUTE_MULTIPLE_TABLES 1
#define CONFIG_BLK_DEV 1
#define CONFIG_MAC80211_RC_DEFAULT "minstrel_ht"
#define CONFIG_RTL8187_LEDS 1
#define CONFIG_NFS_ACL_SUPPORT 1
#define CONFIG_RT2800USB_RT55XX 1
#define CONFIG_W1_SLAVE_DS2433_MODULE 1
#define CONFIG_USB_SERIAL_OMNINET_MODULE 1
#define CONFIG_BRIDGE_NETFILTER_MODULE 1
#define CONFIG_DVB_MB86A20S_MODULE 1
#define CONFIG_CC_HAS_ASM_GOTO_TIED_OUTPUT 1
#define CONFIG_OF_FLATTREE 1
#define CONFIG_HAVE_ARCH_KFENCE 1
#define CONFIG_WLAN_VENDOR_SILABS 1
#define CONFIG_IOMMU_API 1
#define CONFIG_GPIO_GENERIC 1
#define CONFIG_TRACING_SUPPORT 1
#define CONFIG_UNIX98_PTYS 1
#define CONFIG_NETFILTER_XT_TARGET_CONNMARK_MODULE 1
#define CONFIG_NET_RX_BUSY_POLL 1
#define CONFIG_RADIO_WL1273_MODULE 1
#define CONFIG_CRYPTO_MICHAEL_MIC_MODULE 1
#define CONFIG_NET_VENDOR_SOCIONEXT 1
#define CONFIG_PINCTRL_BCM2835 1
#define CONFIG_ZONE_DMA32 1
#define CONFIG_NET_SCHED 1
#define CONFIG_STAGING_MEDIA 1
#define CONFIG_DRM_PANEL 1
#define CONFIG_DVB_PLL_MODULE 1
#define CONFIG_SND_BCM2708_SOC_ALLO_BOSS_DAC_MODULE 1
#define CONFIG_PRINTK_TIME 1
#define CONFIG_VIDEO_VIVID_MAX_DEVS 64
#define CONFIG_INPUT_MOUSEDEV_SCREEN_Y 768
#define CONFIG_TRACE_IRQFLAGS_NMI_SUPPORT 1
#define CONFIG_TASKS_RCU_GENERIC 1
#define CONFIG_SECCOMP_FILTER 1
#define CONFIG_CLK_RASPBERRYPI 1
#define CONFIG_IRQCHIP 1
#define CONFIG_PPP_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_QUOTA_MODULE 1
#define CONFIG_TI_ST_MODULE 1
#define CONFIG_NET_SCH_PIE_MODULE 1
#define CONFIG_NFT_FIB_IPV4_MODULE 1
#define CONFIG_ASYNC_CORE_MODULE 1
#define CONFIG_NET_SCH_MULTIQ_MODULE 1
#define CONFIG_INET_DIAG_MODULE 1
#define CONFIG_CRYPTO_GHASH_MODULE 1
#define CONFIG_OCFS2_DEBUG_MASKLOG 1
#define CONFIG_SND_SOC_WM8741_MODULE 1
#define CONFIG_PSTORE 1
#define CONFIG_OVERLAY_FS_REDIRECT_ALWAYS_FOLLOW 1
#define CONFIG_DVB_MN88443X_MODULE 1
#define CONFIG_SND_BCM2708_SOC_HIFIBERRY_DACPLUSHD_MODULE 1
#define CONFIG_NF_NAT_FTP_MODULE 1
#define CONFIG_MAC80211_RC_MINSTREL 1
#define CONFIG_IIO_CONSUMERS_PER_TRIGGER 2
#define CONFIG_NF_CT_PROTO_UDPLITE 1
#define CONFIG_IKCONFIG_PROC 1
#define CONFIG_SPEAKUP_MODULE 1
#define CONFIG_IP6_NF_TARGET_SYNPROXY_MODULE 1
#define CONFIG_ELF_CORE 1
#define CONFIG_DEV_COREDUMP 1
#define CONFIG_DVB_LNBH29_MODULE 1
#define CONFIG_TEXTSEARCH 1
#define CONFIG_HAVE_DYNAMIC_FTRACE_WITH_CALL_OPS 1
#define CONFIG_USB_DWC3 1
#define CONFIG_DYNAMIC_FTRACE_WITH_DIRECT_CALLS 1
#define CONFIG_HAVE_CONTEXT_TRACKING_USER 1
#define CONFIG_USB_SUPPORT 1
#define CONFIG_RTC_DRV_BQ32K_MODULE 1
#define CONFIG_USB_GSPCA_PAC7311_MODULE 1
#define CONFIG_WLAN_VENDOR_ST 1
#define CONFIG_BLK_DEV_NVME 1
#define CONFIG_BRCMFMAC_PROTO_BCDC 1
#define CONFIG_SOC_BUS 1
#define CONFIG_I2C_BRCMSTB_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_EASYTOUCH 1
#define CONFIG_STAGING 1
#define CONFIG_NET_VENDOR_SIS 1
#define CONFIG_F2FS_FS 1
#define CONFIG_TOUCHSCREEN_EDT_FT5X06_MODULE 1
#define CONFIG_CC_HAS_AUTO_VAR_INIT_ZERO_BARE 1
#define CONFIG_DMA_CMA 1
#define CONFIG_WIZNET_W5100_SPI_MODULE 1
#define CONFIG_ATM_MODULE 1
#define CONFIG_PAGE_POOL 1
#define CONFIG_SERIAL_8250_16550A_VARIANTS 1
#define CONFIG_VIDEO_AD5398_MODULE 1
#define CONFIG_CRYPTO_SM4_MODULE 1
#define CONFIG_INIT_STACK_ALL_ZERO 1
#define CONFIG_ARM64_ERRATUM_2966298 1
#define CONFIG_VT_CONSOLE 1
#define CONFIG_HID_UCLOGIC_MODULE 1
#define CONFIG_SND_SOC_PCM186X_MODULE 1
#define CONFIG_LEDS_GPIO 1
#define CONFIG_SENSIRION_SGP30_MODULE 1
#define CONFIG_SCHED_INFO 1
#define CONFIG_USB_GSPCA_STK014_MODULE 1
#define CONFIG_MQ_IOSCHED_KYBER 1
#define CONFIG_IP_VS_FTP_MODULE 1
#define CONFIG_AS_VERSION 23800
#define CONFIG_SND_BCM2708_SOC_ALLO_DIGIONE_MODULE 1
#define CONFIG_CC_HAS_INT128 1
#define CONFIG_EFI_EARLYCON 1
#define CONFIG_CFG80211_WEXT 1
#define CONFIG_WLAN_VENDOR_MARVELL 1
#define CONFIG_NETFILTER_XT_MATCH_PHYSDEV_MODULE 1
#define CONFIG_NOP_USB_XCEIV 1
#define CONFIG_NET_SOCK_MSG 1
#define CONFIG_AUDIT_ARCH_COMPAT_GENERIC 1
#define CONFIG_CC_OPTIMIZE_FOR_PERFORMANCE 1
#define CONFIG_DVB_USB_DIBUSB_MB_MODULE 1
#define CONFIG_ARM64_CONT_PMD_SHIFT 4
#define CONFIG_SND_SEQ_MIDI_MODULE 1
#define CONFIG_BLK_DEV_RAM 1
#define CONFIG_USB_F_NCM_MODULE 1
#define CONFIG_SENSORS_AHT10_MODULE 1
#define CONFIG_ARCH_MMAP_RND_COMPAT_BITS 11
#define CONFIG_NETFILTER_XT_MATCH_STATE_MODULE 1
#define CONFIG_DVB_L64781_MODULE 1
#define CONFIG_LOGIRUMBLEPAD2_FF 1
#define CONFIG_CRYPTO_CAST_COMMON_MODULE 1
#define CONFIG_IIO_TRIGGERED_BUFFER_MODULE 1
#define CONFIG_RTC_DRV_PCF2127_MODULE 1
#define CONFIG_USB_STORAGE_FREECOM_MODULE 1
#define CONFIG_BRIDGE_EBT_LOG_MODULE 1
#define CONFIG_SND_SOC_PCM1794A_MODULE 1
#define CONFIG_MICROCHIP_PHY 1
#define CONFIG_TOUCHSCREEN_ADS7846_MODULE 1
#define CONFIG_OPENVSWITCH_VXLAN_MODULE 1
#define CONFIG_IR_RC5_DECODER_MODULE 1
#define CONFIG_NET_SCH_GRED_MODULE 1
#define CONFIG_ARM_TIMER_SP804 1
#define CONFIG_DRM_MODULE 1
#define CONFIG_DRM_PANEL_MIPI_DBI_MODULE 1
#define CONFIG_DMABUF_HEAPS_SYSTEM 1
#define CONFIG_MEDIA_RADIO_SUPPORT 1
#define CONFIG_PCIE_DPC 1
#define CONFIG_POSIX_MQUEUE_SYSCTL 1
#define CONFIG_ARM64 1
#define CONFIG_VHOST_MENU 1
#define CONFIG_RTC_DRV_MAX6900_MODULE 1
#define CONFIG_DRM_GUD_MODULE 1
#define CONFIG_PREEMPT 1
#define CONFIG_DEBUG_MISC 1
#define CONFIG_FB_CFB_COPYAREA 1
#define CONFIG_USB_F_ECM_MODULE 1
#define CONFIG_VIDEO_BCM2835_UNICAM_MODULE 1
#define CONFIG_DVB_RTL2830_MODULE 1
#define CONFIG_I40E_MODULE 1
#define CONFIG_BRIDGE_EBT_STP_MODULE 1
#define CONFIG_HAVE_KVM_IRQCHIP 1
#define CONFIG_RT73USB_MODULE 1
#define CONFIG_BRIDGE_EBT_ARP_MODULE 1
#define CONFIG_NET_VENDOR_MICROSEMI 1
#define CONFIG_ARCH_HAS_TICK_BROADCAST 1
#define CONFIG_USB_CYTHERM_MODULE 1
#define CONFIG_IP6_NF_MATCH_EUI64_MODULE 1
#define CONFIG_MWIFIEX_MODULE 1
#define CONFIG_BINARY_PRINTF 1
#define CONFIG_USB_STORAGE_JUMPSHOT_MODULE 1
#define CONFIG_SND_SOC_SGTL5000_MODULE 1
#define CONFIG_NET_SCH_PLUG_MODULE 1
#define CONFIG_TRACER_MAX_TRACE 1
#define CONFIG_USB_KEENE_MODULE 1
#define CONFIG_ZSTD_DECOMPRESS 1
#define CONFIG_DW_AXI_DMAC 1
#define CONFIG_ARM64_ERRATUM_1165522 1
#define CONFIG_SYSFS_SYSCALL 1
#define CONFIG_WLAN_VENDOR_QUANTENNA 1
#define CONFIG_SND_PCM_TIMER 1
#define CONFIG_DVB_STV6110_MODULE 1
#define CONFIG_ARCH_HAS_SET_DIRECT_MAP 1
#define CONFIG_SYSVIPC_SYSCTL 1
#define CONFIG_WLAN_VENDOR_TI 1
#define CONFIG_HID_NTRIG_MODULE 1
#define CONFIG_IP_VS_IPV6 1
#define CONFIG_DMA_SHARED_BUFFER 1
#define CONFIG_RTC_SYSTOHC 1
#define CONFIG_DVB_USB_NOVA_T_USB2_MODULE 1
#define CONFIG_CIFS_POSIX 1
#define CONFIG_USB_EPSON2888 1
#define CONFIG_OF_ADDRESS 1
#define CONFIG_W1_SLAVE_DS28E04_MODULE 1
#define CONFIG_DECOMPRESS_GZIP 1
#define CONFIG_VIRTIO_MENU 1
#define CONFIG_XFRM_SUB_POLICY 1
#define CONFIG_AX88796B_PHY_MODULE 1
#define CONFIG_DECOMPRESS_LZO 1
#define CONFIG_CRYPTO_XXHASH 1
#define CONFIG_USB_SERIAL_ARK3116_MODULE 1
#define CONFIG_64BIT 1
#define CONFIG_QUOTA 1
#define CONFIG_FTRACE_MCOUNT_USE_PATCHABLE_FUNCTION_ENTRY 1
#define CONFIG_ZBUD 1
#define CONFIG_PARTITION_PERCPU 1
#define CONFIG_MMC_SDHCI_PLTFM 1
#define CONFIG_I2C_CHARDEV_MODULE 1
#define CONFIG_MEDIA_TUNER_FC0013_MODULE 1
#define CONFIG_LLC_MODULE 1
#define CONFIG_ARCH_USE_QUEUED_RWLOCKS 1
#define CONFIG_MEDIA_TUNER_TEA5761_MODULE 1
#define CONFIG_ARCH_KEEP_MEMBLOCK 1
#define CONFIG_REGMAP_MMIO 1
#define CONFIG_MEDIA_TEST_SUPPORT 1
#define CONFIG_GENERIC_CLOCKEVENTS_BROADCAST 1
#define CONFIG_HID_HOLTEK_MODULE 1
#define CONFIG_POWER_SUPPLY_HWMON 1
#define CONFIG_SERIAL_8250_PCI 1
#define CONFIG_LIB80211_CRYPT_CCMP_MODULE 1
#define CONFIG_USB_GSPCA_DTCS033_MODULE 1
#define CONFIG_RTC_DRV_DS1672_MODULE 1
#define CONFIG_USB_SERIAL_SSU100_MODULE 1
#define CONFIG_BATMAN_ADV_DAT 1
#define CONFIG_DVB_USB_DIB3000MC_MODULE 1
#define CONFIG_ATA_BMDMA 1
#define CONFIG_ATALK_MODULE 1
#define CONFIG_XZ_DEC_ARMTHUMB 1
#define CONFIG_B43_BCMA 1
#define CONFIG_USB_F_UAC1_MODULE 1
#define CONFIG_NFS_V4_1 1
#define CONFIG_ARCH_USE_CMPXCHG_LOCKREF 1
#define CONFIG_ARCH_WANT_FRAME_POINTERS 1
#define CONFIG_REGMAP 1
#define CONFIG_6PACK_MODULE 1
#define CONFIG_NLS_UTF8_MODULE 1
#define CONFIG_RADIO_SI470X_MODULE 1
#define CONFIG_FB_IOMEM_HELPERS 1
#define CONFIG_PCIE_PME 1
#define CONFIG_TINYDRM_ILI9225_MODULE 1
#define CONFIG_JOYSTICK_XPAD_MODULE 1
#define CONFIG_USB_DWC2_DUAL_ROLE 1
#define CONFIG_GPIO_WATCHDOG_MODULE 1
#define CONFIG_HAVE_MOD_ARCH_SPECIFIC 1
#define CONFIG_FB_NOTIFY 1
#define CONFIG_CAN_DEV_MODULE 1
#define CONFIG_INPUT_YEALINK_MODULE 1
#define CONFIG_DVB_DIB3000MB_MODULE 1
#define CONFIG_IEEE802154_CC2520_MODULE 1
#define CONFIG_PKCS8_PRIVATE_KEY_PARSER_MODULE 1
#define CONFIG_RTC_DRV_M41T80_MODULE 1
#define CONFIG_STRICT_MODULE_RWX 1
#define CONFIG_VHOST_IOTLB_MODULE 1
#define CONFIG_VT6656_MODULE 1
#define CONFIG_USB_USBNET 1
#define CONFIG_ARM64_ERRATUM_834220 1
#define CONFIG_SND_SOC_CS4271_MODULE 1
#define CONFIG_USB_SERIAL_PL2303_MODULE 1
#define CONFIG_NET_ACT_POLICE_MODULE 1
#define CONFIG_ASM_MODVERSIONS 1
#define CONFIG_HAMRADIO 1
#define CONFIG_SYSCTL_EXCEPTION_TRACE 1
#define CONFIG_SYSVIPC_COMPAT 1
#define CONFIG_GPIO_PCA953X_MODULE 1
#define CONFIG_SENSORS_RASPBERRYPI_HWMON_MODULE 1
#define CONFIG_DVB_USB_CINERGY_T2_MODULE 1
#define CONFIG_FHANDLE 1
#define CONFIG_USB_MICROTEK_MODULE 1
#define CONFIG_HAVE_SAMPLE_FTRACE_DIRECT_MULTI 1
#define CONFIG_HID_SMARTJOYPLUS_MODULE 1
#define CONFIG_WATCHDOG_OPEN_TIMEOUT 0
#define CONFIG_TOUCHSCREEN_GOODIX_MODULE 1
#define CONFIG_NEW_LEDS 1
#define CONFIG_CRYPTO_LIB_SHA256 1
#define CONFIG_SWAP 1
#define CONFIG_CRC64 1
#define CONFIG_USB_NET_CDC_SUBSET_ENABLE_MODULE 1
#define CONFIG_NET_SCH_HFSC_MODULE 1
#define CONFIG_RTC_DRV_RV3029C2_MODULE 1
#define CONFIG_MAC80211_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_GENERAL_TOUCH 1
#define CONFIG_VIDEO_OV2311_MODULE 1
#define CONFIG_STACKPROTECTOR_PER_TASK 1
#define CONFIG_BME680_I2C_MODULE 1
#define CONFIG_CRC_CCITT_MODULE 1
#define CONFIG_IPVLAN_L3S 1
#define CONFIG_NET_VENDOR_CAVIUM 1
#define CONFIG_GPIOLIB_IRQCHIP 1
#define CONFIG_BPF_UNPRIV_DEFAULT_OFF 1
#define CONFIG_DVB_TDA8261_MODULE 1
#define CONFIG_BLK_DEV_SD 1
#define CONFIG_SND_SEQ_VIRMIDI_MODULE 1
#define CONFIG_CMDLINE_FROM_BOOTLOADER 1
#define CONFIG_HISILICON_ERRATUM_161600802 1
#define CONFIG_INPUT_AD714X_SPI_MODULE 1
#define CONFIG_NETFILTER_NETLINK_MODULE 1
#define CONFIG_MODULE_UNLOAD 1
#define CONFIG_FSCACHE_STATS 1
#define CONFIG_PREEMPT_COUNT 1
#define CONFIG_SPI_SLAVE 1
#define CONFIG_USB_GSPCA_BENQ_MODULE 1
#define CONFIG_NET_VENDOR_ENGLEDER 1
#define CONFIG_BT_LE 1
#define CONFIG_DVB_USB_CXUSB_MODULE 1
#define CONFIG_CMA 1
#define CONFIG_RWSEM_SPIN_ON_OWNER 1
#define CONFIG_ARM_GIC_V3_ITS_PCI 1
#define CONFIG_DIMLIB 1
#define CONFIG_MEDIA_TUNER_M88RS6000T_MODULE 1
#define CONFIG_TRACER_SNAPSHOT 1
#define CONFIG_CC_HAS_ASM_GOTO_OUTPUT 1
#define CONFIG_BITREVERSE 1
#define CONFIG_DEVPORT 1
#define CONFIG_IGC_MODULE 1
#define CONFIG_PREEMPTION 1
#define CONFIG_IOSCHED_BFQ 1
#define CONFIG_MACB_USE_HWSTAMP 1
#define CONFIG_X509_CERTIFICATE_PARSER 1
#define CONFIG_BLK_DEV_RAM_SIZE 4096
#define CONFIG_USB_SERIAL_WWAN_MODULE 1
#define CONFIG_ARCH_HAVE_TRACE_MMIO_ACCESS 1
#define CONFIG_MAC_PARTITION 1
#define CONFIG_CONSOLE_POLL 1
#define CONFIG_NFT_TPROXY_MODULE 1
#define CONFIG_XFS_POSIX_ACL 1
#define CONFIG_TTY_PRINTK_LEVEL 6
#define CONFIG_PTP_1588_CLOCK_KVM 1
#define CONFIG_BRCMFMAC_USB 1
#define CONFIG_NLS_ISO8859_13_MODULE 1
#define CONFIG_SND_SOC_TLV320AIC3X_I2C_MODULE 1
#define CONFIG_MT76_CONNAC_LIB_MODULE 1
#define CONFIG_USB_STORAGE_ONETOUCH_MODULE 1
#define CONFIG_NLS_ISO8859_8_MODULE 1
#define CONFIG_NF_CONNTRACK_MODULE 1
#define CONFIG_RTC_DRV_PCF8523 1
#define CONFIG_EFI_RUNTIME_WRAPPERS 1
#define CONFIG_MDIO_DEVRES 1
#define CONFIG_LSM ""
#define CONFIG_ARCH_DMA_ADDR_T_64BIT 1
#define CONFIG_FILE_LOCKING 1
#define CONFIG_USB_GSPCA_XIRLINK_CIT_MODULE 1
#define CONFIG_USB_GSPCA_SN9C20X_MODULE 1
#define CONFIG_CRC64_ROCKSOFT 1
#define CONFIG_TOUCHSCREEN_USB_ELO 1
#define CONFIG_RTC_DRV_DS1302_MODULE 1
#define CONFIG_SND_SOC_I2C_AND_SPI_MODULE 1
#define CONFIG_NETPOLL 1
#define CONFIG_ZSWAP 1
#define CONFIG_AIO 1
#define CONFIG_I2C_MUX_GPMUX_MODULE 1
#define CONFIG_SND_BCM2708_SOC_I_SABRE_Q2M_MODULE 1
#define CONFIG_DVB_TDA8083_MODULE 1
#define CONFIG_NET_MPLS_GSO_MODULE 1
#define CONFIG_DVB_USB_AZ6007_MODULE 1
#define CONFIG_OF 1
#define CONFIG_NET_EMATCH 1
#define CONFIG_PERF_EVENTS 1
#define CONFIG_GENERIC_TIME_VSYSCALL 1
#define CONFIG_IP_NF_TARGET_REJECT_MODULE 1
#define CONFIG_HAVE_MOVE_PMD 1
#define CONFIG_NET_SCH_CHOKE_MODULE 1
#define CONFIG_LEDS_CLASS 1
#define CONFIG_DVB_USB_DIGITV_MODULE 1
#define CONFIG_IP6_NF_MATCH_HL_MODULE 1
#define CONFIG_KALLSYMS_BASE_RELATIVE 1
#define CONFIG_IP_VS_TAB_BITS 12
#define CONFIG_IP6_NF_MATCH_OPTS_MODULE 1
#define CONFIG_IR_PWM_TX_MODULE 1
#define CONFIG_PLAYSTATION_FF 1
#define CONFIG_AS_HAS_LSE_ATOMICS 1
#define CONFIG_RTC_INTF_DEV 1
#define CONFIG_MTD_MAP_BANK_WIDTH_4 1
#define CONFIG_AS_HAS_SHA3 1
#define CONFIG_FUJITSU_ERRATUM_010001 1
#define CONFIG_CRYPTO_AES_ARM64_BS_MODULE 1
#define CONFIG_HID_SUPPORT 1
#define CONFIG_DCACHE_WORD_ACCESS 1
#define CONFIG_IP6_NF_TARGET_NPT_MODULE 1
#define CONFIG_DVB_USB_CE6230_MODULE 1
#define CONFIG_CPU_LITTLE_ENDIAN 1
#define CONFIG_USB_SERIAL_SYMBOL_MODULE 1
#define CONFIG_PSTORE_COMPRESS 1
#define CONFIG_CRYPTO_POLY1305_NEON_MODULE 1
#define CONFIG_MAGIC_SYSRQ_SERIAL_SEQUENCE ""
#define CONFIG_SND_SOC_HDMI_CODEC_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_OSF_MODULE 1
#define CONFIG_USB_MIDI_GADGET_MODULE 1
#define CONFIG_VIDEO_GO7007_MODULE 1
#define CONFIG_MESSAGE_LOGLEVEL_DEFAULT 4
#define CONFIG_SND_VIRMIDI_MODULE 1
#define CONFIG_LIB80211_CRYPT_TKIP_MODULE 1
#define CONFIG_APDS9960_MODULE 1
#define CONFIG_IP_VS_PROTO_UDP 1
#define CONFIG_CMA_ALIGNMENT 8
#define CONFIG_VIDEO_CAMERA_SENSOR 1
#define CONFIG_NLS_DEFAULT "utf8"
#define CONFIG_UTS_NS 1
#define CONFIG_NF_CT_PROTO_GRE 1
#define CONFIG_VIDEO_NOMODESET 1
#define CONFIG_NF_CT_NETLINK_MODULE 1
#define CONFIG_AUXDISPLAY 1
#define CONFIG_USB_NET_SR9800_MODULE 1
#define CONFIG_DMA_ENGINE 1
#define CONFIG_NET_EMATCH_TEXT_MODULE 1
#define CONFIG_HID_WIIMOTE_MODULE 1
#define CONFIG_USB_MA901_MODULE 1
#define CONFIG_CGROUP_PIDS 1
#define CONFIG_CRYPTO_AEAD2 1
#define CONFIG_CRYPTO_FCRYPT_MODULE 1
#define CONFIG_NET_IPIP_MODULE 1
#define CONFIG_IP_VS_SH_TAB_BITS 8
#define CONFIG_USB_SERIAL_IPAQ_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_HL_MODULE 1
#define CONFIG_QCOM_QDF2400_ERRATUM_0065 1
#define CONFIG_ARM64_E0PD 1
#define CONFIG_CRYPTO_ALGAPI2 1
#define CONFIG_NETFILTER_XT_TARGET_LED_MODULE 1
#define CONFIG_WEXT_SPY 1
#define CONFIG_UBIFS_FS_LZO 1
#define CONFIG_USB_G_ACM_MS_MODULE 1
#define CONFIG_HAVE_EFFICIENT_UNALIGNED_ACCESS 1
#define CONFIG_INPUT 1
#define CONFIG_PPPOATM_MODULE 1
#define CONFIG_PROC_SYSCTL 1
#define CONFIG_ATH6KL_MODULE 1
#define CONFIG_FWNODE_MDIO 1
#define CONFIG_MMC_SDHCI_BRCMSTB 1
#define CONFIG_NETFILTER_XT_TARGET_CT_MODULE 1
#define CONFIG_RD_LZ4 1
#define CONFIG_CPU_MITIGATIONS 1
#define CONFIG_MMU 1
#define CONFIG_DVB_CX24123_MODULE 1
#define CONFIG_I2C_BCM2835_MODULE 1
#define CONFIG_MEDIA_CONTROLLER_DVB 1
#define CONFIG_OCFS2_FS_MODULE 1
#define CONFIG_MFD_RASPBERRYPI_POE_HAT_MODULE 1
#define CONFIG_USB_KAWETH_MODULE 1
#define CONFIG_USB_SIERRA_NET_MODULE 1
#define CONFIG_LD_VERSION 23800
#define CONFIG_BRIDGE_EBT_NFLOG_MODULE 1
#define CONFIG_HAVE_HARDLOCKUP_DETECTOR_BUDDY 1
#define CONFIG_KUSER_HELPERS 1
#define CONFIG_ZPOOL 1
#define CONFIG_INPUT_AD714X_MODULE 1
